<?php
/**
 * @version $Id: bulletinsControleur.php 27 2009-11-13 16:03:31Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of competencesRB.
 *
 * competencesRB is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * competencesRB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with competencesRB.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

class bulletinsControleur extends applicationControleur{

  /**
   * L'objet bulletin pour la mthode perso()
   * @var object bulletin
   */
  protected $_Bulletin = NULL;
  /**
   * Liste des values pour les textarea de la vue persoBulletin
   * @var array objects appreciation
   */
  protected $_values = NULL;

  public function index(){

    $periodeactuelle = PeriodePeer::getPeriodeActuelle($this->user->getRne());

    $form = new formulaireHtml(array('action'=>'ajouter', 'forme'=>'p', 'name'=>'ajouterBulletin'), $this->_params);
    $form->addInput(array('name'=>'nom', 'label'=>'Nom : '));
    $form->addInput(array('name'=>'debut', 'label'=>'D&eacute;but de la p&eacute;riode : ', 'title'=>'Choisissez une p&eacute;riode d&eacute;j&agrave; d&eacute;finie si vous souhaitez la faire correspondre'));
    $form->addInput(array('name'=>'fin', 'label'=>'Fin de la p&eacute;riode : ', 'title'=>'Choisissez une p&eacute;riode d&eacute;j&agrave; d&eacute;finie si vous souhaitez la faire correspondre'));
    $form->addSelect(array('name'=>'periode', 'label'=>'Une p&eacute;riode ? ', 'title'=>'Choisissez une p&eacute;riode d&eacute;j&agrave; d&eacute;finie si vous souhaitez la faire correspondre'), PeriodePeer::listeForSelect($this->user->getRne()));
    $form->addSelect(array('name'=>'classe', 'selected'=>'nulle', 'multiple'=>'on', 'label'=>'Les classe concern&eacute;es', 'title'=>'Vous pouvez en choisir plusieurs en cliquant sur [Ctrl]'), UtilisateurPeer::listeClasseForSelect());
    $form->addInput(array('type'=>'submit', 'name'=>'enregistrer', 'value'=>'Enregistrer'));

    $this->form = $form;

    $c = new Criteria();
    $c->add(BulletinPeer::RNE, $this->user->getRne());
    $this->_arrayTexte = BulletinPeer::doSelect($c);

  } // index()

  /**
   * Lister les informations sur un bulletin (admin)
   */
  public function infos(){

    $bul = BulletinPeer::retrieveByPK($this->_params['info']);
    $bul->getAppreciations();
    $this->_texte = $bul;

    # On rcupre aussi les informations sur la liste des lves de la classe
    $this->_arrayTexte = UtilisateurPeer::listeElevesCetteCLasse($bul->getClasseId());

  }

  /**
   * Pour ajouter un bulletin
   */
  public function ajouter(){

    if ($this->_requete->isPost() === true){
      $requete = $this->_requete->ajouterBulletin;
      # On vrifie quelques donnes
      if ($requete['nom'] == ''){
        $this->setErreurMessage('Il faut donner un nom au bulletin !');
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit();
      }
      $datedeb = explode("/", $requete["debut"]);
      $datefin = explode("/", $requete["fin"]);
      if (($requete["debut"] != '' AND count($datedeb) != 3) OR ($requete["fin"] != '' AND count($datefin) != 3)){
        $this->setErreurMessage('Le format de date n\'est pas respect&eacute; JJ/MM/YYYY !');
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit();
      }
      if (($requete["debut"] == '' AND $requete["fin"] == '') OR $requete["periode"] != 'nulle'){
        # On vrifie si une priode existe et on rentre ses donnes
        if ($requete["periode"] == 'nulle'){
          $this->setErreurMessage('Il faut choisir une p&eacute;riode si vous ne pr&eacute;cisez pas de dates !');
          $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
          exit();
        }else{
          $periode = PeriodePeer::retrieveByPK($requete["periode"]);
          $debut = $periode->getDebut();
          $fin = $periode->getFin();
        }
      }else{
        # Dans ce cas, on prend les dates envoyes par l'admin
        $debut = mktime(2, 0, 0, $datedeb[1], $datedeb[0], $datedeb[2]);
        $fin = mktime(23, 59, 0, $datefin[1], $datefin[0], $datefin[2]);
      }
      # On compte le nombre de classes concernes
      $marqueur = true;
      $nbre = count($requete['classe']);
      for($a = 0 ; $a < $nbre ; ++$a){
        $newBull = new Bulletin();
        $newBull->setNom(htmlentities($requete['nom']));
        $newBull->setRne($this->user->getRne());
        $newBull->setDebut($debut);
        $newBull->setFin($fin);
        $newBull->setCreatedOn(date('U'));
        $newBull->setClasseId($requete["classe"][$a]);
        if ($newBull->save()){

        }else{
          $marqueur = false;
          $_erreur = $requete["classe"][$a];
        }
      }

      if ($marqueur === false){
        $this->setErreurMessage('Il est impossible d\'enregistrer ce bulletin pour ces classes : '.$_erreur);
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit ();
      }
      $this->redirect_to(array('action'=>'index', 'info'=>'enregistre'));
      exit ();
    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  }

  /**
   * Pour effacer un bulletin
   */
  public function effacer(){

    if ($this->_params['info'] != ''){
      # On fait quelques vrifications
      $test = BulletinPeer::retrieveByPK($this->_params['info']);
      if ((!empty ($test)) AND $test->getRne() == $this->user->getRne()){
        # Si ce bulletin a des apprciations,  il faut arrter la procdure
        $verif = $test->getAppreciations();
        if (!empty ($verif)){
          $this->setErreurMessage('Impossible de supprimer ce bulletin car il existe des appr&eacute;ciations pour lui !');
          $this->redirect_to(array('action'=>'index', 'info'=>'tous'));
          exit();
        }

        # On efface les liens avec les comptences transversales
        $c = new Criteria();
        $c->add(JBulletinTransversalesPeer::BULLETIN_ID, $test->getId());
        JBulletinTransversalesPeer::doDelete($c);

        $test->delete();
        $this->redirect_to(array('action'=>'index', 'info'=>'efface'));
        exit();
      }else{
        $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
      }
      
    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  }

  public function fermerBulletin(){
    $test = BulletinPeer::retrieveByPK($this->_params['info']);
    $test->setFerme('O');
    $test->save();
    $this->redirect_to(array('action'=>'index', 'info'=>'bulletin_'.$this->_params['info'].'_ferme'));
    exit();
  }
  public function ouvrirBulletin(){
    $test = BulletinPeer::retrieveByPK($this->_params['info']);
    $test->setFerme('N');
    $test->save();
    $this->redirect_to(array('action'=>'index', 'info'=>'bulletin_'.$this->_params['info'].'_ouvert'));
    exit();
  }

  public function persoBulletin(){

    $this->_aideMessage = '<p>Vous devez choisir une classe dans la liste suivante pour y saisir vos appr&eacute;ciations.</p>';

    $liste_classes = $this->user->getJProfesseurClassess();
    $tab = array();
    foreach ($liste_classes as $jclasse) {
      $tab[] = $jclasse->getClasseId();
    }

    $c = new Criteria();
    $c->add(BulletinPeer::FERME, 'N');
    $c->add(BulletinPeer::FIN, date("U"), Criteria::GREATER_EQUAL);
    $c->add(BulletinPeer::RNE, $this->user->getRne());
    $c->add(BulletinPeer::CLASSE_ID, $tab, Criteria::IN);
    $c->addJoin(BulletinPeer::CLASSE_ID, ClassePeer::ID);
    $c->addAscendingOrderByColumn(ClassePeer::NOMLONG);
    $this->_arrayTexte = BulletinPeer::doSelect($c);
  }

  public function perso(){

    $this->_aideMessage = '<p>Vous ne voyez que les &eacute;l&egrave;ves pour lesquels vous avez saisi des bilans</p>
                           <p>Vous pouvez choisir des bilans pour qu\'ils apparaissent sur les bulletins en les cochant.</p>
                           <p class="red">N\'oubliez pas d\'enregistrer avant de quitter cette page.</p>';

    $periodeactuelle = PeriodePeer::getPeriodeActuelle($this->user->getRne());

    $c = new Criteria();
    $c->setDistinct();
    $c->add(BilanPeer::PROFESSEUR_ID, $this->user->getId());
    $c->add(BilanPeer::TRANSVERSALE, 'N');
    if (is_numeric($this->_params['info'])){
      # On ne propose que les lves de la classe concerne par ce bulletin
      $this->_Bulletin = BulletinPeer::retrieveByPK($this->_params['info']);
      $c->add(UtilisateurPeer::CLASSE_ID, $this->_Bulletin->getClasseId(), Criteria::EQUAL);
      $criter1 = $c->getNewCriterion(BilanPeer::DATE, $this->_Bulletin->getFin(), Criteria::LESS_EQUAL);
      $criter2 = $c->getNewCriterion(BilanPeer::DATE, $this->_Bulletin->getDebut(), Criteria::GREATER_EQUAL);
      $criter1->addAnd($criter2);
      $c->add($criter1);
    }else{

      Die('Vous ne devriez pas &ecirc;tre ici ! Pr&eacute;venez votre administrateur !');

    }
    $c->addAscendingOrderByColumn(UtilisateurPeer::NOM);
    $c->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
    $bilans = BilanPeer::doSelectJoinUtilisateurRelatedByEleveId($c);

    $this->_arrayTexte = $bilans;

    $this->_texte = ValidationNiveauPeer::listeNiveauxValidation('color');

    # On cherche s'il eiste dj des apprciations saisies pour ce bulletin pour ce professeur
    $c = new Criteria();
    $c->add(AppreciationPeer::BULLETIN_ID, $this->_Bulletin->getId());
    $c->add(AppreciationPeer::PROFESSEUR_ID, $this->user->getId());
    $c->add(AppreciationPeer::TRANSVERSALE, 'N');
    $test = AppreciationPeer::doSelect($c);
      // on rordonne ensuite les index du tableau pour s'y retrouver ensuite
    $tab = array();
    foreach ($test as $apprec) {
      $tab[$apprec->getEleveId()] = $apprec;
    }
    $this->_values = $tab;

  } // perso()

  /**
   * Enregistre les apprciations d'un professeur pour ses lves
   */
  public function ajouterAppreciation(){
    if ($this->_requete->isPost() === true){
      $nbre = count($this->_requete->eleve);
      $marqueur = true;
      $_erreur = NULL;
      for($a = 0 ; $a < $nbre ; ++$a){

        if ($this->_requete->appreciation[$a] != ''){
          if ($this->_requete->exist[$a] == ''){
            $newApprec = new Appreciation();
          }else{
            $newApprec = AppreciationPeer::retrieveByPK((int) $this->_requete->exist[$a]);
          }
          $newApprec->setBulletinId((int) $this->_requete->bulletinId);
          $newApprec->setProfesseurId((int) $this->user->getId());
          $newApprec->setEleveId((int) $this->_requete->eleve[$a]);
          $newApprec->setContenu(htmlentities($this->_requete->appreciation[$a]));
          $newApprec->setCreatedOn(date('U'));

          if ($newApprec->save()){
            // on peut enregistrer les bilans qui sont lis avec cette apprciation
            // sans oublier d'effacer la liste des bilans dj enregistrs s'il s'agit d'une mise  jour ...
            if ($this->_requete->exist[$a] != ''){
              $c = new Criteria();
              $c->add(JAppreciationBilanPeer::APPRECIATION_ID, $newApprec->getId());
              $eff = JAppreciationBilanPeer::doDelete($c);
            }
            // ... ni de vrifier qu'il existe au moins une entre de bilan
            if (!is_null($this->_requete->bilans) AND array_key_exists($a, $this->_requete->bilans)){
              foreach ($this->_requete->bilans[$a] as $bilan){
                $newJoin = new JAppreciationBilan();
                $newJoin->setAppreciation($newApprec);
                $newJoin->setBilanId($bilan);
                $newJoin->save();
              }
            }
          }else{
            $marqueur = false;
            $_erreur .= ' E::'.$this->_requete->eleve[$a].'-B::'.$this->_requete->bulletinId;
          }
        }

      }

      if ($marqueur === true){
        // Tout s'est bien pass
        $this->setMessage('Cette apr&eacute;ciation est bien enregistr&eacute;e !');
        $this->redirect_to(array('action'=>'perso', 'info'=>$this->_requete->bulletinId));
        exit();
      }else{
        $this->setErreurMessage('Une ou des erreurs ont rendu impossibles l\'enregistrement des appr&eacute;ciations suivantes :'.$_erreur);
        $this->redirect_to(array('action'=>'perso', 'info'=>$this->_requete->bulletinId));
        exit();
      }

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

    //$this->affDebug($newApprec);
  } // ajouterAppreciation()

  public function editer(){
    $periodeactu = PeriodePeer::getPeriodeActuelle($this->user->getRne());
    $c = new Criteria();
    $c->add(BulletinPeer::CLASSE, '6EME2');
    $c->add(BulletinPeer::FERME, 'N');
    $criter1 = $c->getNewCriterion(BulletinPeer::DEBUT, $periodeactu->getDebut(), Criteria::GREATER_EQUAL);
    $criter2 = $c->getNewCriterion(BulletinPeer::FIN, $periodeactu->getFin(), Criteria::LESS_EQUAL);
    $criter1->addAnd($criter2);
    $c->add($criter1);
    $test = BulletinPeer::doSelect($c);

    $c = new Criteria();
    $c->add(AppreciationPeer::BULLETIN_ID, $test[0]->getId());
    $this->_arrayTexte = AppreciationPeer::doSelectJoinUtilisateurRelatedByEleveId($c);

  } // editer()

  /**
   * Mthode qui permet de dfinir les comptences transversales d'un bulletin
   */
  public function cptcesTransversalesBulletin(){

    $c = new Criteria();
    $c->add(BulletinPeer::ID, $this->_params['info']);
    $c->add(BulletinPeer::RNE, $this->user->getRne());
    $bulletin = BulletinPeer::doSelect($c);

    if (!empty ($bulletin)){
      $this->_texte = $bulletin[0];
    }else{
      $this->setErreurMessage('Ce bulletin n\'existe pas !');
      logControleur::insertLog('pirate', 2, 'Acces bulletin inexistant ou pas bon RNE : id_bulletin='.$this->_params['info'], $this->user->getId());
      $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
      exit();
    }

    # Le formulaire pour ajouter une cptce transversale
    $form = new formulaireHtml(array('name'=>'ajouterCptce','id'=>'idSelectCptce', 'forme'=>'p', 'action'=>'addCptceTrans'), $this->_params);
    $form->addInput(array('type'=>'hidden', 'name'=>'bulletin', 'value'=>$this->_texte->getId()));
    $form->addSelect(array('name'=>'transversale', 'js'=>'onchange="document.getElementById(\'idSelectCptce\').submit();"', 'limite'=>160), CompetencePeer::listeCptecesAvecPreferenceForSelect('toutes', $this->user));
    $this->form = $form;

  } // cptcesTransversalesBulletin()

  public function addCptceTrans(){
    //$this->affDebug();

    if ($this->_requete->isPost() === true){

      # On peut enregistrer cette comptence comme transversale pour ce bulletin aprs avoir vrifier l'existence du bulletin et de la comptence
      $test_cptce = CompetencePeer::retrieveByPK($this->_requete->ajouterCptce['transversale']);
      $test_bulle = BulletinPeer::retrieveByPK($this->_requete->ajouterCptce['bulletin']);

      if ($test_bulle->getRne() == $this->user->getRne() && ($test_cptce->getRne() == 'all' OR $test_cptce->getRne() == $this->user->getRne())){
        $new = new JBulletinTransversales();
        $new->setBulletin($test_bulle);
        $new->setCompetence($test_cptce);
        $new->setRne($this->user->getRne());
        if ($new->save()){
          $this->setMessage('Comp&eacute;tence ajout&eacute;e !');
          $this->redirect_to(array('action'=>'cptcesTransversalesBulletin', 'info'=>$test_bulle->getId()));
          exit();
        }else{
          $this->setErreurMessage('Impossible d\'effectuer cet enregistrement !');
          $this->redirect_to(array('action'=>'cptcesTransversalesBulletin', 'info'=>$test_bulle->getId()));
          exit();
        }
      }else{
        $this->setErreurMessage('Il ne faut pas tenter de modifier les donn&eacute;es envoy&eacute;es !');
        logControleur::insertLog('pirate', 1, 'Tentative ajouter transversale sur bulletin : '.$test_bulle, $this->user->getId());
        $this->redirect_to(array('action'=>'cptcesTransversalesBulletin', 'info'=>$test_bulle->getId()));
        exit();
      }


    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  } // addCptceTrans()

  /**
   * Suppression d'une comptence transversale d'un bulletin
   */
  public function delCptceTrans(){

    if (isset ($_GET['deltrans'])){
      # Il faut donc vrifier si ce bulletin appartient bien  cet tablissement
      $bul = BulletinPeer::retrieveByPK($this->_params['info']);
      if (empty ($bul) OR $bul->getRne() != $this->user->getRne()){
        $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
      }

      $del = JBulletinTransversalesPeer::retrieveByPK($bul->getId(), $_GET['deltrans']);
      if ($del->delete()){
        $this->redirect_to(array('action'=>'addCptceTrans', 'info'=>$bul->getId()));
        exit();
      }

    }

  } // delCptceTrans()

  /**
   * Permet d'afficher la liste des comptences transversales pour le Professeur Principal
   */
  public function transPP(){

    # On vrifie si le bulletin est bien ouvert
    $bull = isset ($_GET['bull']) ? BulletinPeer::retrieveByPK($_GET['bull']) : NULL;
    if (is_null($bull) OR $bull->getFerme() == 'O'){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'-L::'.__LINE__, $this->user->getId());
    }
    # On vrifie si ce bulletin correspond bien  cette classe
    if ($bull->getClasseId() != $this->_params['info']){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'-L::'.__LINE__, $this->user->getId());
    }
    # On vrifie si ce professeur est bien PP de cette classe
    $test = false;
    foreach ($this->user->getJProfesseurPrincipalClassess() as $joinPP) {
      if ($joinPP->getClasseId() == $this->_params['info']){
        $test = true;
      }
    }
    if ($test === false){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'L::'.__LINE__, $this->user->getId());
    }

    $this->_texte = $bull;
    # On envoie aussi la liste des lves de la classe pour construire le formulaire dans la vue
    $c = new Criteria();
    $c->add(UtilisateurPeer::RNE, $this->user->getRne());
    $c->add(UtilisateurPeer::CLASSE_ID, $this->_params['info']);
    $c->add(UtilisateurPeer::ROLE_ID, rolePeer::getIdByName('eleve'));
    $c->addAscendingOrderByColumn(UtilisateurPeer::NOM);
    $c->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
    $this->_arrayTexte = UtilisateurPeer::doSelect($c);

    # On envoie aussi la liste des apprciations dj effectues pour ce bulletin
    $c = new Criteria();
    $c->add(AppreciationPeer::PROFESSEUR_ID, $this->user->getId());
    $c->add(AppreciationPeer::BULLETIN_ID, $bull->getId());
    $this->saisies = AppreciationPeer::doSelect($c);
    

  } // transPP()


  public function transAjouter(){

    # On vrifie si le bulletin est bien ouvert
    $bull = BulletinPeer::retrieveByPK($this->_params['info']);
    if (is_null($bull) OR $bull->getFerme() == 'O'){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'-L::'.__LINE__, $this->user->getId());
    }
    # On vrifie si ce bulletin correspond bien  cette classe
    if ($bull->getClasseId() != $this->_requete->classe_id){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'-L::'.__LINE__, $this->user->getId());
    }
    # On vrifie si ce professeur est bien PP de cette classe
    $test = false;
    foreach ($this->user->getJProfesseurPrincipalClassess() as $joinPP) {
      if ($joinPP->getClasseId() == $this->_requete->classe_id){
        $test = true;
      }
    }
    if ($test === false){
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'L::'.__LINE__, $this->user->getId());
    }

    foreach ($this->_requete->eleve as $cle => $eleve_id) {

      # On vrifie que cet lve est bien de cet tablissement
      $test_eleve = UtilisateurPeer::retrieveByPK($eleve_id);
      if ($test_eleve->getRne() != $this->user->getRne()){
        $this->dehorsUtilisateur('', __CLASS__, __METHOD__.'L::'.__LINE__, $this->user->getId());
      }
      if (isset($this->_requete->appreciation_id[$cle]) AND $this->_requete->appreciation_id[$cle] != ''){
        $appreciation = AppreciationPeer::retrieveByPK($this->_requete->appreciation_id[$cle]);
      }else{
        $appreciation = new Appreciation();
      }
      $appreciation->setBulletinId($bull->getId());
      $appreciation->setCreatedOn(date('U'));
      $appreciation->setProfesseurId($this->user->getId());
      $appreciation->setEleveId($eleve_id);
      $appreciation->setTransversale('O');
      $appreciation->setContenu(htmlentities($this->_requete->appreciation[$cle]));
      if ($appreciation->save()){
        $marqueur = true;
      }

      $erreur = '';
      $lettres_autorisees = ValidationNiveauPeer::listeNiveauxValidation();
      foreach ($this->_requete->result[$cle] as $cptce => $eval) {
        # On cre les bilans proposs
        if (isset($this->_requete->bilan[$cle][$cptce]) AND $this->_requete->bilan[$cle][$cptce] != ''){
          $bilan = BilanPeer::retrieveByPK($this->_requete->bilan[$cle][$cptce]);
        }else{
          $bilan = new Bilan();
        }
        $cptce_object = CompetencePeer::retrieveByPK($cptce);
        $bilan->setCompetenceId($cptce);
        $bilan->setCreatedOn(date('U'));
        $bilan->setNom($cptce_object->getNomcourt());
        $bilan->setDate(date('U'));
        $bilan->setEleveId($eleve_id);
        $bilan->setProfesseurId($this->user->getId());
        $bilan->setTransversale('O');
        $bilan->setRne($this->user->getRne());
        if (array_key_exists($eval, $lettres_autorisees)){
          $bilan->setResultat($eval);

          if ($bilan->save()){
            // rien  faire
          }else{
            $marqueur = false;
            $erreur .= $bilan->getCompetence()->getNomcourt().'<br />';
          }

          # On vrifie si c'est une mise  jour ou un enregistrement nouveau avant de lier ces bilans  cette apprciation
          if (isset($this->_requete->bilan[$cle][$cptce]) AND $this->_requete->bilan[$cle][$cptce] == ''){
            # On les joint  l'apprciations si ces bilans n'existaient pas
            $joinBilanApprec = new JAppreciationBilan();
            $joinBilanApprec->setAppreciation($appreciation);
            $joinBilanApprec->setBilan($bilan);
            $joinBilanApprec->save();
          }

        }

      }

    }
    if ($marqueur === false){
      $this->setErreurMessage('Certaines inforamtions n\'ont pas pu tre enregistres : '.$erreur);
      $this->redirect_to(array('action'=>'transPP', 'info'=>$this->_requete->classe_id, 'get'=>array('bull'=>$bull->getId())));
      exit();
    }else{
      $this->setMessage('Bilans et appr&eacute;ciations enregistr&eacute;es !');
      $this->redirect_to(array('action'=>'transPP', 'info'=>$this->_requete->classe_id, 'get'=>array('bull'=>$bull->getId())));
      exit();
    }

  } // transAjouter()
}
?>