<?php
/**
 * @version $Id: grillesControleur.php 2 2009-10-25 12:25:37Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of competencesRB.
 *
 * competencesRB is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * competencesRB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with competencesRB.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */
   

/**
 *  Controleur des grilles
 */

class grillesControleur extends applicationControleur{

  public function index(){

    $this->_aideMessage = '<h5>Une grille est une liste de comp&eacute;tences li&eacute;e &agrave; une liste de groupes d\'&eacute;l&egrave;ves</h5>
                          Vous pouvez construire toutes les grilles que vous voulez en utilisant des comp&eacute;tences du socle, de l\'&eacute;quipe
                          p&eacute;dagogique ou personnelles. Il suffit de demander la cr&eacute;ation d\'une nouvelle grille et de cliquer dessus pour y
                          ajouter des comp&eacute;tences et la rattacher  un ou plusieurs groupes d\'&eacute;l&egrave;ves.
                          <p><span class="red">Attention : </span> il ne faut pas supprimer une grille qui a d&eacute;j&agrave; &eacute;t&eacute; utilis&eacute;e
                           pour un contr&ocirc;le ni modifier la liste de ses comp&eacute;tences, ni supprimer des groupes d\'&eacute;l&egrave;ves.</p>
                          <p class="green">A l\'inverse, vous pouvez ajouter des groupes d\'&eacute;l&egrave;ves &agrave; une grille existante.</p>';

    $formulaire = new formulaireHtml(array('name'=>'ajoutergrille', 'action'=>'ajouter', 'forme'=>'p'), $this->_params);
    $formulaire->addInput(array('name'=>'nom', 'label'=>'Nom : '));
    $formulaire->addInput(array('type'=>'hidden', 'name'=>'type', 'value'=>'perso')); // On limite aux grilles personnelles pour le moment
    $formulaire->addSelect(array('name'=>'matiere', 'label'=>'Matire : ', 'selected'=>$this->user->getMatiereId()), MatierePeer::listeMatieresForSelect());
    $formulaire->addInput(array('type'=>'submit', 'name'=>'ajouter', 'value'=>'Ajouter'));

    $this->form = $formulaire;

    $c = new Criteria();
    $criter1 = $c->add(GrillePeer::UTILISATEUR_ID, array($this->user->getId(), '0'), Criteria::IN); // les peda et les perso sont affiches
    $c->addAscendingOrderByColumn(GrillePeer::NOM);
    $this->_arrayTexte = GrillePeer::doSelectJoinMatiere($c);

  } // index

  public function ajouter(){

    if ($this->_requete->isPost() === true){
      $new = new Grille();
      $new->setNom(htmlentities($this->_requete->ajoutergrille['nom']));
      $new->setType($this->_requete->ajoutergrille['type']);
      $new->setMatiereId($this->_requete->ajoutergrille['matiere']);
      $new->setRne($this->user->getRne());
      $new->setCreatedOn(date("U"));
      if ($this->_requete->ajoutergrille['type'] == 'perso'){
        $new->setUtilisateur($this->user);
      }

      if ($new->save()){
        $this->redirect_to(array('action'=>'index', 'info'=>'enregistre'));
        exit();
      }else{
        $_SESSION["erreurMsg"] = 'Impossible d\'enregistrer cette grille !';
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit();
      }

    }

  } // ajouter

  public function effacer(){

    if ($this->_requete->isGet() === true AND $this->_requete->getGet('e') == 'r'){
      # Avant de supprimer cette grille, il faut vrifier qu'elle n'est pas rattache  un contrle
      $test = GrillePeer::retrieveByPK($this->_params['info']);
      if (empty ($test)){
        $this->setErreurMessage('Impossible d\'effacer cette grille car elle n\'existe pas !');
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit();
      }else{
        $test2 = $test->getControles();
        if (empty ($test2)){
          # On efface alors les liens avec les groupes et les comptences
          $c = new Criteria();
          $c->add(JGrilleCompetencePeer::GRILLE_ID, $test->getId()); // @todo  faire
          $listeJoin = JGrilleCompetencePeer::doDelete($c);
          $c = new Criteria();
          $c->add(JGrilleGroupePeer::GRILLE_ID, $test->getId());
          $listeJoin = JGrilleGroupePeer::doDelete($c);

          $test->delete();

          $this->redirect_to(array('action'=>'index', 'info'=>'efface'));
          exit();
        }else{
          $this->setErreurMessage('Impossible d\'effacer cette grille car elle est rattach&eacute;e &agrave; des contr&ocirc;les !');
          $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
          exit();
        }
      }

    }

  } // effacer

  /**
   * Modifier le nom de la grille
   */
  public function modifierNom(){
    //$this->affDebug();
    if ($this->_requete->isPost() === true){

      # Il faut vrifier si cet utilisateur peut modifier cette grille
      $grille = GrillePeer::retrieveByPK($this->_requete->grille_id);
      if (!empty ($grille)){
        # On vrifie le possesseur
        if ($grille->getUtilisateurId() != $this->user->getId()){
          logControleur::insertLog('pirate', 1, 'pas sa grille : '.$this->_requete->grille_id.'-C::grilles-A::modifierNom', $this->user->getId());
          $this->setErreurMessage('Cette grille ne vous appartient pas, vous ne pouvez pas la modifier !');
          $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
          exit();
        }

        $grille->setNom(htmlentities($this->_requete->grille_nom));
        if ($grille->save()){
          $this->setMessage('Modification enregistr&eacute;e !');
          $this->redirect_to(array('action'=>'eleves', 'info'=>$grille->getId()));
          exit();
        }else{
          $this->setErreurMessage('Impossible de modifier le nom de cette grille !');
          $this->redirect_to(array('action'=>'eleves', 'info'=>$grille->getId()));
          exit();
        }

      }else{
        logControleur::insertLog('pirate', 1, 'grille inexistante : '.$this->_requete->grille_id.'-C::grilles-A::modifierNom', $this->user->getId());
        $this->setErreurMessage('Cette grille n\'existe pas, vous ne pouvez pas la modifier !');
        $this->redirect_to(array('action'=>'index', 'info'=>'erreur'));
        exit();
      }

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }
  }

  /**
   * Permet de lier un groupe d'lves  une grille de comptences
   */
  public function eleves(){

    $this->_aideMessage = 'Vous pouvez lier cette grille avec plusieurs groupes et plusieurs comp&eacute;tences,
    il suffit d\'utiliser la touche [Ctrl] de votre clavier. De plus, il est possible de ne voir que les comp&eacute;tences qui ne sont pas du socle.';

    // $grille est donc l'objet grille en question si elle appartient bien  cet utilisateur
    $grille = GrillePeer::utilisateurUtiliseCetteGrille($this->user, $this->_params['info']);
    if ($grille !== false){

      $this->_arrayTexte = $grille;

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

    # Les groupes
    $formulaire = new formulaireHtml(array('name'=>'liergroupegrille', 'action'=>'lierAvecGroupe', 'info'=>$this->_params['info'], 'forme'=>'p'), $this->_params);
    $formulaire->addSelect(array('name'=>'groupe', 'multiple'=>'on'), GroupePeer::listeGroupesForSelect($this->user, 'perso'));
    $formulaire->addInput(array('type'=>'submit', 'name'=>'ajouter', 'value'=>'Ajouter'));

    $this->form = $formulaire;

    # les comptences (on affiche en fonction de la demande)
    $_SESSION['typeaff'] = (isset($_GET['typeaff']) AND in_array($_GET['typeaff'], array('pedaperso', 'toutes'))) ? $_GET['typeaff'] : $_SESSION['typeaff'];
    $form2 = new formulaireHtml(array('name'=>'liergrpcptces', 'action'=>'lierAvecCompetences', 'info'=>$this->_params['info'], 'forme'=>'p'), $this->_params);
    $form2->addSelect(array('name'=>'cptces', 'multiple'=>'on', 'class'=>'limiterHauteur', 'limite'=>80), CompetencePeer::listeCptecesAvecPreferenceForSelect($_SESSION['typeaff'], $this->user));
    $form2->addInput(array('type'=>'submit', 'name'=>'ajouter', 'value'=>'Ajouter'));

    $this->form2 = $form2;

  } // eleves

  /**
   * Enregistre la liste des groupes rattachs  une grille et renvoie sur eleves()
   */
  public function lierAvecGroupe(){

    if ($this->_requete->isPost() === true AND GrillePeer::utilisateurUtiliseCetteGrille($this->user, $this->_params['info'])){

      $marqueur = true;
      $grperror = NULL;
      foreach ($this->_requete->liergroupegrille['groupe'] as $groupe) {
        if ($groupe != '0'){
          $lier = new JGrilleGroupe();
          $lier->setGrilleId($this->_params['info']);
          $lier->setGroupeId($groupe);
          if ($lier->save()){
            // rien
          }else{
            $marqueur = false;
            $grperror .= ' '.$groupe;
          }
        }
      }
      if ($marqueur === true){
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();
      }else{
        $this->setErreurMessage('Impossible d\'enregistrer ces groupes :'.$grperror.' pour cette grille');
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();
      }

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }
  }

  /**
   * Enregistre la liste des comptences de cette grille
   */
  public function lierAvecCompetences(){

    if ($this->_requete->isPost() === true AND GrillePeer::utilisateurUtiliseCetteGrille($this->user, $this->_params['info'])){

      $marqueur = true;
      $grperror = NULL;
      foreach ($this->_requete->liergrpcptces['cptces'] as $cptce) {
        if ($cptce != '0'){
          $lier = new JGrilleCompetence();
          $lier->setGrilleId($this->_params['info']);
          $lier->setCompetenceId($cptce);
          if ($lier->save()){
            // rien
          }else{
            $marqueur = false;
            $grperror .= ' '.$cptce;
          }
        }
      }
      if ($marqueur === true){
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();
      }else{
        $_SESSION['erreurMsg'] = 'Impossible d\'enregistrer ces comp&eacute;tences :'.$grperror.' pour cette grille';
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();
      }

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  } // lierAvecCompetences()

  /**
   * Supprime une comptence de la liste de cette grille
   */
  public function delierCompetence(){

    if ($this->_requete->isGet() === true AND GrillePeer::utilisateurUtiliseCetteGrille($this->user, $this->_params['info'])){

      $c = new Criteria();
      $c->add(JGrilleCompetencePeer::GRILLE_ID, $this->_params['info'], Criteria::EQUAL);
      $c->add(JGrilleCompetencePeer::COMPETENCE_ID, $_GET['cptce'], Criteria::EQUAL);
      $test = JGrilleCompetencePeer::doSelect($c);

      if (!empty ($test)){
        foreach ($test as $join) {
          JGrilleCompetencePeer::doDelete($join);
        }
      }
      $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  } // delierCompetence()

  /**
   * Supprime un groupe de la liste de cette grille
   */
  public function delierGroupe(){

    if ($this->_requete->isGet() === true AND GrillePeer::utilisateurUtiliseCetteGrille($this->user, $this->_params['info'])){

      # On vrifie qu'il n'existe pas de notes pour ce groupe sur cette grille
      $p = new Criteria();
      $p->add(ControlePeer::GRILLE_ID, $this->_params['info']);
      $p->add(ControlePeer::GROUPE_ID, $_GET['groupe']);
      $testGroupe = ControlePeer::doSelect($p);
      if (!empty ($testGroupe)){
        $this->setErreurMessage('Ce groupe poss&egrave;de d&eacute;j&agrave; un contr&ocirc;le sur cette grille pour ce groupe ! Supprimez-le si vous voulez continuer !');
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();
      }

      $c = new Criteria();
      $c->add(JGrilleGroupePeer::GRILLE_ID, $this->_params['info'], Criteria::EQUAL);
      $c->add(JGrilleGroupePeer::GROUPE_ID, $_GET['groupe'], Criteria::EQUAL);
      if (JGrilleGroupePeer::doDelete($c)){
        $this->setMessage('Groupe d&eacute;li&eacute; !');
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();

      }else{
        $this->setErreurMessage('Impossible de d&eacute;lier ce groupe !');
        $this->redirect_to(array('action'=>'eleves', 'info'=>$this->_params['info']));
        exit();

      }

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  } //delierGroupe()

} 
?>