<?php
/**
 * @version $Id: pdfControleur.php 27 2009-11-13 16:03:31Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of competencesRB.
 *
 * competencesRB is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * competencesRB is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with competencesRB.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Classe qui tend fpdf pour mettre en forme des fichiers pdf
 *
 */


class pdfControleur extends applicationControleur{

  private function _includeFPDF(){
    require 'libexterne/pdf/crb_fpdf.php';
  }

  /**
   * Renvoie un pdf d'un contrle vide
   */
  public function controle(){

    $this->_includeFPDF();

    # On vrifie la validit des informations reues
    $test1 = explode("|", $this->_params['info']);

    if (count($test1) != 3 OR $test1[0] != 'evaluer'){
      echo 'Les donn&eacute;es sont corrompues, impossible d\'afficher ce que vous demandez !';
      logControleur::insertLog('ajax', '1', 'Donnes ajax fausses ($test1) : '.$this->_requete->_id . 'C::'.__CLASS__.'-A::'.__METHOD__, $this->user->getId());
      exit();
    }

    # On vrifie que cet utilisateur possde bien une entre correspondante
    $test2 = GrillePeer::utilisateurUtiliseCetteGrilleEtCeGroupe($this->user, $test1[1], $test1[2]);
    if ($test2 !== false){

      # On peut maintenant construire le pdf
      $pdf = new crbfpdf();
      $pdf->SetAuthor($this->user->getNom().' '.$this->user->getPrenom());
      $pdf->SetCreator('CRB (cl) '.date('Y'));
      $pdf->SetTitle('Grille de comptences');
      $pdf->SetSubject('Evaluation d\'un groupe d\'lves');
      $pdf->SetKeywords('grille competence evaluation controle');
      $pdf->AliasNbPages();
      $pdf->AddPage();
      $pdf->SetFont('Times','',12);

      # Le titre de la grille avec le nom du groupe et une case pour le nom du contrle
      $pdf->Cell(40, 10, 'GRILLE', 1, 0);
      $pdf->Cell(0, 10, html_entity_decode($test2->getGrille()->getNom()), 1, 1);
      $pdf->Cell(40, 10, 'GROUPE', 1, 0);
      $pdf->Cell(0, 10, html_entity_decode($test2->getGroupe()->getNomcourt()), 1, 1);
      $pdf->Cell(40, 10, 'Nom du contrle', 1, 0);
      $pdf->Cell(120, 10, '', 1, 1);

      $pdf->Ln(); // saut de ligne

      # Liste des comptnces C 0 : nom de la comptence
      $iter = 1;
      $criter1 = new Criteria();
      $criter1->addAscendingOrderByColumn(JGrilleCompetencePeer::COMPETENCE_ID);
      foreach ($test2->getGrille()->getJGrilleCompetencesJoinCompetence($criter1) as $cptce) {

        # On vrifie si le nom de la comptence n'est pas trop long
        $nbre_carac = strlen(html_entity_decode($cptce->getCompetence()->getNomcourt()));
        if ($nbre_carac < 100){

          $pdf->Cell(10, 6, 'C '.$iter , 1, 0); // le code de la comptence
          $pdf->Cell(0, 6, html_entity_decode($cptce->getCompetence()->getNomcourt()), 1, 1); // le nom de la comptence

        }elseif ($nbre_carac > 100){

          $pdf->Cell(10, 6, 'C '.$iter , 1, 0); // le code de la comptence
          $pdf->MultiCell(0, 6, html_entity_decode($cptce->getCompetence()->getNomcourt()), 1); // le nom de la comptence

        }
        ++$iter;
      }
      $nbre_cptces = $iter; // le nombre de comptences de cette grille
      $pdf->Ln(); // saut de ligne

      # Dbut de la lgende du tableau
      $pdf->Cell(70, 10, 'Liste lves', 1);

      $iter = 1;
      $larg_cel = $nbre_cptces > 13 ? 5 : 10; // largeur par dfaut = 10 sinon 5
      $lettre_c = $nbre_cptces > 13 ? '' : 'C '; // Pour gagner de la place, on enlve la lettre
      foreach ($test2->getGrille()->getJGrilleCompetencesJoinCompetence($criter1) as $cptce) {

        $pdf->Cell($larg_cel,10,$lettre_c.$iter,1,0);
        ++$iter;
      } // fin de la lgende du tableau

      # Dbut du tableau -> ELEVE C0 C1 C2 C3...

      $pdf->SetFillColor('225'); // fixe le niveau de gris (225 est un gris trs clair)

      $bool = true;
      $criter2 = new Criteria();
      $criter2->addAscendingOrderByColumn(UtilisateurPeer::NOM);
      $criter2->addAscendingOrderByColumn(UtilisateurPeer::PRENOM);
      $pdf->SetFont('Times','',10); // On utilise une police plus petite
      foreach ($test2->getGroupe()->getJGroupeElevesJoinUtilisateur($criter2) as $eleve) {
        $pdf->Ln();

        $pdf->Cell(70, 7, html_entity_decode($eleve->getUtilisateur()->getNom()) . ' ' . html_entity_decode($eleve->getUtilisateur()->getPrenom()), 1, 0, 'R', $bool);

        foreach ($test2->getGrille()->getJGrilleCompetencesJoinCompetence($criter1) as $cptce) {
          $pdf->Cell($larg_cel, 7, '', 1, 0, 'L', $bool); // liste des cases vides pour cet lve
        }

        if ($bool === true){$bool = false;}else{$bool = true;} // permet d'alterner une ligne blanche, une ligne grise

      }

      # On envoie le pdf au client
      $pdf->Output();

    }else{
      echo 'Les donn&eacute;es sont fausses, impossible d\'afficher ce que vous demandez !';
      logControleur::insertLog('pirate', '1', 'Utilisateur tente sur Grille/groupe pas  lui (pdf) : '.$this->_params['info'] . 'C::'.__CLASS__.'-A::'.__METHOD__, $this->user->getId());
      exit();
    }
    exit(); // Dans tous les cas, on arrte le script

  } // controle()

  /**
   * Renvoie un pdf d'une grille vide
   */
  public function grille(){

    $this->_includeFPDF();

    # On rcupre les informations ncessaires au bulletin
    $grilleId = (int)$this->_params['info'];

    if (is_numeric($grilleId)){

      $grille = GrillePeer::retrieveByPK($grilleId);
      # On vrifie que cet utilisateur possde bien cette grille
      if ($this->user->getId() != $grille->getUtilisateurId()){
        logControleur::insertLog('pirate', 2, 'Grille pas a lui : '.$grille, $this->user->getId());
        $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
      }

      # On peut gnrer la grille maintenant
      # La mthode retenue est un ensemble de cases vides coorespondant qux niveaux de validation  la fin  droite
      $niveauValidation = ValidationNiveauPeer::listeNiveauxValidation();
      # On peut maintenant construire le pdf
      $pdf = new crbfpdf('P', 'mm', 'A4');
      $pdf->SetAuthor($this->user->getNom().' '.$this->user->getPrenom());
      $pdf->SetCreator('CRB (cl) '.date('Y'));
      $pdf->SetTitle('Grille');
      $pdf->SetSubject('Grille d\'valuation');
      $pdf->SetKeywords('grille competence evaluation controle bulletin');
      $pdf->AliasNbPages();
      $pdf->AddPage();
      $pdf->SetFont('Times','',10);

      foreach ($grille->getJGrilleCompetencesJoinCompetence() as $joinCptce) {

        $pdf->MultiCell(150, 8, html_entity_decode($joinCptce->getCompetence()->getNomcourt(), ENT_QUOTES), 1, 1, 0);
        $y = $pdf->GetY();
        $pdf->SetXY(-50, $y - 8);
        foreach ($niveauValidation as $cle => $valeur) {
          $pdf->Cell(10, 8, strtoupper($cle), 1, 0, 'C');
        }
        $pdf->Ln();
        
      }


      # On envoie le pdf au client
      $pdf->Output('grille_'.$grille->getId().'_'.date("dmY").'.pdf', 'I');
      exit();

    }else{
      $this->dehorsUtilisateur('', __CLASS__, __METHOD__, $this->user->getId());
    }

  } // grille()

  public function editerBulletin(){

    $this->_includeFPDF();

    # On rcupre les informations ncessaires au bulletin
    $bulletinId = (int)$this->_params['info'];
    # On regarde si on les demande en couleur ou en noir et blanc
    $couleur = (isset($_GET['couleur']) AND $_GET['couleur']) == 'nb' ? false : true;

    if (is_numeric($bulletinId)){
      # Le bulletin
      $bul = BulletinPeer::retrieveByPK($this->_params['info']);
      $bul->getAppreciations();
      # On peut maintenant construire le pdf
      $pdf = new crbfpdf('P', 'mm', 'A4');
      $pdf->SetAuthor($this->user->getNom().' '.$this->user->getPrenom());
      $pdf->SetCreator('CRB (cl) '.date('Y'));
      $pdf->SetTitle('Bulletin');
      $pdf->SetSubject('Bulletin d\'un lve');
      $pdf->SetKeywords('grille competence evaluation controle bulletin');
      $pdf->AliasNbPages();
      $pdf->AddPage();
      $pdf->SetFont('Times','B',12);
      # On inscrit le nom du bulletin
      $pdf->Cell(80, 10, $bul->getNom() . "\n" . ' ('.date("d/m/Y", $bul->getDebut()).' au '.date("d/m/Y", $bul->getFin()).' )', 0, 0);
      $pdf->Cell(10, 10, '', 0, 0);
      $pdf->SetFont('Times','',12);

      $ColorValidation = ValidationNiveauPeer::listeNiveauxValidation('color');
      $texteValidation = ValidationNiveauPeer::listeNiveauxValidation();

      # On commence par les comptences transversales si elles existes (on ordonne simplement celles l en premier)
      # On les ordonne par ordre alphabtique des matires enseignes
      $c = new Criteria();
      $c->addAscendingOrderByColumn(AppreciationPeer::TRANSVERSALE);
      $c->addJoin(AppreciationPeer::PROFESSEUR_ID, UtilisateurPeer::ID);
      $c->addJoin(UtilisateurPeer::MATIERE_ID, MatierePeer::ID);
      $c->addAscendingOrderByColumn(MatierePeer::NOMLONG);

      $marqueur = true;
      $_ident = '';
      foreach ($bul->getAppreciations($c) as $apprec) {
        if ($apprec->getEleveId() == $_GET['eleve']){
          # Le nom, prnom, adresse de l'lve
          if ($marqueur === true){
            # C'est le premier passage, on insre les informations sur l'lve
            $_ident = html_entity_decode($apprec->getUtilisateurRelatedByEleveId()->getNom() . ' ' . $apprec->getUtilisateurRelatedByEleveId()->getPrenom());
            # L'adresse de l'lve
            /**
             * @todo :  terminer pour insrer la vrais adresse de l'lve et/ ou de ses parents
             */
            $pdf->MultiCell(80, 10, $_ident."\n".'('.$apprec->getUtilisateurRelatedByEleveId()->getClasse()->getNom().')', 1, 'C');
            $pdf->Cell(0, 5, '', 0, 1);

            $marqueur = false;
          }
          // On remet une criture assez grande
          $pdf->SetFont('Times','',12);
          # le professeur en vrifiant si c'est une apprciation transversale ou pas
          if ($apprec->getTransversale() == 'O'){
            $aff_appreciation = html_entity_decode('Bilan g&eacute;n&eacute;ral');
            $pdf->SetFillColor(210);
            $aff_color = true;
          }else{
            $pdf->SetFillColor(240);
            $aff_appreciation = $apprec->getUtilisateurRelatedByProfesseurId()->getMatiere()->getNomlong();
            $aff_color = true;
          }
          $prof = html_entity_decode($aff_appreciation."\n".' (' . $apprec->getUtilisateurRelatedByProfesseurId()->getCivilite() .' '. $apprec->getUtilisateurRelatedByProfesseurId()->getNom() .')');
          $pdf->Cell(90, 10, $prof, 'LT', 1, 'L', $aff_color);
          # L'apprciation de ce professeur
          $pdf->SetFont('Times','',10);
          $pdf->SetLineWidth(0.5);
          $pdf->MultiCell(0, 5, html_entity_decode($apprec->getContenu()), 1, 'J');
          $pdf->SetLineWidth(0.2);

          # On ajoute les bilans lis  cette apprciation
          foreach ($apprec->getJAppreciationBilans() as $join) {
            //$c = new Criteria();
            //$c->add(BilanPeer::ID, $join->getBilanId());
            $bilan = $join->getBilan(); //BilanPeer::doSelect($c);
            $pdf->Cell(8, 8, '', 0, 0);
            $pdf->SetFont('Times', 'I', 8);

            # On vrifie si on les veut en noir et blanc ou en couleur
            if ($couleur){

              $aff_3pts = (substr(html_entity_decode($bilan->getNom()), 150, 160) != '') ? '[...]' : NULL;
              $pdf->Cell(176, 6, substr(html_entity_decode($bilan->getNom()), 0, 150).$aff_3pts, 1, 0, 'L', false);
              $rgb = ValidationNiveauPeer::convertirHexadecimalToRgb(substr($ColorValidation[$bilan->getResultat()], 1));
              $pdf->SetFillColor($rgb[0], $rgb[1], $rgb[2]);
              $pdf->Cell(6, 6, $bilan->getResultat(), 1, 1, 'C', true);

            }else{

              $nbrecel  = count($ColorValidation); // le nombre de cellules correspondants aux niveaux de validation
              $largeur  = 182 - (($nbrecel - 1) * 6); // On enlve l'absence
              $aff_3pts = (substr(html_entity_decode($bilan->getNom()), 132, 140) != '') ? '[...]' : NULL;
              $pdf->Cell($largeur, 6, substr(html_entity_decode($bilan->getNom()), 0, 132).$aff_3pts, 1, 0, 'L', false);

              # on construit alors les petits carrs du fond avec le bon en gris
              $iter = 1;
              foreach ($texteValidation as $cle => $valid) {
                $pdf->SetLineWidth(0.2); // pour tre certain de rester sur cette paisseur de trait
                $alaligne = ($iter == $nbrecel) ? 1 : 0;
                if ($cle == $bilan->getResultat() AND $cle != 'a'){
                  $pdf->SetFillColor(180);
                  $pdf->Cell(6, 6, $cle, 1, $alaligne, 'C', true);
                }elseif($cle != 'a'){
                  $pdf->SetLineWidth(0.1);
                  $pdf->SetTextColor(150);
                  $pdf->Cell(6, 6, $cle, 1, $alaligne, 'C', false);
                }
                $pdf->SetTextColor(0);
                ++$iter;
              }

            }

          }
          # On saute deux lignes et on recommence  moins que ce ne soit termin
          $pdf->Cell(0, 5, '', 0, 1); // Pour laisser un espace entre deux apprciations

        }
      } // foreach ($bul->getAppreciations($c) as $apprec) {

      $pdf->Cell(0, 8, '', 0, 1);
      # Avant d'envoyer le bulletin, on ajoute une lgende sur les couleurs
      $pdf->SetFont('Times','',8);
      $deb = 0;
      foreach($ColorValidation as $cle => $valeur){

        if ($cle != 'a'){
          ++$deb;
          $rgb = ValidationNiveauPeer::convertirHexadecimalToRgb(substr($valeur, 1));
          $pdf->SetFillColor($rgb[0], $rgb[1], $rgb[2]);
          $aff_couleurs = $couleur ? true : false;
          $pdf->Cell(6, 6, $cle, 1, 0, 'C', $aff_couleurs);
          $pdf->Cell(42, 6, html_entity_decode($texteValidation[$cle]), 0, 0);
        }

      }

      # On envoie le pdf au client
      $pdf->Output('bulletin_'.str_replace(' ', '_', $_ident).'_'.date("dmY").'.pdf', 'I');
      exit();
    }else{
      echo 'Les donn&eacute;es sont fausses, impossible d\'afficher ce que vous demandez !';
      logControleur::insertLog('pirate', '1', 'Utilisateur tente sur Grille/groupe pas  lui (pdf) : '.$this->_params['info'] . 'C::'.__CLASS__.'-A::'.__METHOD__, $this->user->getId());
      exit();
    }

  }

}

?>