<?php
/**
 * @version $Id: form.class.php 2 2009-10-25 12:25:37Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of stats18.
 *
 * stats18 is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * stats18 is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with stats18.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 * You should have received a copy of the GNU General Public License
 * along with superGepi.  If not, see <http://www.gnu.org/licenses/>.
 *
 * 
 *
 */

/**
 *
 */
class formulaireHtml {

  /**
   * @var string tag html
   */
  protected $_tag = 'input';

  /**
   * @var string type de tag
   */
  protected $_type = 'text';

  /**
   * @var string name du tag
   */
  protected $_name = 'data[]';

  /**
   * @var string value du tag
   */
  protected $_value = '';

  /**
   * @var string class du tag html
   */
  protected $_class = NULL;

  /**
   * Mise en forme des champs du formulaire
   * r = aucune balise particulire
   * p = chaque champ est encadr par des balises <p>
   *
   * @var string p,...
   */
  protected $_forme = 'r';

  /**
   * @var string identifiant unique du tag html
   */
  protected $_id = 'id';

  /**
   * @var string name du tag <form>
   */
  protected $_nameform = NULL;

  /**
   * @var string path de l'application
   */
  protected $_path = NULL;

  /**
   * @var string module a appeler dans l'url
   */
  protected $_moduleform = NULL;
    /**
   * @var string controleur  appeler dans l'url
   */
  protected $_controleurform = NULL;
  /**
   * @var string action  appeler dans l'url
   */
  protected $_actionform = NULL;

    /**
   * @var string info  faire suivre dans l'url
   */
  protected $_infoform = '#';

  /**
   * @var string methode du tag <form>
   */
  protected $_methodform = 'post';

  /**
   * @var string id du tag <form>
   */
  protected $_idform = NULL;

  /**
   * @var string Le formulaire est construit dans cet attribut
   */
  private $_form = NULL;

  /**
   * itrateur pour les attributs name des tags html
   *
   * @var integer gal  zro au dpart
   */
  private $_iter = 0;

  /**
   * Constructeur de la classe
   *
   * @param array $options tableau des informations ncessaires  la cration du tag <form>
   * @param array $params Module, controleur, action et info de base
   */
  public function  __construct(array $options, array $params) {
    if (!is_array($options)){
      throw new Exception('Attention, il manque des informations pour construire le formulaire.');
    }else{
      if (array_key_exists('method', $options))     {$this->_methodform = $options["method"];}
      if (array_key_exists('module', $options))     {$this->_moduleform = $options["module"];}else{$this->_moduleform = $params["module"];}
      if (array_key_exists('controleur', $options)) {$this->_controleurform = $options["controleur"];}else{$this->_controleurform = $params["controleur"];}
      if (array_key_exists('action', $options))     {$this->_actionform = $options["action"];}else{$this->_actionform = $params["action"];}
      if (array_key_exists('info', $options))       {$this->_infoform = $options["info"];}else{$this->_infoform = $params["info"];}
      if (array_key_exists('name', $options))       {$this->_nameform   = $options["name"];}
      if (array_key_exists('id', $options))         {$this->_idform     = $options["id"];}
      if (array_key_exists('forme', $options))      {$this->_forme      = $options["forme"];}
      $this->_path = $params["path"];

      $this->openForm($options);
    }
  }

  /**
   * Ajoute la balise d'entre de formulaire <form ...>
   *
   * @param array $options tableaux des informations de cration du tag <form>
   */
  private function openForm(array $options){
    $aff_id   = (!is_null($this->_idform)) ? ' id="'.$this->_idform.'"' : NULL;
    $aff_name = (!is_null($this->_nameform)) ? ' name="'.$this->_nameform.'"' : NULL;
    $module   = !is_null($this->_moduleform) ? '/'.$this->_moduleform : NULL;
    $action   = $this->_path.$module.'/'.$this->_controleurform.'/'.$this->_actionform.'/'.$this->_infoform;

    $_enctype = (array_key_exists('enctype', $options)) ? ' enctype="'.$options['enctype'].'"' : NULL;

    $this->_form = ('<form method="' . $this->_methodform . '"'.$_enctype.' action="'.$action.'"'.$aff_id.$aff_name.'>'."\n");

  }

  /**
   * Ferme le formulaire par la balise </form>
   */
  private function closeForm(){
    $this->_form .= '</form>'."\n";
  }

  /**
   * Renvoie la forme des champs du formulaire : dans un paragraphe ou pas
   *
   * @return string $po ou $pf
   */
  private function getBaliseOuvranteFermante($ouvranteOuFermante){

    $po = $pf = '';

    if ($this->_forme == 'p'){
      $po = '<p>';
      $pf = '</p>';
    }elseif($this->_forme == 'td'){
      $po = '<td>';
      $pf = '</td>';
    }

    if ($ouvranteOuFermante == 'o'){
      return $po;
    }elseif($ouvranteOuFermante == 'f'){
      return $pf;
    }

  }

  /**
   * Insre une balise <input />
   *
   * @param array $options Permet de dfinir des valeurs diffrentes de celles par dfaut pour cet input type, name, value, id, label
   */
  public function addInput(array $options){

    $_type    = (array_key_exists('type', $options)) ? $options["type"] : $this->_type;
    $_name    = (array_key_exists('name', $options)) ? $options["name"] : $this->_name;
    $_value   = (array_key_exists('value', $options)) ? $options["value"] : $this->_value;
    $_title   = (array_key_exists('title', $options)) ? ' title="'.$options["title"].'"' : NULL;
    $_style   = (array_key_exists('style', $options)) ? ' style="'.$options["style"].'"' : NULL;
    $_class   = (array_key_exists('class', $options)) ? ' class="'.$options["class"].'"' : NULL;
    $_lclass  = (array_key_exists('labelclass', $options)) ? ' class="'.$options["labelclass"].'"' : NULL;
    $_id      = (array_key_exists('id', $options)) ? $options["id"] : $this->_id.$_name;
    $_label   = (array_key_exists('label', $options)) ? '<label'.$_lclass.$_title.' for="'.$_id.'">'.$options["label"].'</label>' : NULL;
    $_checked = (array_key_exists('checked', $options) AND $options["checked"] == 'on') ? ' checked="checked"' : NULL;
    $_size    = (array_key_exists('size', $options)) ? ' size="'.$options["size"].'"' : NULL;
    $_multi   = (array_key_exists('multiple', $options)) ? '[]' : NULL;
    $_js      = (array_key_exists('js', $options)) ? ' '.$options["js"] : NULL;

    $this->_form .= $this->getBaliseOuvranteFermante("o") . $_label . "\n";
    $this->_form .= '<input type="' . $_type . '" name="' . $this->_nameform .'[' . $_name . ']' . $_multi . '" value="' . $_value . '" id="'.$_id.'"'.$_title.$_js.$_checked.$_size.$_style.$_class.' />'."\n";
    $this->_form .= $this->getBaliseOuvranteFermante("f");

  }

  /**
   * Insre une balise select, ses options et sa balise fermante
   *
   * @param array $infos_select Liste des informations du select
   * @param array $infos_options Liste des options du select sous la forme (value = $key)
   */
  public function addSelect(array $options, array $infos_options){

    $_name      = (array_key_exists('name', $options)) ? $options["name"] : $this->_name;
    $_id        = (array_key_exists('id', $options)) ? $options["id"] : $this->_id.$_name;
    $_lclass    = (array_key_exists('labelclass', $options)) ? ' class="'.$options["labelclass"].'"' : NULL;
    $_label     = (array_key_exists('label', $options)) ? '<label'.$_lclass.' for="'.$_id.'">'.$options["label"].'</label>' : NULL;
    $_title     = (array_key_exists('title', $options)) ? ' title="'.$options["title"].'"' : NULL;
    $_class     = (array_key_exists('class', $options)) ? ' class="'.$options["class"].'"' : NULL;
    $_selected  = (array_key_exists('selected', $options)) ? $options["selected"] : NULL;
    $_disabled  = (array_key_exists('disabled', $options)) ? ' disabled="disabled"' : NULL;
    $_multiple  = (array_key_exists('multiple', $options)) ? ' multiple="multiple"' : NULL;
    $_affMulti  = !is_null($_multiple) ? '[]' : NULL;
    $_js        = (array_key_exists('js', $options)) ? ' '.$options["js"] : NULL;
    $_limiter   = (array_key_exists('limite', $options)) ? $options["limite"] : NULL;
    $aff_title  = NULL;

    $this->_form .= $this->getBaliseOuvranteFermante("o") . $_label . "\n";
    $this->_form .= '<select'.$_class.' name="' . $this->_nameform .'[' . $_name . ']'.$_affMulti.'" id="'.$_id.'"'.$_multiple.$_title.$_disabled.$_js.'>'."\n";
    foreach ($infos_options as $key => $valeur) {
      $aff_selected = ($key == $_selected) ? ' selected="selected"' : NULL;
      # Si c'est demand, on limite le nombre de caractres  afficher
      if (!is_null($_limiter)){
        if (strlen($valeur) > $_limiter){
          $aff_title = ' title="'.$valeur.'"';
          $valeur = substr($valeur, 0, $_limiter).' ...';
        }else{
          $aff_title = ' title="'.$valeur.'"';
        }
      }
      $this->_form .= '<option value="'. $key .'"'.$aff_selected.$aff_title.'>'. $valeur .'</option>'."\n";
    }
    $this->_form .= '</select>'."\n";
    $this->_form .= $this->getBaliseOuvranteFermante("f");

  }

  public function addTextArea($options = array()){

    $_name    = (array_key_exists('name', $options)) ? $options["name"] : $this->_name;
    $_value   = (array_key_exists('value', $options)) ? $options["value"] : $this->_value;
    $_title   = (array_key_exists('title', $options)) ? ' title="'.$options["title"].'"' : NULL;
    $_style   = (array_key_exists('style', $options)) ? ' style="'.$options["style"].'"' : NULL;
    $_class   = (array_key_exists('class', $options)) ? ' class="'.$options["class"].'"' : NULL;
    $_lclass  = (array_key_exists('labelclass', $options)) ? ' class="'.$options["labelclass"].'"' : NULL;
    $_id      = (array_key_exists('id', $options)) ? $options["id"] : $this->_id.$_name;
    $_label   = (array_key_exists('label', $options)) ? '<label'.$_lclass.' for="'.$_id.'">'.$options["label"].'</label>' : NULL;
    $_size    = (array_key_exists('size', $options)) ? ' size="'.$options["size"].'"' : NULL;

    $this->_form .= $this->getBaliseOuvranteFermante("o") . $_label . "\n";
    $this->_form .= '<textarea name="' . $this->_nameform .'[' . $_name . ']" id="'.$_id.'"'.$_title.$_size.$_style.$_class.'>' . $_value . '</textarea>'."\n";
    $this->_form .= $this->getBaliseOuvranteFermante("f");
  }

  /**
   * Ouvre une balise fieldset en prcisant sa lgende
   *
   * @param array $options id, class, legend
   */
  public function openFieldset($options = array()){

    $class  = (array_key_exists('class', $options)) ? ' class="'.$options["class"].'"' : NULL;
    $id     = (array_key_exists('id', $options)) ? ' id="'.$options["id"].'"' : NULL;
    $legend = (array_key_exists('legend', $options)) ? '  <legend>'.$options["legend"].'</legend>'."\n" : NULL;

    $this->_form .= '<fieldset'.$class.$id.'>'."\n";
    $this->_form .= $legend;

  }

  /**
   * Ferme la balise fieldset dj ouverte
   */
  public function closeFieldset(){
    $this->_form .= '</fieldset>'."\n";
  }

  /**
   * Ajoute un saut de ligne xhtml
   */
  public function addBr(){
    $this->_form .= '<br />'."\n";
  }

  /**
   * crit le tag appel (penser  fermer les balises)
   *
   * @param string $tag table, /table, tr, /tr
   */
  public function addTag($tag, $options = array()){

    $autorise = array('table', '/table', 'tr', '/tr', 'td', '/td');

    $_class   = (array_key_exists('class', $options)) ? ' class="'.$options["class"].'"' : NULL;

    if (!in_array($tag, $autorise)){
      return 'Impossible de lancer ce tag html ici !';
    }

    $this->_form .= '<'.$tag.$_class.'>'."\n";

  }

  /**
   * Intgre du texte dans le formulaire
   *
   * @param string $texte
   * @return string ERREUR
   */
  public function addLegende($texte){
    if (!is_string($texte)){
      return 'Impossible d\'afficher ce texte';
    }
    $this->_form .= $texte;
  }

  /**
   * Affiche par un echo le formulaire termin
   */
  public function returnForm(){
    $this->closeForm();

    return $this->_form;
  }

}
?>
