<?php
/**
 * @version $Id: applicationControleur.php 41 2009-11-25 11:32:59Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of miniFramework.
 *
 * miniFramework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * miniFramework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with miniFramework.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

/**
 * L'applicationControleur est destine  tre tendu par tous les controleurs de l'application pour servir d'API
 *  ces controleurs
 *
 * @author jjocal
 */
class applicationControleur {

  /**
   * Titre de la page renvoye au navigateur <title>
   * @var string titre
   */
  public $_title = "Titre en attente";

  /**
   * Titre de l'application utilisable dans la page (header ou ailleurs)
   * @var string Titre affich
   */
  public $_titre = "Application";

  /**
   * Permet de stocker un formulaire pour la vue
   * @var object formHelper
   */
  public $form = NULL;

  /**
   * Informations sur l'utilisateur rcupres dans la session si il y a authentifictaion ou sur un cookie
   * @var array $_SESSION["user"]
   */
  public $user = NULL;

  /**
   * Format de la rponse  envoyer au client
   * @var string Par dfaut gal  html
   */
  protected $_modeSortie = 'html';

  /**
   * Ensemble des informations sur le module, le controleur, l'action, la vue, l'info et le path de la requte
   * @var array tableau des paramtres de la requte
   */
  public $_params = array();

  /**
   * Toutes les informations sur la mthode (get, post, put, delete) et les paramtres de la requte ($_POST, $_GET).
   * @var object requeteControleur
   */
  protected $_requete = NULL;

  /**
   * Nom du layout  utiliser pour la rponse au client
   * @var string Par dfaut 'base'
   */
  protected $_layout = 'base';

  /**
   * Texte disponible pour la vue
   * @var string Tete pass  la vue
   */
  protected $_texte = NULL;

  /**
   * Tableau de textes disponible pour la vue
   * @var <type> Tableau de textes pass  la vue
   */
  protected $_arrayTexte = array();

  /**
   * Nom de la vue renvoye au client (disponible pour le frontControleur).
   * @var string Nom de la vue
   */
  protected $_vue = NULL;

  /**
   * Message d'erreur disponible pour la vue
   * @var string Message
   */
  protected $_erreurMessage = NULL;

  /**
   * Message transmis  la vue
   * @var string message
   */
  protected $_msg = NULL;

  /**
   * Texte d'aide diponible pour la vue
   *
   * @var string texte en html
   */
  protected $_aideMessage = 'Aucune aide disponible pour cette page &agrave; ce jour !';

  /**
   * Pour dterminer si la page / l'application ncessitent d'tre authentifier.
   * @var boolean true/false, false par dfaut.
   */
  protected $_auth = false;

  /**
   * Ensemble des informations de la table settings
   *
   * @var array settings
   */
  protected $_settings = NULL;

  /**
   * Liste des droits pour le controleur actif, cette liste ne correspond pas forcment avec la seule liste des mthodes de la classeControleur
   *
   * @var array tableau des actions autorises pour le role de l'utilisateur
   */
  protected static $_droits = array();

  /**
   * Le constructeur reoit les informations sur la requte html, les paramtres de celle-ci et la demande globale
   * pour l'authentifictaion au niveau de l'application.
   *
   * @param object requeteControleur $r
   * @param array $params
   * @param boolean $auth
   */
  public function  __construct(requeteControleur $r, array $params, $auth) {

    $this->_requete = $r;
    $this->_params  = $params;
    $this->_auth    = $auth;
    $this->_vue     = $params["vue"];

    // Si la session existe, on initialise la proprit user
    $this->user = (isset($_SESSION["user"])) ? $_SESSION["user"] : array();

    // On initialise le message d'erreur s'il existe
    $__errore = isset($_SESSION["erreurMsg"]) ? $_SESSION["erreurMsg"] : NULL;
    $this->setMessageErreur($__errore);
    $_SESSION["erreurMsg"] = NULL;
    # On initialise le message autre que celui d'erreur ici
    $__errore = isset($_SESSION["Msg"]) ? $_SESSION["Msg"] : NULL;
    $this->setMessageS($__errore);
    $_SESSION["Msg"] = NULL;
    $this->setSettings();

    $this->_titre = $this->getSettings('titre');
    $this->_title = $this->getSettings('title');

    $this->verifDroits($params['action']);

    // On lance la mthode appele en action
    if (!method_exists($this, $params['action'])){
      logControleur::insertLog('url', 2, 'action inexistante : '.$params['action'], $this->user->getId());
      echo 'Cette action n\'est pas disponible actuellement !';
      exit();
    }
    $this->{$params['action']}();

  }

  /**
   * Teste les droits et autorise ou non la poursuite du script
   *
   * @param string $action nom de l'action demande
   * @return bollean true or exit
   */
  protected function verifDroits($action){

    if ($this->verifDroitsSansVirer($action) === true){
      return true;
    }else{
      logControleur::insertLog('droits', 2, 'Pas le droit suffisant::M'.$this->_params["module"].'::C'.$this->_params["controleur"].'::A'.$action, $this->user->getId());
      authControleur::logout();
      $this->redirect_to(array('controleur'=>'login', 'action'=>'index', 'info'=>'bad'));
      exit();
    }

  }

  /**
   * Charge et/ou analyse les droits du controleur pour ce role
   *
   * @param string $action nom de l'action demande
   * @return boolean true or false
   */
  protected function verifDroitsSansVirer($action){

    // Si la session n'est pas initialis, on ne vrifie pas les droits car la session renvoie sur la page de login.
    // Donc le controleur login n'est pas vrifi car tout le monde doit pouvoir y avoir accs
    if (!isset($_SESSION["user"]) OR $this->_params["controleur"] == 'login' OR ($this->user->getRole()->getNom() == 'superadmin')){
      return true;
    }else{
      // Sinon on charge tous les droits de ce module, ce controleur et ce role
      self::chargeLesDroitsEnStatique($this->_params["module"], $this->_params["controleur"], $this->user->getRoleId());
    }

    if (in_array($action, self::$_droits)){
      return true;
    }else{
      return false;
    }

  }

  /**
   * Charge la liste des actions autorises pour ce role sur ce module et ce controleur
   *
   * @param string $module
   * @param string $controleur
   * @param integer $roleIdUser
   * @return array Liste des actions autorises pour cet utilisateur
   */
  private static function chargeLesDroitsEnStatique($module, $controleur, $roleIdUser){

    if (empty (self::$_droits)){
      $cr = new Criteria();
      $cr->add(droitPeer::ROLE_ID, $roleIdUser, Criteria::EQUAL);
      if (!is_null($module)){
        $cr->add(droitPeer::MODULE, $module, Criteria::EQUAL);
      }
      $cr->add(droitPeer::CONTROLEUR, $controleur, Criteria::EQUAL);

      $test = droitPeer::doSelect($cr);
      $tab = array();
      foreach ($test as $droit) {
        $tab[]= $droit->getAction();
      }
      self::$_droits = $tab;
    }else{
      return true;
    }

  }

  /**
   * Dconnecte un utilisateur en insrant un log 'droits'
   *
   * @param string $module
   * @param string $controleur
   * @param string $action
   * @param int $userId 
   */
  public function dehorsUtilisateur($module, $controleur, $action, $userId){
    logControleur::insertLog('droits', 2, 'url modifie et pas le droit suffisant::M'.$module.'::C'.$controleur.'::A'.$action, $userId);
      authControleur::logout();
      $this->redirect_to(array('controleur'=>'login', 'action'=>'index', 'info'=>'bad'));
      exit();
  }

  /**
   * Charge la proprit _settings de la classe avec toutes les entres de la table settings
   *
   * @return boolean true
   */
  public function setSettings(){
    if (!is_array($this->_settings)){
      $c = new Criteria();
      $c->addAscendingOrderByColumn(SettingPeer::NOM);
      $retour = SettingPeer::doSelect($c);

      $this->_settings = $retour;
      return true;
    }else{
      return true;
    }
  }

  /**
   *
   * @param string $reglage
   * @return string valeur du $reglage
   */
  public function getSettings($reglage){
    foreach ($this->_settings as $setting) {
      if ($setting->getNom() == $reglage){
        return $setting->getValeur();
      }
    }
    return '<span class="red italic">' . $reglage . ' doit &ecirc;tre d&eacute;fini dans les r&eacute;glages</span>';
  }

  public function getTexte(){
    return $this->_texte;
  }
  public function getArrayTexte(){
    return $this->_arrayTexte;
  }
  public function getModeSortie(){
    return $this->_modeSortie;
  }
  public function getLayout(){
    return $this->_layout;
  }

  public function getVue(){

    include 'www/layout/' . $this->getLayout() . '.haut.php';
    $module = (!is_null($this->_params["module"])) ? '/'.$this->_params["module"] : NULL;
    include 'app' . $module . '/vues/'.$this->_vue . ucfirst($this->_params["controleur"]) .'.vue.php';
    include 'www/layout/' . $this->getLayout() . '.bas.php';

  }


  /**
   * Insre un lien html
   *
   * @param array $options module, controleur, action, info, intitule, js et get => array()
   * @return string tag html a
   */
  public function tag_a($options = array()){

    $module     = array_key_exists('module', $options) ? '/'.$options["module"] : (!is_null($this->_params["module"]) ? '/'.$this->_params["module"] : NULL);
    $controleur = array_key_exists('controleur', $options) ? '/'.$options["controleur"] : '/'.$this->_params["controleur"];
    $action     = array_key_exists('action', $options) ? '/'.$options["action"] : '/'.$this->_params["action"];
    $info       = array_key_exists('info', $options) ? '/'.$options["info"] : '/-';
    $intitule   = array_key_exists('intitule', $options) ? $options["intitule"] : 'Lien';
    $js         = array_key_exists('js', $options) ? ' '.$options["js"] : NULL;
    $title      = array_key_exists('title', $options) ? ' title="'.$options["title"].'"' : NULL;
    $get        = array_key_exists('get', $options) ? $options["get"] : NULL;
    $aff_get    = NULL;

    // $get permet d'ajouter des infos en get  l'url
    if (!is_null($get)){
      if (!is_array($get)){
        throw new Exception("les donnes en get pour le formulaire dovent tre intgres dans un tableau !");
      }else{
        $aff_get = '?';
        foreach ($get as $cle => $valeur){
          $aff_get .= $cle . '=' . $valeur .'&';
        }
      }
    }

    return '<a href="http://'.$_SERVER["HTTP_HOST"].$this->_params["path"].$module.$controleur.$action.$info.substr($aff_get, 0, -1).'"'.$js.$title.'>'.$intitule.'</a>';
  }

  /**
   * Ajoute un tag html sous la forme d'un paragraphe en rouge du message d'erreur
   *
   * @param string $msg Le message d'erreur
   * @return string message d'erreur sous balise p en rouge
   */
  private function setMessageErreur($msg){
    if ($msg != ''){
      $this->_erreurMessage = '<p id="idMessKo" class="red divko moz"><img src="'.$this->_params['path'].'/www/images/erreur1.png" />'.$msg.'</p>';
    }
  }
  private function setMessageS($msg){
    if ($msg != ''){
      $this->_msg = $msg;
    }
  }

  /**
   * Charge en session le message d'erreur
   *
   * @param string $msg Le message d'erreur
   * @return string message d'erreur sous balise p en rouge
   */
  protected function setErreurMessage($msg){

      $_SESSION['erreurMsg'] .= $msg;

  }

  /**
   * Charge le message pour la vue
   * @param string $msg message
   */
  protected function setMessage($msg){
    $_SESSION['Msg'] = $msg;
  }
  /**
   * Renvoie le message dans la vue s'il n'est pas NULL.
   *
   * @return string message dans un paragraphe en vert (ou rien si _msg est NULL
   */
  public function getMessage(){
    if (!is_null($this->_msg)){
      return '<p id="idMessOk" class="green divok moz"><img src="'.$this->_params['path'].'/www/images/valider.png" />'.$this->_msg.'</p>';
    }else{
      return '<p id="idMessOk" style="display:none;">&nbsp;</p>';
    }
  }
  /**
   * Redirige l'utilisateur avec la fonction php header()
   *
   * @param array $options module, controleur, action, info
   */
  protected function redirect_to($options = array()){
    $module     = array_key_exists('module', $options) ? '/'.$options["module"] : ((!is_null($this->_params["module"])) ? '/'.$this->_params["module"] : NULL);
    $controleur = array_key_exists('controleur', $options) ? '/'.$options["controleur"] : ((!is_null($this->_params["controleur"])) ? '/'.$this->_params["controleur"] : NULL);
    $action     = array_key_exists('action', $options) ? '/'.$options["action"] : ((!is_null($this->_params["action"])) ? '/'.$this->_params["action"] : NULL);
    $info       = array_key_exists('info', $options) ? '/'.$options["info"] : ((!is_null($this->_params["info"])) ? '/'.$this->_params["info"] : '/');
    $get        = array_key_exists('get', $options) ? 'oui' : NULL;
    if ($get == 'oui'){
      $get = '?';
      foreach ($options['get'] as $cle => $valeur) {
        $get .= $cle.'='.$valeur.'&';
      }
    }

    header("Location:http://".$_SERVER["HTTP_HOST"].$this->_params['path'].$module.$controleur.$action.$info.$get);
    Die();
  }

  /**
   * Met en forme l'aide
   *
   * @return <type> Un div dont l'id est aide et le contenu $this->_aideMessage
   */
  public function afficheAide(){
    $retour = '
    <span class="lien" id="affAideDiv" title="Cliquez pour faire appara&icirc;tre ou dispara&icirc;tre l\'aide">
      <img src="'.$this->_params['path'].'/www/images/info.png" alt="aide" /></span>
    <div id="aideDiv" style="display:none;">
      '.$this->_aideMessage.'
    </div>
    ';

    return $retour;
  }

  /**
   * Affiche les deux tableaux php envoys en paramtres ainsi que l'objet requete et le tableau $params
   *
   * @param array $array1
   * @param array $array2
   */
  public function affDebug($array1 = array(), $array2 = array()){

    echo '<html>
            <head>
              <title> -- Application DEBUG -- </title>
              <script type="text/javascript" src="'.$this->_params["path"].'/www/javascript/prototype.js"></script>
              <script type="text/javascript" src="'.$this->_params["path"].'/www/javascript/fonctions.js"></script>
            </head><body>

            <h3 class="red"> -- Application DEBUG -- </h3>

      <div class="debug">';
        echo '<pre>';
        print_r($array1);
        echo '</pre>';
        echo '<hr />';
        echo '<pre>';
        print_r($array2);
        echo '
            </pre>
          <hr />
            <p onclick="inverserDiv(\'idParams\');" class="lien">Les paramtres</p>
            <div id="idParams" style="display:none;">
            <pre>';
        print_r($this->_params);
        echo '</pre></div>
          <hr />
            <p onclick="inverserDiv(\'idRequest\');" class="lien">La requete</p>
            <div id="idRequest" style="display:none;">
              <pre>';
        print_r($this->_requete);
        echo '</pre>
            </div>
      </div>
    </body></html>';
        exit();

  }

}
?>