<?php
/**
 * @version $Id: authControleur.php 23 2009-11-10 14:36:55Z jjocal $
 * @author Julien Jocal
 * @copyright 2009 Julien Jocal
 *
 * This file is part of miniFramework.
 *
 * miniFramework is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * miniFramework is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details (COPYING).
 *
 * You should have received a copy of the GNU General Public License
 * along with miniFramework.  If not, see <http://www.gnu.org/licenses/>.
 *
 *
 */

/**
 * Le authControleur gre toute la partis authentification de l'application ainsi que la gestion des sessions
 *
 * @author jjocal
 */
class authControleur {

  private $_auth = false;
  /**
   * Mode d'authentification sur l'application
   * @var string appli/cas/ldap...
   */
  private $_mode = "appli";
  /**
   * Le niveau 2 ajoute une vrification de l'adresse IP et du navigateur de l'utilisateur
   * @var integer 2 ou 3
   */
  private $_niveau = 2;
  private $_infos = NULL;
  /**
   * Nom du fichier  charger pour une authentification sur une serveur CAS
   * @var string fichier
   */
  private $_fichier = "cas.php";
  /**
   * Nom de la table o sont stockes les informations des utilisateurs
   * @var string table
   */
  private $_table = "utilisateurs";
  /**
   * Nom du champ du login des utilisateurs
   * @var string champ
   */
  private $_champLogin = "login";
  /**
   * Nom du champ du mot de passe des utilisateurs
   * @var string champ
   */
  private $_champMdp = "password";
  /**
   * Encryptage des mots de passe dans la base de donnes
   * @var string code
   */
  private $_crypt = "md5";
  /**
   * L'objet utilisateur qui sera stock en session
   * @var object Utilisateur
   */
  private $_user = NULL;

  /**
   * Cette proprit peut se modifier  travers le fichier securite/auth.inc.php
   * @var string Nom de la session
   */
  private $_nameSession = 'miniworks';

  public function  __construct($auth) {

    include 'securite/auth.inc.php';
    $this->_mode        = array_key_exists("mode", $infosAuth) ? $infosAuth["mode"] : "appli";
    $this->_niveau      = array_key_exists("niveau", $infosAuth) ? $infosAuth["niveau"] : "appli";
    $this->_table       = array_key_exists("table", $infosAuth) ? $infosAuth["table"] : "utilisateurs";
    $this->_champLogin  = array_key_exists("login", $infosAuth) ? $infosAuth["login"] : "login";
    $this->_champMdp    = array_key_exists("password", $infosAuth) ? $infosAuth["password"] : "password";
    $this->_nameSession = array_key_exists("namesession", $infosAuth) ? $infosAuth["namesession"] : "miniworks";

    if ($auth === false) {
      return false;
      exit();
    }elseif($this->_mode == 'cas'){
      $this->verifUser();
    }elseif($auth === true){
      $this->_session($this->_nameSession);
      $this->verifUser();
    }

  }

  public function verifUser(){

    if (self::isAuthWithSession() === true){
      return true;
    }elseif(isset($_POST['testlogin'][$this->_champLogin])){
      switch ($this->_mode) {
        case "appli":
          $resultat = $this->setAuthAppli();
          break;
        case "cas":
          $resultat = $this->setAuthCas();
          break;

      default:
        $resultat = false;
        break;
      }
    }elseif($this->_mode == 'cas'){
      $resultat = $this->setAuthCas();
    }else{
      return false;
    }

    if ($resultat === true){
      $this->lancerSession();
    }else{
      return 'Impossible de reconnaitre cet utilisateur';
    }

  }

  /**
   * Par dfaut, miniframework cherche dans la table utilisateurs les champs login et mdp mais on peut le changer.
   * Il attend aussi un formulaire $_POST['testlogin'] par dfaut
   *
   * @todo Il faudra penser  rendre paramtrable le nom du champ POST qui arrive du formulaire : testlogin
   * @return boolean true/false
   */
  private function setAuthAppli(){

    $criteria = new Criteria();
    $criteria->add(UtilisateurPeer::LOGIN, $_POST['testlogin'][$this->_champLogin], Criteria::EQUAL);
    $test = UtilisateurPeer::doSelect($criteria);

    if (empty ($test)){

      return false;

    }else{

      $methode = 'get'.ucfirst($this->_champMdp);

      if ($test[0]->{$methode}() == md5($_POST['testlogin'][$this->_champMdp])){
        $this->_user = $test[0];
        return true;
      }else{
        return false;
      }
      
    }

  }

  /**
   * Vrification de l'authentifictaion  travers un serveur CAS
   *
   * @todo : En voie de rsolution
   * @return boolean true/false
   */
  private function setAuthCas(){
    include 'libexterne/cas/CAS.php';
		include('securite/connect_cas.inc.php');

    //phpCAS::setDebug();

    // initialize phpCAS
    phpCAS::client(CAS_VERSION_2_0,$cas_host,$cas_port,'');

    // no SSL validation for the CAS server
    phpCAS::setNoCasServerValidation();

    if (isset($_REQUEST['logout'])) {
      phpCAS::logout();
    }
    //if (isset($_REQUEST['login'])) {
      phpCAS::forceAuthentication();
    //}

    // check CAS authentication
    $auth = phpCAS::checkAuthentication();

		$_login = phpCAS::getUser();

    // On teste si le login existe
    $c = new Criteria();
    $c->add(UtilisateurPeer::LOGIN, $_login, Criteria::EQUAL);
    $test = UtilisateurPeer::doSelect($c);

    if (!empty ($test)){
      if ($test[0]->getSso() == 'o'){
        $this->_user = $test[0];

        return true;
      }
    }
    return false;
  }
  private function setUserAuth($userLogin = NULL){

  }
  private function _session($name){
    session_name($name);
    session_start();
  }
  private function lancerSession(){

    // Pour CAS, on lance la session
    if ($this->_mode == 'cas'){
      //$this->_session($this->_nameSession);
    }

    $_SESSION["user"] = $this->_user;

    $_SESSION["idLog"] = logControleur::insertLog('login', '0', 'Session', $_SESSION["user"]->getId());
    $_SESSION['typeaff'] = 'toutes'; // sert  dterminer les comptences visibles dans le select des grilles de comptences

    if ($this->_niveau == "2"){
      $ip = false;
    }elseif($this->_niveau == "3"){
      $ip = true;
    }else{
      $ip = false;
    }
    $this->insertUserAgentMd5($ip);

  }
  private function insertUserAgentMd5($ip){
    $_SESSION["agent"] = $this->createUserAgent($ip);
  }
  private function createUserAgent($ip){
    if ($ip === true){
      return md5($_SERVER["REMOTE_ADDR"].$_SERVER["HTTP_USER_AGENT"]);
    }else{
      return md5($_SERVER["HTTP_USER_AGENT"]);
    }

  }
  public static function logout(){

    $userId = isset($_SESSION["user"]) ? $_SESSION["user"]->getId() : 0;
    $idLog = isset($_SESSION["idLog"]) ? $_SESSION["idLog"] : 'n';

    /**
     * @todo : il vaudrait mieux updater le log de l'utilisteur ete le mettre  jour pour sa date de sortie.
     */
    if ($idLog == 'n'){
      logControleur::insertLog("logout", 0, "Utilisateur dconnect", $userId);
    }else{
      $log = LogPeer::retrieveByPK($idLog);
      $log->setFin(date("U"));
      $log->save();
    }
    unset ($_SESSION);
    session_destroy();
  }
  public static function isAuthWithSession(){

    if (isset($_SESSION["user"]) AND is_object($_SESSION["user"]) === true){
      return true;
    }else {
      return false;;
    }
  }

  /**
   * Renvoie le mode de connexion : appli cas
   *
   * @return string Mode
   */
  public function getMode(){
    return $this->_mode;
  }

}
?>
