<?php

require 'competencesrb/om/BaseCompetencePeer.php';


/**
 * Skeleton subclass for performing query and update operations on the 'competences' table.
 *
 * Liste des competences evaluees
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    competencesrb
 */
class CompetencePeer extends BaseCompetencePeer {

  /**
   * Renvoie un tableau pour les select sous la forme tab[id] = nomcourt
   *
   * @param string $type socle/peda/perso/toutes
   * @param object $user objet utilisateur
   * @return array liste des comptences du socle commun
   */
  public static function listeCptecesForSelect($type, utilisateur $user){

    $tabtype = array('socle', 'socle2', 'peda', 'perso', 'toutes', 'pedaperso');

    if (in_array($type, $tabtype)){

      $liste = CompetencePeer::listeCpteces($type, $user);

      $tab = array();
      $tab['0'] = ' -- Les comp&eacute;tences du socle commun --';
      if ($type == 'perso'){$tab['0'] = ' -- Mes comp&eacute;tences personnelles --';}
      if ($type == 'peda'){$tab['0'] = ' -- Les comp&eacute;tences communes --';}
      if ($type == 'pedaperso'){$tab['0'] = ' -- Les comp&eacute;tences personnelles et communes --';}
      if ($type == 'toutes'){$tab['0'] = ' -- Liste des comp&eacute;tences --';}
      foreach ($liste as $cptce) {
        $tab[$cptce->getId()] = '['.$cptce->getCompetenceGrp()->getOrdre().'] - '.$cptce->getNomCourt();
      }
      return $tab;

    }else{
      throw new Exception('Ce type de comptences n\'est pas pris en compte : ' . $type . ' !');
    }

  }

  /**
   * Renvoie un tableau format pour le select en tenant compte des domaines de comptences mis en prfrences par l'utilisateur
   *
   * @param string $type socle, perso, peda, toutes
   * @param object $user utilisateur
   * @return array $tab[id] = $nomcourt
   */
  public static function listeCptecesAvecPreferenceForSelect($type, utilisateur $user){

    $domaine = $user->getDomainesDeCetUtilisateur();

    if (empty ($domaine)){
      return CompetencePeer::listeCptecesForSelect($type, $user);
    }else{

      $liste = CompetencePeer::listeCpteces($type, $user);

      $tab = array();
      $tab['0'] = ' -- Les comp&eacute;tences du socle commun --';
      if ($type == 'perso'){$tab['0'] = ' -- Mes comp&eacute;tences personnelles --';}
      if ($type == 'peda'){$tab['0'] = ' -- Les comp&eacute;tences communes --';}
      if ($type == 'pedaperso'){$tab['0'] = ' -- Les comp&eacute;tences personnelles et communes --';}
      if ($type == 'toutes'){$tab['0'] = ' -- Liste des comp&eacute;tences --';}

      foreach ($liste as $cptce) {
        if (in_array($cptce->getCptcegrpId(), $domaine) === true){
          $tab[$cptce->getId()] = '['.$cptce->getCompetenceGrp()->getOrdre().'] - '.$cptce->getNomcourt();
        }
      }
    }

    return $tab;

  }

  /**
   * Renvoie la liste des comptences en tenant compte du type demand
   *
   * @param string $type perso peda socle toutes
   * @param object $user utilisateur
   * @return array tableau des objets comptences
   */
  private static function listeCpteces($type, utilisateur $user){
    $tabtype = array('socle', 'socle2', 'peda', 'perso', 'toutes', 'pedaperso');

    if (in_array($type, $tabtype)){

      # On limine les comptences caches
      $criteria = new Criteria();
      $criteria->add(JCompetenceVisiblePeer::RNE, $user->getRne());
      $invisibles = JCompetenceVisiblePeer::doSelect($criteria);
      $listeinvisible = array();
      foreach ($invisibles as $inv) {
        $listeinvisible[] = $inv->getCompetenceId();
      }

      $cr = new Criteria();
      if ($type == 'pedaperso'){

        # On rcupre la liste des comptences communes (dites "peda") de cet utilisateur
        $listePeda = JCompetencesProfesseursPeer::listeCptcesCommunesCetUtilisateur($user);

        $criter1 = $cr->getNewCriterion(CompetencePeer::TYPE, 'peda');
        //$criter2 = $cr->getNewCriterion(CompetencePeer::RNE, $user->getRne());
        $criter2 = $cr->getNewCriterion(CompetencePeer::ID, $listePeda, Criteria::IN);
        $criter3 = $cr->getNewCriterion(CompetencePeer::TYPE, 'perso');
        $criter4 = $cr->getNewCriterion(CompetencePeer::UTILISATEUR_ID, $user->getId());
        $criter1->addAnd($criter2);
        $criter3->addAnd($criter4);
        $criter1->addOr($criter3);

        $cr->add($criter1);
        
      }elseif($type != 'toutes'){
        $cr->add(CompetencePeer::TYPE, $type, Criteria::EQUAL);
        # socle niveau 2 seulement
        if (isset($_GET['voir']) AND $_GET['voir'] == 'niveau2'){
          $cr->add(CompetencePeer::NIVEAU, '2');
        }
        if ($type == 'peda'){
          $cr->add(CompetencePeer::ID, $listePeda, Criteria::IN);
        }
      }else{
        # On ne doit envoyer que les comptences perso de cet utilisateur quand il les appelle toutes
        $cr->add(CompetencePeer::UTILISATEUR_ID, array($user->getId(), '0'), Criteria::IN);
        $cr->add(CompetencePeer::RNE, array($user->getRne(), 'all'), Criteria::IN);
      }
      if ($type == 'perso'){
        $cr->add(CompetencePeer::UTILISATEUR_ID, $user->getId(), Criteria::EQUAL);
      }
      $cr->add(CompetencePeer::ID, $listeinvisible, Criteria::NOT_IN);
      $cr->addAscendingOrderByColumn(CompetenceGrpPeer::ORDRE);
      $cr->addAscendingOrderByColumn(CompetencePeer::CPTCEGRP_ID);
      $cr->addAscendingOrderByColumn(CompetencePeer::NOMLONG);
      return CompetencePeer::doSelectJoinCompetenceGrp($cr);

    }
  } // listeCptces()

} // CompetencePeer
