<?php

require 'competencesrb/om/BaseValidationNiveauPeer.php';


/**
 * Skeleton subclass for performing query and update operations on the 'validations' table.
 *
 * Liste des niveaux de validation
 *
 * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package    competencesrb
 */
class ValidationNiveauPeer extends BaseValidationNiveauPeer {

  /**
   * Retourne la liste des niveaux de validation
   *
   * @var string $option permet de modifier la valeur retourne pour chaque itration : NULL par dfaut, color - niveau, niveauLettre
   * @return array $tab tableau php $tab[lettre] = texte
   */
  public static function listeNiveauxValidation($option = NULL){

    $cr = new Criteria();
    $cr->add(ValidationNiveauPeer::RNE, $_SESSION['user']->getRne());
    $cr->addAscendingOrderByColumn(ValidationNiveauPeer::NIVEAU);
    $test = ValidationNiveauPeer::doSelect($cr);
    $tab = array();

    if (!empty ($test)){

      foreach ($test as $niveau) {
        if (is_null($option)){
          $tab[$niveau->getLettre()] = $niveau->getTexte();
        }elseif($option == 'color'){
          $tab[$niveau->getLettre()] = $niveau->getCouleur();
        }elseif($option == 'niveau'){
          $tab[$niveau->getLettre()] = $niveau->getNiveau();
        }elseif($option == 'niveauLettre'){
          $tab[$niveau->getNiveau()] = $niveau->getLettre();
        }else{
          Die('Option indisponible '.__CLASS__.' - '.__METHOD__);
        }
      }

    }else{
      $tab['z'] = 'Aucun niveau de validation n\'a &eacute;t&eacute; d&eacute;fini';
    }
    return $tab;
  } // listeNiveauxValidation()

  /**
   * Convertit une couleur hxadcimale en RGB
   *
   * @param integer $hexa couleur hxadcimale sans le # devant
   * @return array $tab[0]=rouge $tab[1]=vert $tab[2]=bleu
   */
  public static function convertirHexadecimalToRgb($hexa){
    if(! ereg("[0-9a-fA-F]{6}", $hexa)) {
      echo "Le nombre hexa propos n'est pas valide !";
      return 0;
    }
    for($i=0; $i<3; $i++) {
      $temp = substr($hexa, 2*$i, 2);
      $rgb[$i] = 16 * hexdec(substr($temp, 0, 1)) + hexdec(substr($temp, 1, 1));
    }
    return $rgb;
  } // convertirHexadecimalToRgb()

  public static function listeNiveauxValidationForSelect(){

    $tab = array();

    $tab[0] = ' -- Liste des Niveaux de validation -- ';
    $tab2 = ValidationNiveauPeer::listeNiveauxValidation();

    $tab3 = array_merge($tab, $tab2);

    return $tab3;
  } // listeNiveauxValidationForSelect()

  /**
   * Renvoie une moyenne de plusieurs valuations
   *
   * @param integer $nbre nombre d'valuations
   * @param array $total Tableau des niveaux (integer) de chaque valuation
   * @param string $options mode de calcul de la moyenne 'defaut',...
   * @param string $type type de rponses 'lettre',...
   * @return string En fonction du $type
   */
  public static function calculeMoyenne($nbre, $total, $options = 'defaut', $type = 'lettre'){

    if ($options == 'defaut'){
      $calcul = 0;
      $retour = self::listeNiveauxValidation('niveauLettre');
      foreach ($total as $eval){
        $calcul = $calcul + $eval;
      }
      if ($nbre != 0){
        $moyenne = round($calcul/$nbre);
      }else{
        $moyenne = 0;
      }

    }
    if ($moyenne != 0){
      return $retour[$moyenne];
    }else{
      return 0;
    }
  } // calculeMoyenne()

} // ValidationNiveauPeer
