<?php

/**
 * Base class that represents a row from the 'appreciations' table.
 *
 * Liste des appreciations pour chaque matiere
 *
 * @package    competencesrb.om
 */
abstract class BaseAppreciation extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        AppreciationPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the bulletin_id field.
	 * @var        int
	 */
	protected $bulletin_id;

	/**
	 * The value for the professeur_id field.
	 * @var        int
	 */
	protected $professeur_id;

	/**
	 * The value for the eleve_id field.
	 * @var        int
	 */
	protected $eleve_id;

	/**
	 * The value for the transversale field.
	 * @var        string
	 */
	protected $transversale;

	/**
	 * The value for the contenu field.
	 * @var        string
	 */
	protected $contenu;

	/**
	 * The value for the created_on field.
	 * @var        int
	 */
	protected $created_on;

	/**
	 * The value for the moyennecrite field.
	 * @var        int
	 */
	protected $moyennecrite;

	/**
	 * The value for the moyenneorale field.
	 * @var        int
	 */
	protected $moyenneorale;

	/**
	 * @var        Bulletin
	 */
	protected $aBulletin;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateurRelatedByProfesseurId;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateurRelatedByEleveId;

	/**
	 * @var        array JAppreciationBilan[] Collection to store aggregation of JAppreciationBilan objects.
	 */
	protected $collJAppreciationBilans;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJAppreciationBilans.
	 */
	private $lastJAppreciationBilanCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseAppreciation object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table appreciations
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [bulletin_id] column value.
	 * cle etrangere du bulletin
	 * @return     int
	 */
	public function getBulletinId()
	{
		return $this->bulletin_id;
	}

	/**
	 * Get the [professeur_id] column value.
	 * cle etrangere de l'utilisateur professeur
	 * @return     int
	 */
	public function getProfesseurId()
	{
		return $this->professeur_id;
	}

	/**
	 * Get the [eleve_id] column value.
	 * cle etrangere de l'utilisateur eleve
	 * @return     int
	 */
	public function getEleveId()
	{
		return $this->eleve_id;
	}

	/**
	 * Get the [transversale] column value.
	 * Transversale ou pas (O/N)
	 * @return     string
	 */
	public function getTransversale()
	{
		return $this->transversale;
	}

	/**
	 * Get the [contenu] column value.
	 * Contenu de l'appreciation
	 * @return     string
	 */
	public function getContenu()
	{
		return $this->contenu;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation de l'appreciation
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Get the [moyennecrite] column value.
	 * inutile
	 * @return     int
	 */
	public function getMoyennecrite()
	{
		return $this->moyennecrite;
	}

	/**
	 * Get the [moyenneorale] column value.
	 * inutile
	 * @return     int
	 */
	public function getMoyenneorale()
	{
		return $this->moyenneorale;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table appreciations
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = AppreciationPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [bulletin_id] column.
	 * cle etrangere du bulletin
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setBulletinId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->bulletin_id !== $v) {
			$this->bulletin_id = $v;
			$this->modifiedColumns[] = AppreciationPeer::BULLETIN_ID;
		}

		if ($this->aBulletin !== null && $this->aBulletin->getId() !== $v) {
			$this->aBulletin = null;
		}

		return $this;
	} // setBulletinId()

	/**
	 * Set the value of [professeur_id] column.
	 * cle etrangere de l'utilisateur professeur
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setProfesseurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->professeur_id !== $v) {
			$this->professeur_id = $v;
			$this->modifiedColumns[] = AppreciationPeer::PROFESSEUR_ID;
		}

		if ($this->aUtilisateurRelatedByProfesseurId !== null && $this->aUtilisateurRelatedByProfesseurId->getId() !== $v) {
			$this->aUtilisateurRelatedByProfesseurId = null;
		}

		return $this;
	} // setProfesseurId()

	/**
	 * Set the value of [eleve_id] column.
	 * cle etrangere de l'utilisateur eleve
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setEleveId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->eleve_id !== $v) {
			$this->eleve_id = $v;
			$this->modifiedColumns[] = AppreciationPeer::ELEVE_ID;
		}

		if ($this->aUtilisateurRelatedByEleveId !== null && $this->aUtilisateurRelatedByEleveId->getId() !== $v) {
			$this->aUtilisateurRelatedByEleveId = null;
		}

		return $this;
	} // setEleveId()

	/**
	 * Set the value of [transversale] column.
	 * Transversale ou pas (O/N)
	 * @param      string $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setTransversale($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->transversale !== $v) {
			$this->transversale = $v;
			$this->modifiedColumns[] = AppreciationPeer::TRANSVERSALE;
		}

		return $this;
	} // setTransversale()

	/**
	 * Set the value of [contenu] column.
	 * Contenu de l'appreciation
	 * @param      string $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setContenu($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->contenu !== $v) {
			$this->contenu = $v;
			$this->modifiedColumns[] = AppreciationPeer::CONTENU;
		}

		return $this;
	} // setContenu()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation de l'appreciation
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v) {
			$this->created_on = $v;
			$this->modifiedColumns[] = AppreciationPeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Set the value of [moyennecrite] column.
	 * inutile
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setMoyennecrite($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->moyennecrite !== $v) {
			$this->moyennecrite = $v;
			$this->modifiedColumns[] = AppreciationPeer::MOYENNECRITE;
		}

		return $this;
	} // setMoyennecrite()

	/**
	 * Set the value of [moyenneorale] column.
	 * inutile
	 * @param      int $v new value
	 * @return     Appreciation The current object (for fluent API support)
	 */
	public function setMoyenneorale($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->moyenneorale !== $v) {
			$this->moyenneorale = $v;
			$this->modifiedColumns[] = AppreciationPeer::MOYENNEORALE;
		}

		return $this;
	} // setMoyenneorale()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->bulletin_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->professeur_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->eleve_id = ($row[$startcol + 3] !== null) ? (int) $row[$startcol + 3] : null;
			$this->transversale = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->contenu = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->created_on = ($row[$startcol + 6] !== null) ? (int) $row[$startcol + 6] : null;
			$this->moyennecrite = ($row[$startcol + 7] !== null) ? (int) $row[$startcol + 7] : null;
			$this->moyenneorale = ($row[$startcol + 8] !== null) ? (int) $row[$startcol + 8] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 9; // 9 = AppreciationPeer::NUM_COLUMNS - AppreciationPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Appreciation object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aBulletin !== null && $this->bulletin_id !== $this->aBulletin->getId()) {
			$this->aBulletin = null;
		}
		if ($this->aUtilisateurRelatedByProfesseurId !== null && $this->professeur_id !== $this->aUtilisateurRelatedByProfesseurId->getId()) {
			$this->aUtilisateurRelatedByProfesseurId = null;
		}
		if ($this->aUtilisateurRelatedByEleveId !== null && $this->eleve_id !== $this->aUtilisateurRelatedByEleveId->getId()) {
			$this->aUtilisateurRelatedByEleveId = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AppreciationPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = AppreciationPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aBulletin = null;
			$this->aUtilisateurRelatedByProfesseurId = null;
			$this->aUtilisateurRelatedByEleveId = null;
			$this->collJAppreciationBilans = null;
			$this->lastJAppreciationBilanCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AppreciationPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			AppreciationPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AppreciationPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			AppreciationPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aBulletin !== null) {
				if ($this->aBulletin->isModified() || $this->aBulletin->isNew()) {
					$affectedRows += $this->aBulletin->save($con);
				}
				$this->setBulletin($this->aBulletin);
			}

			if ($this->aUtilisateurRelatedByProfesseurId !== null) {
				if ($this->aUtilisateurRelatedByProfesseurId->isModified() || $this->aUtilisateurRelatedByProfesseurId->isNew()) {
					$affectedRows += $this->aUtilisateurRelatedByProfesseurId->save($con);
				}
				$this->setUtilisateurRelatedByProfesseurId($this->aUtilisateurRelatedByProfesseurId);
			}

			if ($this->aUtilisateurRelatedByEleveId !== null) {
				if ($this->aUtilisateurRelatedByEleveId->isModified() || $this->aUtilisateurRelatedByEleveId->isNew()) {
					$affectedRows += $this->aUtilisateurRelatedByEleveId->save($con);
				}
				$this->setUtilisateurRelatedByEleveId($this->aUtilisateurRelatedByEleveId);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = AppreciationPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = AppreciationPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += AppreciationPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJAppreciationBilans !== null) {
				foreach ($this->collJAppreciationBilans as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aBulletin !== null) {
				if (!$this->aBulletin->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aBulletin->getValidationFailures());
				}
			}

			if ($this->aUtilisateurRelatedByProfesseurId !== null) {
				if (!$this->aUtilisateurRelatedByProfesseurId->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateurRelatedByProfesseurId->getValidationFailures());
				}
			}

			if ($this->aUtilisateurRelatedByEleveId !== null) {
				if (!$this->aUtilisateurRelatedByEleveId->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateurRelatedByEleveId->getValidationFailures());
				}
			}


			if (($retval = AppreciationPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJAppreciationBilans !== null) {
					foreach ($this->collJAppreciationBilans as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = AppreciationPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getBulletinId();
				break;
			case 2:
				return $this->getProfesseurId();
				break;
			case 3:
				return $this->getEleveId();
				break;
			case 4:
				return $this->getTransversale();
				break;
			case 5:
				return $this->getContenu();
				break;
			case 6:
				return $this->getCreatedOn();
				break;
			case 7:
				return $this->getMoyennecrite();
				break;
			case 8:
				return $this->getMoyenneorale();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = AppreciationPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getBulletinId(),
			$keys[2] => $this->getProfesseurId(),
			$keys[3] => $this->getEleveId(),
			$keys[4] => $this->getTransversale(),
			$keys[5] => $this->getContenu(),
			$keys[6] => $this->getCreatedOn(),
			$keys[7] => $this->getMoyennecrite(),
			$keys[8] => $this->getMoyenneorale(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = AppreciationPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setBulletinId($value);
				break;
			case 2:
				$this->setProfesseurId($value);
				break;
			case 3:
				$this->setEleveId($value);
				break;
			case 4:
				$this->setTransversale($value);
				break;
			case 5:
				$this->setContenu($value);
				break;
			case 6:
				$this->setCreatedOn($value);
				break;
			case 7:
				$this->setMoyennecrite($value);
				break;
			case 8:
				$this->setMoyenneorale($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = AppreciationPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setBulletinId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setProfesseurId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setEleveId($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setTransversale($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setContenu($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setCreatedOn($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setMoyennecrite($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setMoyenneorale($arr[$keys[8]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(AppreciationPeer::DATABASE_NAME);

		if ($this->isColumnModified(AppreciationPeer::ID)) $criteria->add(AppreciationPeer::ID, $this->id);
		if ($this->isColumnModified(AppreciationPeer::BULLETIN_ID)) $criteria->add(AppreciationPeer::BULLETIN_ID, $this->bulletin_id);
		if ($this->isColumnModified(AppreciationPeer::PROFESSEUR_ID)) $criteria->add(AppreciationPeer::PROFESSEUR_ID, $this->professeur_id);
		if ($this->isColumnModified(AppreciationPeer::ELEVE_ID)) $criteria->add(AppreciationPeer::ELEVE_ID, $this->eleve_id);
		if ($this->isColumnModified(AppreciationPeer::TRANSVERSALE)) $criteria->add(AppreciationPeer::TRANSVERSALE, $this->transversale);
		if ($this->isColumnModified(AppreciationPeer::CONTENU)) $criteria->add(AppreciationPeer::CONTENU, $this->contenu);
		if ($this->isColumnModified(AppreciationPeer::CREATED_ON)) $criteria->add(AppreciationPeer::CREATED_ON, $this->created_on);
		if ($this->isColumnModified(AppreciationPeer::MOYENNECRITE)) $criteria->add(AppreciationPeer::MOYENNECRITE, $this->moyennecrite);
		if ($this->isColumnModified(AppreciationPeer::MOYENNEORALE)) $criteria->add(AppreciationPeer::MOYENNEORALE, $this->moyenneorale);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(AppreciationPeer::DATABASE_NAME);

		$criteria->add(AppreciationPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Appreciation (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setBulletinId($this->bulletin_id);

		$copyObj->setProfesseurId($this->professeur_id);

		$copyObj->setEleveId($this->eleve_id);

		$copyObj->setTransversale($this->transversale);

		$copyObj->setContenu($this->contenu);

		$copyObj->setCreatedOn($this->created_on);

		$copyObj->setMoyennecrite($this->moyennecrite);

		$copyObj->setMoyenneorale($this->moyenneorale);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJAppreciationBilans() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJAppreciationBilan($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Appreciation Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     AppreciationPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new AppreciationPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Bulletin object.
	 *
	 * @param      Bulletin $v
	 * @return     Appreciation The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setBulletin(Bulletin $v = null)
	{
		if ($v === null) {
			$this->setBulletinId(NULL);
		} else {
			$this->setBulletinId($v->getId());
		}

		$this->aBulletin = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Bulletin object, it will not be re-added.
		if ($v !== null) {
			$v->addAppreciation($this);
		}

		return $this;
	}


	/**
	 * Get the associated Bulletin object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Bulletin The associated Bulletin object.
	 * @throws     PropelException
	 */
	public function getBulletin(PropelPDO $con = null)
	{
		if ($this->aBulletin === null && ($this->bulletin_id !== null)) {
			$this->aBulletin = BulletinPeer::retrieveByPK($this->bulletin_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aBulletin->addAppreciations($this);
			 */
		}
		return $this->aBulletin;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Appreciation The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateurRelatedByProfesseurId(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setProfesseurId(NULL);
		} else {
			$this->setProfesseurId($v->getId());
		}

		$this->aUtilisateurRelatedByProfesseurId = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addAppreciationRelatedByProfesseurId($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateurRelatedByProfesseurId(PropelPDO $con = null)
	{
		if ($this->aUtilisateurRelatedByProfesseurId === null && ($this->professeur_id !== null)) {
			$this->aUtilisateurRelatedByProfesseurId = UtilisateurPeer::retrieveByPK($this->professeur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateurRelatedByProfesseurId->addAppreciationsRelatedByProfesseurId($this);
			 */
		}
		return $this->aUtilisateurRelatedByProfesseurId;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Appreciation The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateurRelatedByEleveId(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setEleveId(NULL);
		} else {
			$this->setEleveId($v->getId());
		}

		$this->aUtilisateurRelatedByEleveId = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addAppreciationRelatedByEleveId($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateurRelatedByEleveId(PropelPDO $con = null)
	{
		if ($this->aUtilisateurRelatedByEleveId === null && ($this->eleve_id !== null)) {
			$this->aUtilisateurRelatedByEleveId = UtilisateurPeer::retrieveByPK($this->eleve_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateurRelatedByEleveId->addAppreciationsRelatedByEleveId($this);
			 */
		}
		return $this->aUtilisateurRelatedByEleveId;
	}

	/**
	 * Clears out the collJAppreciationBilans collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJAppreciationBilans()
	 */
	public function clearJAppreciationBilans()
	{
		$this->collJAppreciationBilans = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJAppreciationBilans collection (array).
	 *
	 * By default this just sets the collJAppreciationBilans collection to an empty array (like clearcollJAppreciationBilans());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJAppreciationBilans()
	{
		$this->collJAppreciationBilans = array();
	}

	/**
	 * Gets an array of JAppreciationBilan objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Appreciation has previously been saved, it will retrieve
	 * related JAppreciationBilans from storage. If this Appreciation is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JAppreciationBilan[]
	 * @throws     PropelException
	 */
	public function getJAppreciationBilans($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AppreciationPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAppreciationBilans === null) {
			if ($this->isNew()) {
			   $this->collJAppreciationBilans = array();
			} else {

				$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

				JAppreciationBilanPeer::addSelectColumns($criteria);
				$this->collJAppreciationBilans = JAppreciationBilanPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

				JAppreciationBilanPeer::addSelectColumns($criteria);
				if (!isset($this->lastJAppreciationBilanCriteria) || !$this->lastJAppreciationBilanCriteria->equals($criteria)) {
					$this->collJAppreciationBilans = JAppreciationBilanPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJAppreciationBilanCriteria = $criteria;
		return $this->collJAppreciationBilans;
	}

	/**
	 * Returns the number of related JAppreciationBilan objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JAppreciationBilan objects.
	 * @throws     PropelException
	 */
	public function countJAppreciationBilans(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AppreciationPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJAppreciationBilans === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

				$count = JAppreciationBilanPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

				if (!isset($this->lastJAppreciationBilanCriteria) || !$this->lastJAppreciationBilanCriteria->equals($criteria)) {
					$count = JAppreciationBilanPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJAppreciationBilans);
				}
			} else {
				$count = count($this->collJAppreciationBilans);
			}
		}
		$this->lastJAppreciationBilanCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JAppreciationBilan object to this object
	 * through the JAppreciationBilan foreign key attribute.
	 *
	 * @param      JAppreciationBilan $l JAppreciationBilan
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJAppreciationBilan(JAppreciationBilan $l)
	{
		if ($this->collJAppreciationBilans === null) {
			$this->initJAppreciationBilans();
		}
		if (!in_array($l, $this->collJAppreciationBilans, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJAppreciationBilans, $l);
			$l->setAppreciation($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Appreciation is new, it will return
	 * an empty collection; or if this Appreciation has previously
	 * been saved, it will retrieve related JAppreciationBilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Appreciation.
	 */
	public function getJAppreciationBilansJoinBilan($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AppreciationPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAppreciationBilans === null) {
			if ($this->isNew()) {
				$this->collJAppreciationBilans = array();
			} else {

				$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

				$this->collJAppreciationBilans = JAppreciationBilanPeer::doSelectJoinBilan($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->id);

			if (!isset($this->lastJAppreciationBilanCriteria) || !$this->lastJAppreciationBilanCriteria->equals($criteria)) {
				$this->collJAppreciationBilans = JAppreciationBilanPeer::doSelectJoinBilan($criteria, $con, $join_behavior);
			}
		}
		$this->lastJAppreciationBilanCriteria = $criteria;

		return $this->collJAppreciationBilans;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJAppreciationBilans) {
				foreach ((array) $this->collJAppreciationBilans as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJAppreciationBilans = null;
			$this->aBulletin = null;
			$this->aUtilisateurRelatedByProfesseurId = null;
			$this->aUtilisateurRelatedByEleveId = null;
	}

} // BaseAppreciation
