<?php

/**
 * Base class that represents a row from the 'attestations' table.
 *
 * Liste des attestations
 *
 * @package    competencesrb.om
 */
abstract class BaseAttestation extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        AttestationPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the eleve_id field.
	 * @var        int
	 */
	protected $eleve_id;

	/**
	 * The value for the pallier field.
	 * @var        int
	 */
	protected $pallier;

	/**
	 * The value for the assr1 field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $assr1;

	/**
	 * The value for the assr2 field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $assr2;

	/**
	 * The value for the psc1 field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $psc1;

	/**
	 * The value for the maitrise field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $maitrise;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the created_on field.
	 * @var        int
	 */
	protected $created_on;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * @var        array JAttestationItem[] Collection to store aggregation of JAttestationItem objects.
	 */
	protected $collJAttestationItems;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJAttestationItems.
	 */
	private $lastJAttestationItemCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseAttestation object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->assr1 = '';
		$this->assr2 = '';
		$this->psc1 = '';
		$this->maitrise = '';
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table attestations
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [eleve_id] column value.
	 * cle etrangere de l'eleve
	 * @return     int
	 */
	public function getEleveId()
	{
		return $this->eleve_id;
	}

	/**
	 * Get the [pallier] column value.
	 * Pallier 1,  2 ou 3
	 * @return     int
	 */
	public function getPallier()
	{
		return $this->pallier;
	}

	/**
	 * Get the [assr1] column value.
	 * ASSR 1 o/n
	 * @return     string
	 */
	public function getAssr1()
	{
		return $this->assr1;
	}

	/**
	 * Get the [assr2] column value.
	 * ASSR 2 o/n
	 * @return     string
	 */
	public function getAssr2()
	{
		return $this->assr2;
	}

	/**
	 * Get the [psc1] column value.
	 * PSC 1 o/n
	 * @return     string
	 */
	public function getPsc1()
	{
		return $this->psc1;
	}

	/**
	 * Get the [maitrise] column value.
	 * maitrise o/n
	 * @return     string
	 */
	public function getMaitrise()
	{
		return $this->maitrise;
	}

	/**
	 * Get the [rne] column value.
	 * Rne de l'etablissement
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table attestations
	 * @param      int $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = AttestationPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [eleve_id] column.
	 * cle etrangere de l'eleve
	 * @param      int $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setEleveId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->eleve_id !== $v) {
			$this->eleve_id = $v;
			$this->modifiedColumns[] = AttestationPeer::ELEVE_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setEleveId()

	/**
	 * Set the value of [pallier] column.
	 * Pallier 1,  2 ou 3
	 * @param      int $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setPallier($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->pallier !== $v) {
			$this->pallier = $v;
			$this->modifiedColumns[] = AttestationPeer::PALLIER;
		}

		return $this;
	} // setPallier()

	/**
	 * Set the value of [assr1] column.
	 * ASSR 1 o/n
	 * @param      string $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setAssr1($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->assr1 !== $v || $v === '') {
			$this->assr1 = $v;
			$this->modifiedColumns[] = AttestationPeer::ASSR1;
		}

		return $this;
	} // setAssr1()

	/**
	 * Set the value of [assr2] column.
	 * ASSR 2 o/n
	 * @param      string $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setAssr2($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->assr2 !== $v || $v === '') {
			$this->assr2 = $v;
			$this->modifiedColumns[] = AttestationPeer::ASSR2;
		}

		return $this;
	} // setAssr2()

	/**
	 * Set the value of [psc1] column.
	 * PSC 1 o/n
	 * @param      string $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setPsc1($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->psc1 !== $v || $v === '') {
			$this->psc1 = $v;
			$this->modifiedColumns[] = AttestationPeer::PSC1;
		}

		return $this;
	} // setPsc1()

	/**
	 * Set the value of [maitrise] column.
	 * maitrise o/n
	 * @param      string $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setMaitrise($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->maitrise !== $v || $v === '') {
			$this->maitrise = $v;
			$this->modifiedColumns[] = AttestationPeer::MAITRISE;
		}

		return $this;
	} // setMaitrise()

	/**
	 * Set the value of [rne] column.
	 * Rne de l'etablissement
	 * @param      string $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = AttestationPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation
	 * @param      int $v new value
	 * @return     Attestation The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v) {
			$this->created_on = $v;
			$this->modifiedColumns[] = AttestationPeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(AttestationPeer::ASSR1,AttestationPeer::ASSR2,AttestationPeer::PSC1,AttestationPeer::MAITRISE))) {
				return false;
			}

			if ($this->assr1 !== '') {
				return false;
			}

			if ($this->assr2 !== '') {
				return false;
			}

			if ($this->psc1 !== '') {
				return false;
			}

			if ($this->maitrise !== '') {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->eleve_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->pallier = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->assr1 = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->assr2 = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->psc1 = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->maitrise = ($row[$startcol + 6] !== null) ? (string) $row[$startcol + 6] : null;
			$this->rne = ($row[$startcol + 7] !== null) ? (string) $row[$startcol + 7] : null;
			$this->created_on = ($row[$startcol + 8] !== null) ? (int) $row[$startcol + 8] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 9; // 9 = AttestationPeer::NUM_COLUMNS - AttestationPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Attestation object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aUtilisateur !== null && $this->eleve_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AttestationPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = AttestationPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aUtilisateur = null;
			$this->collJAttestationItems = null;
			$this->lastJAttestationItemCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AttestationPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			AttestationPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(AttestationPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			AttestationPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = AttestationPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = AttestationPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += AttestationPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJAttestationItems !== null) {
				foreach ($this->collJAttestationItems as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}


			if (($retval = AttestationPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJAttestationItems !== null) {
					foreach ($this->collJAttestationItems as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = AttestationPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getEleveId();
				break;
			case 2:
				return $this->getPallier();
				break;
			case 3:
				return $this->getAssr1();
				break;
			case 4:
				return $this->getAssr2();
				break;
			case 5:
				return $this->getPsc1();
				break;
			case 6:
				return $this->getMaitrise();
				break;
			case 7:
				return $this->getRne();
				break;
			case 8:
				return $this->getCreatedOn();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = AttestationPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getEleveId(),
			$keys[2] => $this->getPallier(),
			$keys[3] => $this->getAssr1(),
			$keys[4] => $this->getAssr2(),
			$keys[5] => $this->getPsc1(),
			$keys[6] => $this->getMaitrise(),
			$keys[7] => $this->getRne(),
			$keys[8] => $this->getCreatedOn(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = AttestationPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setEleveId($value);
				break;
			case 2:
				$this->setPallier($value);
				break;
			case 3:
				$this->setAssr1($value);
				break;
			case 4:
				$this->setAssr2($value);
				break;
			case 5:
				$this->setPsc1($value);
				break;
			case 6:
				$this->setMaitrise($value);
				break;
			case 7:
				$this->setRne($value);
				break;
			case 8:
				$this->setCreatedOn($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = AttestationPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setEleveId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setPallier($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setAssr1($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setAssr2($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setPsc1($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setMaitrise($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setRne($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setCreatedOn($arr[$keys[8]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(AttestationPeer::DATABASE_NAME);

		if ($this->isColumnModified(AttestationPeer::ID)) $criteria->add(AttestationPeer::ID, $this->id);
		if ($this->isColumnModified(AttestationPeer::ELEVE_ID)) $criteria->add(AttestationPeer::ELEVE_ID, $this->eleve_id);
		if ($this->isColumnModified(AttestationPeer::PALLIER)) $criteria->add(AttestationPeer::PALLIER, $this->pallier);
		if ($this->isColumnModified(AttestationPeer::ASSR1)) $criteria->add(AttestationPeer::ASSR1, $this->assr1);
		if ($this->isColumnModified(AttestationPeer::ASSR2)) $criteria->add(AttestationPeer::ASSR2, $this->assr2);
		if ($this->isColumnModified(AttestationPeer::PSC1)) $criteria->add(AttestationPeer::PSC1, $this->psc1);
		if ($this->isColumnModified(AttestationPeer::MAITRISE)) $criteria->add(AttestationPeer::MAITRISE, $this->maitrise);
		if ($this->isColumnModified(AttestationPeer::RNE)) $criteria->add(AttestationPeer::RNE, $this->rne);
		if ($this->isColumnModified(AttestationPeer::CREATED_ON)) $criteria->add(AttestationPeer::CREATED_ON, $this->created_on);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(AttestationPeer::DATABASE_NAME);

		$criteria->add(AttestationPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Attestation (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setEleveId($this->eleve_id);

		$copyObj->setPallier($this->pallier);

		$copyObj->setAssr1($this->assr1);

		$copyObj->setAssr2($this->assr2);

		$copyObj->setPsc1($this->psc1);

		$copyObj->setMaitrise($this->maitrise);

		$copyObj->setRne($this->rne);

		$copyObj->setCreatedOn($this->created_on);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJAttestationItems() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJAttestationItem($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Attestation Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     AttestationPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new AttestationPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Attestation The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setEleveId(NULL);
		} else {
			$this->setEleveId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addAttestation($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->eleve_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->eleve_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addAttestations($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Clears out the collJAttestationItems collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJAttestationItems()
	 */
	public function clearJAttestationItems()
	{
		$this->collJAttestationItems = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJAttestationItems collection (array).
	 *
	 * By default this just sets the collJAttestationItems collection to an empty array (like clearcollJAttestationItems());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJAttestationItems()
	{
		$this->collJAttestationItems = array();
	}

	/**
	 * Gets an array of JAttestationItem objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Attestation has previously been saved, it will retrieve
	 * related JAttestationItems from storage. If this Attestation is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JAttestationItem[]
	 * @throws     PropelException
	 */
	public function getJAttestationItems($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AttestationPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
			   $this->collJAttestationItems = array();
			} else {

				$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

				JAttestationItemPeer::addSelectColumns($criteria);
				$this->collJAttestationItems = JAttestationItemPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

				JAttestationItemPeer::addSelectColumns($criteria);
				if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
					$this->collJAttestationItems = JAttestationItemPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;
		return $this->collJAttestationItems;
	}

	/**
	 * Returns the number of related JAttestationItem objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JAttestationItem objects.
	 * @throws     PropelException
	 */
	public function countJAttestationItems(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AttestationPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

				$count = JAttestationItemPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

				if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
					$count = JAttestationItemPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJAttestationItems);
				}
			} else {
				$count = count($this->collJAttestationItems);
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JAttestationItem object to this object
	 * through the JAttestationItem foreign key attribute.
	 *
	 * @param      JAttestationItem $l JAttestationItem
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJAttestationItem(JAttestationItem $l)
	{
		if ($this->collJAttestationItems === null) {
			$this->initJAttestationItems();
		}
		if (!in_array($l, $this->collJAttestationItems, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJAttestationItems, $l);
			$l->setAttestation($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Attestation is new, it will return
	 * an empty collection; or if this Attestation has previously
	 * been saved, it will retrieve related JAttestationItems from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Attestation.
	 */
	public function getJAttestationItemsJoinCompetenceGrp($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(AttestationPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJAttestationItems === null) {
			if ($this->isNew()) {
				$this->collJAttestationItems = array();
			} else {

				$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

				$this->collJAttestationItems = JAttestationItemPeer::doSelectJoinCompetenceGrp($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JAttestationItemPeer::ATTESTATION_ID, $this->id);

			if (!isset($this->lastJAttestationItemCriteria) || !$this->lastJAttestationItemCriteria->equals($criteria)) {
				$this->collJAttestationItems = JAttestationItemPeer::doSelectJoinCompetenceGrp($criteria, $con, $join_behavior);
			}
		}
		$this->lastJAttestationItemCriteria = $criteria;

		return $this->collJAttestationItems;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJAttestationItems) {
				foreach ((array) $this->collJAttestationItems as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJAttestationItems = null;
			$this->aUtilisateur = null;
	}

} // BaseAttestation
