<?php

/**
 * Base class that represents a row from the 'competences' table.
 *
 * Liste des competences evaluees
 *
 * @package    competencesrb.om
 */
abstract class BaseCompetence extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        CompetencePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the nomcourt field.
	 * @var        string
	 */
	protected $nomcourt;

	/**
	 * The value for the nomlong field.
	 * @var        string
	 */
	protected $nomlong;

	/**
	 * The value for the rne field.
	 * Note: this column has a database default value of: 'all'
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the cptcegrp_id field.
	 * @var        int
	 */
	protected $cptcegrp_id;

	/**
	 * The value for the competence_id field.
	 * Note: this column has a database default value of: 0
	 * @var        int
	 */
	protected $competence_id;

	/**
	 * The value for the type field.
	 * Note: this column has a database default value of: 'perso'
	 * @var        string
	 */
	protected $type;

	/**
	 * The value for the niveau field.
	 * Note: this column has a database default value of: 3
	 * @var        int
	 */
	protected $niveau;

	/**
	 * The value for the utilisateur_id field.
	 * Note: this column has a database default value of: 0
	 * @var        int
	 */
	protected $utilisateur_id;

	/**
	 * @var        CompetenceGrp
	 */
	protected $aCompetenceGrp;

	/**
	 * @var        Competence
	 */
	protected $aCompetenceRelatedByCompetenceId;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * @var        array Competence[] Collection to store aggregation of Competence objects.
	 */
	protected $collCompetencesRelatedByCompetenceId;

	/**
	 * @var        Criteria The criteria used to select the current contents of collCompetencesRelatedByCompetenceId.
	 */
	private $lastCompetenceRelatedByCompetenceIdCriteria = null;

	/**
	 * @var        array JCompetencesProfesseurs[] Collection to store aggregation of JCompetencesProfesseurs objects.
	 */
	protected $collJCompetencesProfesseurss;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetencesProfesseurss.
	 */
	private $lastJCompetencesProfesseursCriteria = null;

	/**
	 * @var        array JCompetenceVisible[] Collection to store aggregation of JCompetenceVisible objects.
	 */
	protected $collJCompetenceVisibles;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetenceVisibles.
	 */
	private $lastJCompetenceVisibleCriteria = null;

	/**
	 * @var        array JGrilleCompetence[] Collection to store aggregation of JGrilleCompetence objects.
	 */
	protected $collJGrilleCompetences;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJGrilleCompetences.
	 */
	private $lastJGrilleCompetenceCriteria = null;

	/**
	 * @var        array JControleResultat[] Collection to store aggregation of JControleResultat objects.
	 */
	protected $collJControleResultats;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJControleResultats.
	 */
	private $lastJControleResultatCriteria = null;

	/**
	 * @var        array JBulletinTransversales[] Collection to store aggregation of JBulletinTransversales objects.
	 */
	protected $collJBulletinTransversaless;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJBulletinTransversaless.
	 */
	private $lastJBulletinTransversalesCriteria = null;

	/**
	 * @var        array Bilan[] Collection to store aggregation of Bilan objects.
	 */
	protected $collBilans;

	/**
	 * @var        Criteria The criteria used to select the current contents of collBilans.
	 */
	private $lastBilanCriteria = null;

	/**
	 * @var        array JCompetenceRessources[] Collection to store aggregation of JCompetenceRessources objects.
	 */
	protected $collJCompetenceRessourcess;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJCompetenceRessourcess.
	 */
	private $lastJCompetenceRessourcesCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseCompetence object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->rne = 'all';
		$this->competence_id = 0;
		$this->type = 'perso';
		$this->niveau = 3;
		$this->utilisateur_id = 0;
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table competences
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [nomcourt] column value.
	 * Nom court de la competence
	 * @return     string
	 */
	public function getNomcourt()
	{
		return $this->nomcourt;
	}

	/**
	 * Get the [nomlong] column value.
	 * Nom long de la competence
	 * @return     string
	 */
	public function getNomlong()
	{
		return $this->nomlong;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de la cptce, all si pour tous etab
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [cptcegrp_id] column value.
	 * Domaine de la competence
	 * @return     int
	 */
	public function getCptcegrpId()
	{
		return $this->cptcegrp_id;
	}

	/**
	 * Get the [competence_id] column value.
	 * Permet de lier des competences entre elles
	 * @return     int
	 */
	public function getCompetenceId()
	{
		return $this->competence_id;
	}

	/**
	 * Get the [type] column value.
	 * Type de competence :tronc peda perso
	 * @return     string
	 */
	public function getType()
	{
		return $this->type;
	}

	/**
	 * Get the [niveau] column value.
	 * Niveau de hiérarchie des competences : 1 = socle, 2 = derivee du socle, 3 = les autres
	 * @return     int
	 */
	public function getNiveau()
	{
		return $this->niveau;
	}

	/**
	 * Get the [utilisateur_id] column value.
	 * cle etrangere de l'utilisateur dans le cas d'une competence perso
	 * @return     int
	 */
	public function getUtilisateurId()
	{
		return $this->utilisateur_id;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table competences
	 * @param      int $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = CompetencePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [nomcourt] column.
	 * Nom court de la competence
	 * @param      string $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setNomcourt($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomcourt !== $v) {
			$this->nomcourt = $v;
			$this->modifiedColumns[] = CompetencePeer::NOMCOURT;
		}

		return $this;
	} // setNomcourt()

	/**
	 * Set the value of [nomlong] column.
	 * Nom long de la competence
	 * @param      string $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setNomlong($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nomlong !== $v) {
			$this->nomlong = $v;
			$this->modifiedColumns[] = CompetencePeer::NOMLONG;
		}

		return $this;
	} // setNomlong()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de la cptce, all si pour tous etab
	 * @param      string $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v || $v === 'all') {
			$this->rne = $v;
			$this->modifiedColumns[] = CompetencePeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [cptcegrp_id] column.
	 * Domaine de la competence
	 * @param      int $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setCptcegrpId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->cptcegrp_id !== $v) {
			$this->cptcegrp_id = $v;
			$this->modifiedColumns[] = CompetencePeer::CPTCEGRP_ID;
		}

		if ($this->aCompetenceGrp !== null && $this->aCompetenceGrp->getId() !== $v) {
			$this->aCompetenceGrp = null;
		}

		return $this;
	} // setCptcegrpId()

	/**
	 * Set the value of [competence_id] column.
	 * Permet de lier des competences entre elles
	 * @param      int $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setCompetenceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->competence_id !== $v || $v === 0) {
			$this->competence_id = $v;
			$this->modifiedColumns[] = CompetencePeer::COMPETENCE_ID;
		}

		if ($this->aCompetenceRelatedByCompetenceId !== null && $this->aCompetenceRelatedByCompetenceId->getId() !== $v) {
			$this->aCompetenceRelatedByCompetenceId = null;
		}

		return $this;
	} // setCompetenceId()

	/**
	 * Set the value of [type] column.
	 * Type de competence :tronc peda perso
	 * @param      string $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setType($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->type !== $v || $v === 'perso') {
			$this->type = $v;
			$this->modifiedColumns[] = CompetencePeer::TYPE;
		}

		return $this;
	} // setType()

	/**
	 * Set the value of [niveau] column.
	 * Niveau de hiérarchie des competences : 1 = socle, 2 = derivee du socle, 3 = les autres
	 * @param      int $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setNiveau($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->niveau !== $v || $v === 3) {
			$this->niveau = $v;
			$this->modifiedColumns[] = CompetencePeer::NIVEAU;
		}

		return $this;
	} // setNiveau()

	/**
	 * Set the value of [utilisateur_id] column.
	 * cle etrangere de l'utilisateur dans le cas d'une competence perso
	 * @param      int $v new value
	 * @return     Competence The current object (for fluent API support)
	 */
	public function setUtilisateurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->utilisateur_id !== $v || $v === 0) {
			$this->utilisateur_id = $v;
			$this->modifiedColumns[] = CompetencePeer::UTILISATEUR_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setUtilisateurId()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(CompetencePeer::RNE,CompetencePeer::COMPETENCE_ID,CompetencePeer::TYPE,CompetencePeer::NIVEAU,CompetencePeer::UTILISATEUR_ID))) {
				return false;
			}

			if ($this->rne !== 'all') {
				return false;
			}

			if ($this->competence_id !== 0) {
				return false;
			}

			if ($this->type !== 'perso') {
				return false;
			}

			if ($this->niveau !== 3) {
				return false;
			}

			if ($this->utilisateur_id !== 0) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->nomcourt = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->nomlong = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->rne = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->cptcegrp_id = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->competence_id = ($row[$startcol + 5] !== null) ? (int) $row[$startcol + 5] : null;
			$this->type = ($row[$startcol + 6] !== null) ? (string) $row[$startcol + 6] : null;
			$this->niveau = ($row[$startcol + 7] !== null) ? (int) $row[$startcol + 7] : null;
			$this->utilisateur_id = ($row[$startcol + 8] !== null) ? (int) $row[$startcol + 8] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 9; // 9 = CompetencePeer::NUM_COLUMNS - CompetencePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Competence object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aCompetenceGrp !== null && $this->cptcegrp_id !== $this->aCompetenceGrp->getId()) {
			$this->aCompetenceGrp = null;
		}
		if ($this->aCompetenceRelatedByCompetenceId !== null && $this->competence_id !== $this->aCompetenceRelatedByCompetenceId->getId()) {
			$this->aCompetenceRelatedByCompetenceId = null;
		}
		if ($this->aUtilisateur !== null && $this->utilisateur_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetencePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = CompetencePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aCompetenceGrp = null;
			$this->aCompetenceRelatedByCompetenceId = null;
			$this->aUtilisateur = null;
			$this->collCompetencesRelatedByCompetenceId = null;
			$this->lastCompetenceRelatedByCompetenceIdCriteria = null;

			$this->collJCompetencesProfesseurss = null;
			$this->lastJCompetencesProfesseursCriteria = null;

			$this->collJCompetenceVisibles = null;
			$this->lastJCompetenceVisibleCriteria = null;

			$this->collJGrilleCompetences = null;
			$this->lastJGrilleCompetenceCriteria = null;

			$this->collJControleResultats = null;
			$this->lastJControleResultatCriteria = null;

			$this->collJBulletinTransversaless = null;
			$this->lastJBulletinTransversalesCriteria = null;

			$this->collBilans = null;
			$this->lastBilanCriteria = null;

			$this->collJCompetenceRessourcess = null;
			$this->lastJCompetenceRessourcesCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetencePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			CompetencePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(CompetencePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			CompetencePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aCompetenceGrp !== null) {
				if ($this->aCompetenceGrp->isModified() || $this->aCompetenceGrp->isNew()) {
					$affectedRows += $this->aCompetenceGrp->save($con);
				}
				$this->setCompetenceGrp($this->aCompetenceGrp);
			}

			if ($this->aCompetenceRelatedByCompetenceId !== null) {
				if ($this->aCompetenceRelatedByCompetenceId->isModified() || $this->aCompetenceRelatedByCompetenceId->isNew()) {
					$affectedRows += $this->aCompetenceRelatedByCompetenceId->save($con);
				}
				$this->setCompetenceRelatedByCompetenceId($this->aCompetenceRelatedByCompetenceId);
			}

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = CompetencePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = CompetencePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += CompetencePeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collCompetencesRelatedByCompetenceId !== null) {
				foreach ($this->collCompetencesRelatedByCompetenceId as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetencesProfesseurss !== null) {
				foreach ($this->collJCompetencesProfesseurss as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetenceVisibles !== null) {
				foreach ($this->collJCompetenceVisibles as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJGrilleCompetences !== null) {
				foreach ($this->collJGrilleCompetences as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJControleResultats !== null) {
				foreach ($this->collJControleResultats as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJBulletinTransversaless !== null) {
				foreach ($this->collJBulletinTransversaless as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collBilans !== null) {
				foreach ($this->collBilans as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collJCompetenceRessourcess !== null) {
				foreach ($this->collJCompetenceRessourcess as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aCompetenceGrp !== null) {
				if (!$this->aCompetenceGrp->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCompetenceGrp->getValidationFailures());
				}
			}

			if ($this->aCompetenceRelatedByCompetenceId !== null) {
				if (!$this->aCompetenceRelatedByCompetenceId->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCompetenceRelatedByCompetenceId->getValidationFailures());
				}
			}

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}


			if (($retval = CompetencePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collCompetencesRelatedByCompetenceId !== null) {
					foreach ($this->collCompetencesRelatedByCompetenceId as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetencesProfesseurss !== null) {
					foreach ($this->collJCompetencesProfesseurss as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetenceVisibles !== null) {
					foreach ($this->collJCompetenceVisibles as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJGrilleCompetences !== null) {
					foreach ($this->collJGrilleCompetences as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJControleResultats !== null) {
					foreach ($this->collJControleResultats as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJBulletinTransversaless !== null) {
					foreach ($this->collJBulletinTransversaless as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collBilans !== null) {
					foreach ($this->collBilans as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collJCompetenceRessourcess !== null) {
					foreach ($this->collJCompetenceRessourcess as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = CompetencePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getNomcourt();
				break;
			case 2:
				return $this->getNomlong();
				break;
			case 3:
				return $this->getRne();
				break;
			case 4:
				return $this->getCptcegrpId();
				break;
			case 5:
				return $this->getCompetenceId();
				break;
			case 6:
				return $this->getType();
				break;
			case 7:
				return $this->getNiveau();
				break;
			case 8:
				return $this->getUtilisateurId();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = CompetencePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getNomcourt(),
			$keys[2] => $this->getNomlong(),
			$keys[3] => $this->getRne(),
			$keys[4] => $this->getCptcegrpId(),
			$keys[5] => $this->getCompetenceId(),
			$keys[6] => $this->getType(),
			$keys[7] => $this->getNiveau(),
			$keys[8] => $this->getUtilisateurId(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = CompetencePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setNomcourt($value);
				break;
			case 2:
				$this->setNomlong($value);
				break;
			case 3:
				$this->setRne($value);
				break;
			case 4:
				$this->setCptcegrpId($value);
				break;
			case 5:
				$this->setCompetenceId($value);
				break;
			case 6:
				$this->setType($value);
				break;
			case 7:
				$this->setNiveau($value);
				break;
			case 8:
				$this->setUtilisateurId($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = CompetencePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setNomcourt($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setNomlong($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setRne($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setCptcegrpId($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setCompetenceId($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setType($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setNiveau($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setUtilisateurId($arr[$keys[8]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(CompetencePeer::DATABASE_NAME);

		if ($this->isColumnModified(CompetencePeer::ID)) $criteria->add(CompetencePeer::ID, $this->id);
		if ($this->isColumnModified(CompetencePeer::NOMCOURT)) $criteria->add(CompetencePeer::NOMCOURT, $this->nomcourt);
		if ($this->isColumnModified(CompetencePeer::NOMLONG)) $criteria->add(CompetencePeer::NOMLONG, $this->nomlong);
		if ($this->isColumnModified(CompetencePeer::RNE)) $criteria->add(CompetencePeer::RNE, $this->rne);
		if ($this->isColumnModified(CompetencePeer::CPTCEGRP_ID)) $criteria->add(CompetencePeer::CPTCEGRP_ID, $this->cptcegrp_id);
		if ($this->isColumnModified(CompetencePeer::COMPETENCE_ID)) $criteria->add(CompetencePeer::COMPETENCE_ID, $this->competence_id);
		if ($this->isColumnModified(CompetencePeer::TYPE)) $criteria->add(CompetencePeer::TYPE, $this->type);
		if ($this->isColumnModified(CompetencePeer::NIVEAU)) $criteria->add(CompetencePeer::NIVEAU, $this->niveau);
		if ($this->isColumnModified(CompetencePeer::UTILISATEUR_ID)) $criteria->add(CompetencePeer::UTILISATEUR_ID, $this->utilisateur_id);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(CompetencePeer::DATABASE_NAME);

		$criteria->add(CompetencePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Competence (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setNomcourt($this->nomcourt);

		$copyObj->setNomlong($this->nomlong);

		$copyObj->setRne($this->rne);

		$copyObj->setCptcegrpId($this->cptcegrp_id);

		$copyObj->setCompetenceId($this->competence_id);

		$copyObj->setType($this->type);

		$copyObj->setNiveau($this->niveau);

		$copyObj->setUtilisateurId($this->utilisateur_id);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getCompetencesRelatedByCompetenceId() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addCompetenceRelatedByCompetenceId($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetencesProfesseurss() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetencesProfesseurs($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetenceVisibles() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetenceVisible($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJGrilleCompetences() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJGrilleCompetence($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJControleResultats() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJControleResultat($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJBulletinTransversaless() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJBulletinTransversales($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getBilans() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addBilan($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getJCompetenceRessourcess() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJCompetenceRessources($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Competence Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     CompetencePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new CompetencePeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a CompetenceGrp object.
	 *
	 * @param      CompetenceGrp $v
	 * @return     Competence The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setCompetenceGrp(CompetenceGrp $v = null)
	{
		if ($v === null) {
			$this->setCptcegrpId(NULL);
		} else {
			$this->setCptcegrpId($v->getId());
		}

		$this->aCompetenceGrp = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the CompetenceGrp object, it will not be re-added.
		if ($v !== null) {
			$v->addCompetence($this);
		}

		return $this;
	}


	/**
	 * Get the associated CompetenceGrp object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     CompetenceGrp The associated CompetenceGrp object.
	 * @throws     PropelException
	 */
	public function getCompetenceGrp(PropelPDO $con = null)
	{
		if ($this->aCompetenceGrp === null && ($this->cptcegrp_id !== null)) {
			$this->aCompetenceGrp = CompetenceGrpPeer::retrieveByPK($this->cptcegrp_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aCompetenceGrp->addCompetences($this);
			 */
		}
		return $this->aCompetenceGrp;
	}

	/**
	 * Declares an association between this object and a Competence object.
	 *
	 * @param      Competence $v
	 * @return     Competence The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setCompetenceRelatedByCompetenceId(Competence $v = null)
	{
		if ($v === null) {
			$this->setCompetenceId(0);
		} else {
			$this->setCompetenceId($v->getId());
		}

		$this->aCompetenceRelatedByCompetenceId = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Competence object, it will not be re-added.
		if ($v !== null) {
			$v->addCompetenceRelatedByCompetenceId($this);
		}

		return $this;
	}


	/**
	 * Get the associated Competence object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Competence The associated Competence object.
	 * @throws     PropelException
	 */
	public function getCompetenceRelatedByCompetenceId(PropelPDO $con = null)
	{
		if ($this->aCompetenceRelatedByCompetenceId === null && ($this->competence_id !== null)) {
			$this->aCompetenceRelatedByCompetenceId = CompetencePeer::retrieveByPK($this->competence_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aCompetenceRelatedByCompetenceId->addCompetencesRelatedByCompetenceId($this);
			 */
		}
		return $this->aCompetenceRelatedByCompetenceId;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Competence The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setUtilisateurId(0);
		} else {
			$this->setUtilisateurId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addCompetence($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->utilisateur_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->utilisateur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addCompetences($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Clears out the collCompetencesRelatedByCompetenceId collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addCompetencesRelatedByCompetenceId()
	 */
	public function clearCompetencesRelatedByCompetenceId()
	{
		$this->collCompetencesRelatedByCompetenceId = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collCompetencesRelatedByCompetenceId collection (array).
	 *
	 * By default this just sets the collCompetencesRelatedByCompetenceId collection to an empty array (like clearcollCompetencesRelatedByCompetenceId());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initCompetencesRelatedByCompetenceId()
	{
		$this->collCompetencesRelatedByCompetenceId = array();
	}

	/**
	 * Gets an array of Competence objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related CompetencesRelatedByCompetenceId from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Competence[]
	 * @throws     PropelException
	 */
	public function getCompetencesRelatedByCompetenceId($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetencesRelatedByCompetenceId === null) {
			if ($this->isNew()) {
			   $this->collCompetencesRelatedByCompetenceId = array();
			} else {

				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				CompetencePeer::addSelectColumns($criteria);
				$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				CompetencePeer::addSelectColumns($criteria);
				if (!isset($this->lastCompetenceRelatedByCompetenceIdCriteria) || !$this->lastCompetenceRelatedByCompetenceIdCriteria->equals($criteria)) {
					$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastCompetenceRelatedByCompetenceIdCriteria = $criteria;
		return $this->collCompetencesRelatedByCompetenceId;
	}

	/**
	 * Returns the number of related Competence objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Competence objects.
	 * @throws     PropelException
	 */
	public function countCompetencesRelatedByCompetenceId(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collCompetencesRelatedByCompetenceId === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				$count = CompetencePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastCompetenceRelatedByCompetenceIdCriteria) || !$this->lastCompetenceRelatedByCompetenceIdCriteria->equals($criteria)) {
					$count = CompetencePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collCompetencesRelatedByCompetenceId);
				}
			} else {
				$count = count($this->collCompetencesRelatedByCompetenceId);
			}
		}
		$this->lastCompetenceRelatedByCompetenceIdCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Competence object to this object
	 * through the Competence foreign key attribute.
	 *
	 * @param      Competence $l Competence
	 * @return     void
	 * @throws     PropelException
	 */
	public function addCompetenceRelatedByCompetenceId(Competence $l)
	{
		if ($this->collCompetencesRelatedByCompetenceId === null) {
			$this->initCompetencesRelatedByCompetenceId();
		}
		if (!in_array($l, $this->collCompetencesRelatedByCompetenceId, true)) { // only add it if the **same** object is not already associated
			array_push($this->collCompetencesRelatedByCompetenceId, $l);
			$l->setCompetenceRelatedByCompetenceId($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related CompetencesRelatedByCompetenceId from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getCompetencesRelatedByCompetenceIdJoinCompetenceGrp($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetencesRelatedByCompetenceId === null) {
			if ($this->isNew()) {
				$this->collCompetencesRelatedByCompetenceId = array();
			} else {

				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelectJoinCompetenceGrp($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastCompetenceRelatedByCompetenceIdCriteria) || !$this->lastCompetenceRelatedByCompetenceIdCriteria->equals($criteria)) {
				$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelectJoinCompetenceGrp($criteria, $con, $join_behavior);
			}
		}
		$this->lastCompetenceRelatedByCompetenceIdCriteria = $criteria;

		return $this->collCompetencesRelatedByCompetenceId;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related CompetencesRelatedByCompetenceId from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getCompetencesRelatedByCompetenceIdJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collCompetencesRelatedByCompetenceId === null) {
			if ($this->isNew()) {
				$this->collCompetencesRelatedByCompetenceId = array();
			} else {

				$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

				$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(CompetencePeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastCompetenceRelatedByCompetenceIdCriteria) || !$this->lastCompetenceRelatedByCompetenceIdCriteria->equals($criteria)) {
				$this->collCompetencesRelatedByCompetenceId = CompetencePeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastCompetenceRelatedByCompetenceIdCriteria = $criteria;

		return $this->collCompetencesRelatedByCompetenceId;
	}

	/**
	 * Clears out the collJCompetencesProfesseurss collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetencesProfesseurss()
	 */
	public function clearJCompetencesProfesseurss()
	{
		$this->collJCompetencesProfesseurss = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetencesProfesseurss collection (array).
	 *
	 * By default this just sets the collJCompetencesProfesseurss collection to an empty array (like clearcollJCompetencesProfesseurss());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetencesProfesseurss()
	{
		$this->collJCompetencesProfesseurss = array();
	}

	/**
	 * Gets an array of JCompetencesProfesseurs objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JCompetencesProfesseurss from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetencesProfesseurs[]
	 * @throws     PropelException
	 */
	public function getJCompetencesProfesseurss($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetencesProfesseurss === null) {
			if ($this->isNew()) {
			   $this->collJCompetencesProfesseurss = array();
			} else {

				$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

				JCompetencesProfesseursPeer::addSelectColumns($criteria);
				$this->collJCompetencesProfesseurss = JCompetencesProfesseursPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

				JCompetencesProfesseursPeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetencesProfesseursCriteria) || !$this->lastJCompetencesProfesseursCriteria->equals($criteria)) {
					$this->collJCompetencesProfesseurss = JCompetencesProfesseursPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetencesProfesseursCriteria = $criteria;
		return $this->collJCompetencesProfesseurss;
	}

	/**
	 * Returns the number of related JCompetencesProfesseurs objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetencesProfesseurs objects.
	 * @throws     PropelException
	 */
	public function countJCompetencesProfesseurss(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetencesProfesseurss === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

				$count = JCompetencesProfesseursPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJCompetencesProfesseursCriteria) || !$this->lastJCompetencesProfesseursCriteria->equals($criteria)) {
					$count = JCompetencesProfesseursPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetencesProfesseurss);
				}
			} else {
				$count = count($this->collJCompetencesProfesseurss);
			}
		}
		$this->lastJCompetencesProfesseursCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetencesProfesseurs object to this object
	 * through the JCompetencesProfesseurs foreign key attribute.
	 *
	 * @param      JCompetencesProfesseurs $l JCompetencesProfesseurs
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetencesProfesseurs(JCompetencesProfesseurs $l)
	{
		if ($this->collJCompetencesProfesseurss === null) {
			$this->initJCompetencesProfesseurss();
		}
		if (!in_array($l, $this->collJCompetencesProfesseurss, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetencesProfesseurss, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JCompetencesProfesseurss from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJCompetencesProfesseurssJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetencesProfesseurss === null) {
			if ($this->isNew()) {
				$this->collJCompetencesProfesseurss = array();
			} else {

				$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

				$this->collJCompetencesProfesseurss = JCompetencesProfesseursPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetencesProfesseursPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJCompetencesProfesseursCriteria) || !$this->lastJCompetencesProfesseursCriteria->equals($criteria)) {
				$this->collJCompetencesProfesseurss = JCompetencesProfesseursPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetencesProfesseursCriteria = $criteria;

		return $this->collJCompetencesProfesseurss;
	}

	/**
	 * Clears out the collJCompetenceVisibles collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetenceVisibles()
	 */
	public function clearJCompetenceVisibles()
	{
		$this->collJCompetenceVisibles = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetenceVisibles collection (array).
	 *
	 * By default this just sets the collJCompetenceVisibles collection to an empty array (like clearcollJCompetenceVisibles());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetenceVisibles()
	{
		$this->collJCompetenceVisibles = array();
	}

	/**
	 * Gets an array of JCompetenceVisible objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JCompetenceVisibles from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetenceVisible[]
	 * @throws     PropelException
	 */
	public function getJCompetenceVisibles($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
			   $this->collJCompetenceVisibles = array();
			} else {

				$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

				JCompetenceVisiblePeer::addSelectColumns($criteria);
				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

				JCompetenceVisiblePeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
					$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;
		return $this->collJCompetenceVisibles;
	}

	/**
	 * Returns the number of related JCompetenceVisible objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetenceVisible objects.
	 * @throws     PropelException
	 */
	public function countJCompetenceVisibles(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

				$count = JCompetenceVisiblePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
					$count = JCompetenceVisiblePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetenceVisibles);
				}
			} else {
				$count = count($this->collJCompetenceVisibles);
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetenceVisible object to this object
	 * through the JCompetenceVisible foreign key attribute.
	 *
	 * @param      JCompetenceVisible $l JCompetenceVisible
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetenceVisible(JCompetenceVisible $l)
	{
		if ($this->collJCompetenceVisibles === null) {
			$this->initJCompetenceVisibles();
		}
		if (!in_array($l, $this->collJCompetenceVisibles, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetenceVisibles, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JCompetenceVisibles from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJCompetenceVisiblesJoinetablissement($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceVisibles === null) {
			if ($this->isNew()) {
				$this->collJCompetenceVisibles = array();
			} else {

				$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceVisiblePeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJCompetenceVisibleCriteria) || !$this->lastJCompetenceVisibleCriteria->equals($criteria)) {
				$this->collJCompetenceVisibles = JCompetenceVisiblePeer::doSelectJoinetablissement($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceVisibleCriteria = $criteria;

		return $this->collJCompetenceVisibles;
	}

	/**
	 * Clears out the collJGrilleCompetences collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJGrilleCompetences()
	 */
	public function clearJGrilleCompetences()
	{
		$this->collJGrilleCompetences = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJGrilleCompetences collection (array).
	 *
	 * By default this just sets the collJGrilleCompetences collection to an empty array (like clearcollJGrilleCompetences());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJGrilleCompetences()
	{
		$this->collJGrilleCompetences = array();
	}

	/**
	 * Gets an array of JGrilleCompetence objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JGrilleCompetences from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JGrilleCompetence[]
	 * @throws     PropelException
	 */
	public function getJGrilleCompetences($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
			   $this->collJGrilleCompetences = array();
			} else {

				$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

				JGrilleCompetencePeer::addSelectColumns($criteria);
				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

				JGrilleCompetencePeer::addSelectColumns($criteria);
				if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
					$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;
		return $this->collJGrilleCompetences;
	}

	/**
	 * Returns the number of related JGrilleCompetence objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JGrilleCompetence objects.
	 * @throws     PropelException
	 */
	public function countJGrilleCompetences(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

				$count = JGrilleCompetencePeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
					$count = JGrilleCompetencePeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJGrilleCompetences);
				}
			} else {
				$count = count($this->collJGrilleCompetences);
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JGrilleCompetence object to this object
	 * through the JGrilleCompetence foreign key attribute.
	 *
	 * @param      JGrilleCompetence $l JGrilleCompetence
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJGrilleCompetence(JGrilleCompetence $l)
	{
		if ($this->collJGrilleCompetences === null) {
			$this->initJGrilleCompetences();
		}
		if (!in_array($l, $this->collJGrilleCompetences, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJGrilleCompetences, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JGrilleCompetences from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJGrilleCompetencesJoinGrille($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJGrilleCompetences === null) {
			if ($this->isNew()) {
				$this->collJGrilleCompetences = array();
			} else {

				$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JGrilleCompetencePeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJGrilleCompetenceCriteria) || !$this->lastJGrilleCompetenceCriteria->equals($criteria)) {
				$this->collJGrilleCompetences = JGrilleCompetencePeer::doSelectJoinGrille($criteria, $con, $join_behavior);
			}
		}
		$this->lastJGrilleCompetenceCriteria = $criteria;

		return $this->collJGrilleCompetences;
	}

	/**
	 * Clears out the collJControleResultats collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJControleResultats()
	 */
	public function clearJControleResultats()
	{
		$this->collJControleResultats = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJControleResultats collection (array).
	 *
	 * By default this just sets the collJControleResultats collection to an empty array (like clearcollJControleResultats());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJControleResultats()
	{
		$this->collJControleResultats = array();
	}

	/**
	 * Gets an array of JControleResultat objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JControleResultats from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JControleResultat[]
	 * @throws     PropelException
	 */
	public function getJControleResultats($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
			   $this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				JControleResultatPeer::addSelectColumns($criteria);
				$this->collJControleResultats = JControleResultatPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				JControleResultatPeer::addSelectColumns($criteria);
				if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
					$this->collJControleResultats = JControleResultatPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJControleResultatCriteria = $criteria;
		return $this->collJControleResultats;
	}

	/**
	 * Returns the number of related JControleResultat objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JControleResultat objects.
	 * @throws     PropelException
	 */
	public function countJControleResultats(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				$count = JControleResultatPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
					$count = JControleResultatPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJControleResultats);
				}
			} else {
				$count = count($this->collJControleResultats);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JControleResultat object to this object
	 * through the JControleResultat foreign key attribute.
	 *
	 * @param      JControleResultat $l JControleResultat
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJControleResultat(JControleResultat $l)
	{
		if ($this->collJControleResultats === null) {
			$this->initJControleResultats();
		}
		if (!in_array($l, $this->collJControleResultats, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJControleResultats, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJControleResultatsJoinControle($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinControle($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinControle($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJControleResultatsJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJControleResultatsJoinValidationNiveau($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinValidationNiveau($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinValidationNiveau($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}

	/**
	 * Clears out the collJBulletinTransversaless collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJBulletinTransversaless()
	 */
	public function clearJBulletinTransversaless()
	{
		$this->collJBulletinTransversaless = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJBulletinTransversaless collection (array).
	 *
	 * By default this just sets the collJBulletinTransversaless collection to an empty array (like clearcollJBulletinTransversaless());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJBulletinTransversaless()
	{
		$this->collJBulletinTransversaless = array();
	}

	/**
	 * Gets an array of JBulletinTransversales objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JBulletinTransversaless from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JBulletinTransversales[]
	 * @throws     PropelException
	 */
	public function getJBulletinTransversaless($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
			   $this->collJBulletinTransversaless = array();
			} else {

				$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

				JBulletinTransversalesPeer::addSelectColumns($criteria);
				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

				JBulletinTransversalesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
					$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;
		return $this->collJBulletinTransversaless;
	}

	/**
	 * Returns the number of related JBulletinTransversales objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JBulletinTransversales objects.
	 * @throws     PropelException
	 */
	public function countJBulletinTransversaless(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

				$count = JBulletinTransversalesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
					$count = JBulletinTransversalesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJBulletinTransversaless);
				}
			} else {
				$count = count($this->collJBulletinTransversaless);
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JBulletinTransversales object to this object
	 * through the JBulletinTransversales foreign key attribute.
	 *
	 * @param      JBulletinTransversales $l JBulletinTransversales
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJBulletinTransversales(JBulletinTransversales $l)
	{
		if ($this->collJBulletinTransversaless === null) {
			$this->initJBulletinTransversaless();
		}
		if (!in_array($l, $this->collJBulletinTransversaless, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJBulletinTransversaless, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JBulletinTransversaless from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJBulletinTransversalessJoinBulletin($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJBulletinTransversaless === null) {
			if ($this->isNew()) {
				$this->collJBulletinTransversaless = array();
			} else {

				$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelectJoinBulletin($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JBulletinTransversalesPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJBulletinTransversalesCriteria) || !$this->lastJBulletinTransversalesCriteria->equals($criteria)) {
				$this->collJBulletinTransversaless = JBulletinTransversalesPeer::doSelectJoinBulletin($criteria, $con, $join_behavior);
			}
		}
		$this->lastJBulletinTransversalesCriteria = $criteria;

		return $this->collJBulletinTransversaless;
	}

	/**
	 * Clears out the collBilans collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addBilans()
	 */
	public function clearBilans()
	{
		$this->collBilans = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collBilans collection (array).
	 *
	 * By default this just sets the collBilans collection to an empty array (like clearcollBilans());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initBilans()
	{
		$this->collBilans = array();
	}

	/**
	 * Gets an array of Bilan objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related Bilans from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Bilan[]
	 * @throws     PropelException
	 */
	public function getBilans($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
			   $this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				BilanPeer::addSelectColumns($criteria);
				$this->collBilans = BilanPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				BilanPeer::addSelectColumns($criteria);
				if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
					$this->collBilans = BilanPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastBilanCriteria = $criteria;
		return $this->collBilans;
	}

	/**
	 * Returns the number of related Bilan objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Bilan objects.
	 * @throws     PropelException
	 */
	public function countBilans(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				$count = BilanPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
					$count = BilanPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collBilans);
				}
			} else {
				$count = count($this->collBilans);
			}
		}
		$this->lastBilanCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Bilan object to this object
	 * through the Bilan foreign key attribute.
	 *
	 * @param      Bilan $l Bilan
	 * @return     void
	 * @throws     PropelException
	 */
	public function addBilan(Bilan $l)
	{
		if ($this->collBilans === null) {
			$this->initBilans();
		}
		if (!in_array($l, $this->collBilans, true)) { // only add it if the **same** object is not already associated
			array_push($this->collBilans, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getBilansJoinUtilisateurRelatedByProfesseurId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getBilansJoinUtilisateurRelatedByEleveId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getBilansJoinValidationNiveau($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

				$this->collBilans = BilanPeer::doSelectJoinValidationNiveau($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinValidationNiveau($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}

	/**
	 * Clears out the collJCompetenceRessourcess collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJCompetenceRessourcess()
	 */
	public function clearJCompetenceRessourcess()
	{
		$this->collJCompetenceRessourcess = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJCompetenceRessourcess collection (array).
	 *
	 * By default this just sets the collJCompetenceRessourcess collection to an empty array (like clearcollJCompetenceRessourcess());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJCompetenceRessourcess()
	{
		$this->collJCompetenceRessourcess = array();
	}

	/**
	 * Gets an array of JCompetenceRessources objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this Competence has previously been saved, it will retrieve
	 * related JCompetenceRessourcess from storage. If this Competence is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JCompetenceRessources[]
	 * @throws     PropelException
	 */
	public function getJCompetenceRessourcess($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
			   $this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				JCompetenceRessourcesPeer::addSelectColumns($criteria);
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				JCompetenceRessourcesPeer::addSelectColumns($criteria);
				if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
					$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;
		return $this->collJCompetenceRessourcess;
	}

	/**
	 * Returns the number of related JCompetenceRessources objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JCompetenceRessources objects.
	 * @throws     PropelException
	 */
	public function countJCompetenceRessourcess(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				$count = JCompetenceRessourcesPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
					$count = JCompetenceRessourcesPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJCompetenceRessourcess);
				}
			} else {
				$count = count($this->collJCompetenceRessourcess);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JCompetenceRessources object to this object
	 * through the JCompetenceRessources foreign key attribute.
	 *
	 * @param      JCompetenceRessources $l JCompetenceRessources
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJCompetenceRessources(JCompetenceRessources $l)
	{
		if ($this->collJCompetenceRessourcess === null) {
			$this->initJCompetenceRessourcess();
		}
		if (!in_array($l, $this->collJCompetenceRessourcess, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJCompetenceRessourcess, $l);
			$l->setCompetence($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JCompetenceRessourcess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJCompetenceRessourcessJoinRessource($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinRessource($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinRessource($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;

		return $this->collJCompetenceRessourcess;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this Competence is new, it will return
	 * an empty collection; or if this Competence has previously
	 * been saved, it will retrieve related JCompetenceRessourcess from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in Competence.
	 */
	public function getJCompetenceRessourcessJoinMatiere($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(CompetencePeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJCompetenceRessourcess === null) {
			if ($this->isNew()) {
				$this->collJCompetenceRessourcess = array();
			} else {

				$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JCompetenceRessourcesPeer::COMPETENCE_ID, $this->id);

			if (!isset($this->lastJCompetenceRessourcesCriteria) || !$this->lastJCompetenceRessourcesCriteria->equals($criteria)) {
				$this->collJCompetenceRessourcess = JCompetenceRessourcesPeer::doSelectJoinMatiere($criteria, $con, $join_behavior);
			}
		}
		$this->lastJCompetenceRessourcesCriteria = $criteria;

		return $this->collJCompetenceRessourcess;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collCompetencesRelatedByCompetenceId) {
				foreach ((array) $this->collCompetencesRelatedByCompetenceId as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetencesProfesseurss) {
				foreach ((array) $this->collJCompetencesProfesseurss as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetenceVisibles) {
				foreach ((array) $this->collJCompetenceVisibles as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJGrilleCompetences) {
				foreach ((array) $this->collJGrilleCompetences as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJControleResultats) {
				foreach ((array) $this->collJControleResultats as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJBulletinTransversaless) {
				foreach ((array) $this->collJBulletinTransversaless as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collBilans) {
				foreach ((array) $this->collBilans as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collJCompetenceRessourcess) {
				foreach ((array) $this->collJCompetenceRessourcess as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collCompetencesRelatedByCompetenceId = null;
		$this->collJCompetencesProfesseurss = null;
		$this->collJCompetenceVisibles = null;
		$this->collJGrilleCompetences = null;
		$this->collJControleResultats = null;
		$this->collJBulletinTransversaless = null;
		$this->collBilans = null;
		$this->collJCompetenceRessourcess = null;
			$this->aCompetenceGrp = null;
			$this->aCompetenceRelatedByCompetenceId = null;
			$this->aUtilisateur = null;
	}

} // BaseCompetence
