<?php

/**
 * Base class that represents a row from the 'appreciation_bilans' table.
 *
 * Liste des bilans de chaque appreciation
 *
 * @package    competencesrb.om
 */
abstract class BaseJAppreciationBilan extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JAppreciationBilanPeer
	 */
	protected static $peer;

	/**
	 * The value for the appreciation_id field.
	 * @var        int
	 */
	protected $appreciation_id;

	/**
	 * The value for the bilan_id field.
	 * @var        int
	 */
	protected $bilan_id;

	/**
	 * @var        Appreciation
	 */
	protected $aAppreciation;

	/**
	 * @var        Bilan
	 */
	protected $aBilan;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJAppreciationBilan object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [appreciation_id] column value.
	 * cle etrangere de l'appreciation
	 * @return     int
	 */
	public function getAppreciationId()
	{
		return $this->appreciation_id;
	}

	/**
	 * Get the [bilan_id] column value.
	 * cle etrangere du bilan
	 * @return     int
	 */
	public function getBilanId()
	{
		return $this->bilan_id;
	}

	/**
	 * Set the value of [appreciation_id] column.
	 * cle etrangere de l'appreciation
	 * @param      int $v new value
	 * @return     JAppreciationBilan The current object (for fluent API support)
	 */
	public function setAppreciationId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->appreciation_id !== $v) {
			$this->appreciation_id = $v;
			$this->modifiedColumns[] = JAppreciationBilanPeer::APPRECIATION_ID;
		}

		if ($this->aAppreciation !== null && $this->aAppreciation->getId() !== $v) {
			$this->aAppreciation = null;
		}

		return $this;
	} // setAppreciationId()

	/**
	 * Set the value of [bilan_id] column.
	 * cle etrangere du bilan
	 * @param      int $v new value
	 * @return     JAppreciationBilan The current object (for fluent API support)
	 */
	public function setBilanId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->bilan_id !== $v) {
			$this->bilan_id = $v;
			$this->modifiedColumns[] = JAppreciationBilanPeer::BILAN_ID;
		}

		if ($this->aBilan !== null && $this->aBilan->getId() !== $v) {
			$this->aBilan = null;
		}

		return $this;
	} // setBilanId()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->appreciation_id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->bilan_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 2; // 2 = JAppreciationBilanPeer::NUM_COLUMNS - JAppreciationBilanPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JAppreciationBilan object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aAppreciation !== null && $this->appreciation_id !== $this->aAppreciation->getId()) {
			$this->aAppreciation = null;
		}
		if ($this->aBilan !== null && $this->bilan_id !== $this->aBilan->getId()) {
			$this->aBilan = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JAppreciationBilanPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JAppreciationBilanPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aAppreciation = null;
			$this->aBilan = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JAppreciationBilanPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JAppreciationBilanPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JAppreciationBilanPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JAppreciationBilanPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aAppreciation !== null) {
				if ($this->aAppreciation->isModified() || $this->aAppreciation->isNew()) {
					$affectedRows += $this->aAppreciation->save($con);
				}
				$this->setAppreciation($this->aAppreciation);
			}

			if ($this->aBilan !== null) {
				if ($this->aBilan->isModified() || $this->aBilan->isNew()) {
					$affectedRows += $this->aBilan->save($con);
				}
				$this->setBilan($this->aBilan);
			}


			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JAppreciationBilanPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setNew(false);
				} else {
					$affectedRows += JAppreciationBilanPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aAppreciation !== null) {
				if (!$this->aAppreciation->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aAppreciation->getValidationFailures());
				}
			}

			if ($this->aBilan !== null) {
				if (!$this->aBilan->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aBilan->getValidationFailures());
				}
			}


			if (($retval = JAppreciationBilanPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JAppreciationBilanPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getAppreciationId();
				break;
			case 1:
				return $this->getBilanId();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JAppreciationBilanPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getAppreciationId(),
			$keys[1] => $this->getBilanId(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JAppreciationBilanPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setAppreciationId($value);
				break;
			case 1:
				$this->setBilanId($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JAppreciationBilanPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setAppreciationId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setBilanId($arr[$keys[1]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JAppreciationBilanPeer::DATABASE_NAME);

		if ($this->isColumnModified(JAppreciationBilanPeer::APPRECIATION_ID)) $criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->appreciation_id);
		if ($this->isColumnModified(JAppreciationBilanPeer::BILAN_ID)) $criteria->add(JAppreciationBilanPeer::BILAN_ID, $this->bilan_id);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JAppreciationBilanPeer::DATABASE_NAME);

		$criteria->add(JAppreciationBilanPeer::APPRECIATION_ID, $this->appreciation_id);
		$criteria->add(JAppreciationBilanPeer::BILAN_ID, $this->bilan_id);

		return $criteria;
	}

	/**
	 * Returns the composite primary key for this object.
	 * The array elements will be in same order as specified in XML.
	 * @return     array
	 */
	public function getPrimaryKey()
	{
		$pks = array();

		$pks[0] = $this->getAppreciationId();

		$pks[1] = $this->getBilanId();

		return $pks;
	}

	/**
	 * Set the [composite] primary key.
	 *
	 * @param      array $keys The elements of the composite key (order must match the order in XML file).
	 * @return     void
	 */
	public function setPrimaryKey($keys)
	{

		$this->setAppreciationId($keys[0]);

		$this->setBilanId($keys[1]);

	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JAppreciationBilan (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setAppreciationId($this->appreciation_id);

		$copyObj->setBilanId($this->bilan_id);


		$copyObj->setNew(true);

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JAppreciationBilan Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JAppreciationBilanPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JAppreciationBilanPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Appreciation object.
	 *
	 * @param      Appreciation $v
	 * @return     JAppreciationBilan The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setAppreciation(Appreciation $v = null)
	{
		if ($v === null) {
			$this->setAppreciationId(NULL);
		} else {
			$this->setAppreciationId($v->getId());
		}

		$this->aAppreciation = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Appreciation object, it will not be re-added.
		if ($v !== null) {
			$v->addJAppreciationBilan($this);
		}

		return $this;
	}


	/**
	 * Get the associated Appreciation object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Appreciation The associated Appreciation object.
	 * @throws     PropelException
	 */
	public function getAppreciation(PropelPDO $con = null)
	{
		if ($this->aAppreciation === null && ($this->appreciation_id !== null)) {
			$this->aAppreciation = AppreciationPeer::retrieveByPK($this->appreciation_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aAppreciation->addJAppreciationBilans($this);
			 */
		}
		return $this->aAppreciation;
	}

	/**
	 * Declares an association between this object and a Bilan object.
	 *
	 * @param      Bilan $v
	 * @return     JAppreciationBilan The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setBilan(Bilan $v = null)
	{
		if ($v === null) {
			$this->setBilanId(NULL);
		} else {
			$this->setBilanId($v->getId());
		}

		$this->aBilan = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Bilan object, it will not be re-added.
		if ($v !== null) {
			$v->addJAppreciationBilan($this);
		}

		return $this;
	}


	/**
	 * Get the associated Bilan object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Bilan The associated Bilan object.
	 * @throws     PropelException
	 */
	public function getBilan(PropelPDO $con = null)
	{
		if ($this->aBilan === null && ($this->bilan_id !== null)) {
			$this->aBilan = BilanPeer::retrieveByPK($this->bilan_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aBilan->addJAppreciationBilans($this);
			 */
		}
		return $this->aBilan;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aAppreciation = null;
			$this->aBilan = null;
	}

} // BaseJAppreciationBilan
