<?php

/**
 * Base class that represents a row from the 'controle_resultats' table.
 *
 * Resultat de l'evaluation de chaque competence pour chaque controle
 *
 * @package    competencesrb.om
 */
abstract class BaseJControleResultat extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JControleResultatPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the controle_id field.
	 * @var        int
	 */
	protected $controle_id;

	/**
	 * The value for the utilisateur_id field.
	 * @var        int
	 */
	protected $utilisateur_id;

	/**
	 * The value for the competence_id field.
	 * @var        int
	 */
	protected $competence_id;

	/**
	 * The value for the resultat field.
	 * @var        string
	 */
	protected $resultat;

	/**
	 * @var        Controle
	 */
	protected $aControle;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * @var        Competence
	 */
	protected $aCompetence;

	/**
	 * @var        ValidationNiveau
	 */
	protected $aValidationNiveau;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJControleResultat object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table controle_resultats
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [controle_id] column value.
	 * cle etrangere du controle
	 * @return     int
	 */
	public function getControleId()
	{
		return $this->controle_id;
	}

	/**
	 * Get the [utilisateur_id] column value.
	 * cle etrangere de l'utilisateur eleve
	 * @return     int
	 */
	public function getUtilisateurId()
	{
		return $this->utilisateur_id;
	}

	/**
	 * Get the [competence_id] column value.
	 * cle etrangere de la competence
	 * @return     int
	 */
	public function getCompetenceId()
	{
		return $this->competence_id;
	}

	/**
	 * Get the [resultat] column value.
	 * resultat de la competence
	 * @return     string
	 */
	public function getResultat()
	{
		return $this->resultat;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table controle_resultats
	 * @param      int $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = JControleResultatPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = JControleResultatPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [controle_id] column.
	 * cle etrangere du controle
	 * @param      int $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setControleId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->controle_id !== $v) {
			$this->controle_id = $v;
			$this->modifiedColumns[] = JControleResultatPeer::CONTROLE_ID;
		}

		if ($this->aControle !== null && $this->aControle->getId() !== $v) {
			$this->aControle = null;
		}

		return $this;
	} // setControleId()

	/**
	 * Set the value of [utilisateur_id] column.
	 * cle etrangere de l'utilisateur eleve
	 * @param      int $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setUtilisateurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->utilisateur_id !== $v) {
			$this->utilisateur_id = $v;
			$this->modifiedColumns[] = JControleResultatPeer::UTILISATEUR_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setUtilisateurId()

	/**
	 * Set the value of [competence_id] column.
	 * cle etrangere de la competence
	 * @param      int $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setCompetenceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->competence_id !== $v) {
			$this->competence_id = $v;
			$this->modifiedColumns[] = JControleResultatPeer::COMPETENCE_ID;
		}

		if ($this->aCompetence !== null && $this->aCompetence->getId() !== $v) {
			$this->aCompetence = null;
		}

		return $this;
	} // setCompetenceId()

	/**
	 * Set the value of [resultat] column.
	 * resultat de la competence
	 * @param      string $v new value
	 * @return     JControleResultat The current object (for fluent API support)
	 */
	public function setResultat($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->resultat !== $v) {
			$this->resultat = $v;
			$this->modifiedColumns[] = JControleResultatPeer::RESULTAT;
		}

		if ($this->aValidationNiveau !== null && $this->aValidationNiveau->getLettre() !== $v) {
			$this->aValidationNiveau = null;
		}

		return $this;
	} // setResultat()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->rne = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->controle_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->utilisateur_id = ($row[$startcol + 3] !== null) ? (int) $row[$startcol + 3] : null;
			$this->competence_id = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->resultat = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 6; // 6 = JControleResultatPeer::NUM_COLUMNS - JControleResultatPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JControleResultat object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aControle !== null && $this->controle_id !== $this->aControle->getId()) {
			$this->aControle = null;
		}
		if ($this->aUtilisateur !== null && $this->utilisateur_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
		if ($this->aCompetence !== null && $this->competence_id !== $this->aCompetence->getId()) {
			$this->aCompetence = null;
		}
		if ($this->aValidationNiveau !== null && $this->resultat !== $this->aValidationNiveau->getLettre()) {
			$this->aValidationNiveau = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JControleResultatPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JControleResultatPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aControle = null;
			$this->aUtilisateur = null;
			$this->aCompetence = null;
			$this->aValidationNiveau = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JControleResultatPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JControleResultatPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JControleResultatPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JControleResultatPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aControle !== null) {
				if ($this->aControle->isModified() || $this->aControle->isNew()) {
					$affectedRows += $this->aControle->save($con);
				}
				$this->setControle($this->aControle);
			}

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->aCompetence !== null) {
				if ($this->aCompetence->isModified() || $this->aCompetence->isNew()) {
					$affectedRows += $this->aCompetence->save($con);
				}
				$this->setCompetence($this->aCompetence);
			}

			if ($this->aValidationNiveau !== null) {
				if ($this->aValidationNiveau->isModified() || $this->aValidationNiveau->isNew()) {
					$affectedRows += $this->aValidationNiveau->save($con);
				}
				$this->setValidationNiveau($this->aValidationNiveau);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = JControleResultatPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JControleResultatPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += JControleResultatPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aControle !== null) {
				if (!$this->aControle->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aControle->getValidationFailures());
				}
			}

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}

			if ($this->aCompetence !== null) {
				if (!$this->aCompetence->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aCompetence->getValidationFailures());
				}
			}

			if ($this->aValidationNiveau !== null) {
				if (!$this->aValidationNiveau->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aValidationNiveau->getValidationFailures());
				}
			}


			if (($retval = JControleResultatPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JControleResultatPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getRne();
				break;
			case 2:
				return $this->getControleId();
				break;
			case 3:
				return $this->getUtilisateurId();
				break;
			case 4:
				return $this->getCompetenceId();
				break;
			case 5:
				return $this->getResultat();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JControleResultatPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getRne(),
			$keys[2] => $this->getControleId(),
			$keys[3] => $this->getUtilisateurId(),
			$keys[4] => $this->getCompetenceId(),
			$keys[5] => $this->getResultat(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JControleResultatPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setRne($value);
				break;
			case 2:
				$this->setControleId($value);
				break;
			case 3:
				$this->setUtilisateurId($value);
				break;
			case 4:
				$this->setCompetenceId($value);
				break;
			case 5:
				$this->setResultat($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JControleResultatPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setRne($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setControleId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setUtilisateurId($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setCompetenceId($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setResultat($arr[$keys[5]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JControleResultatPeer::DATABASE_NAME);

		if ($this->isColumnModified(JControleResultatPeer::ID)) $criteria->add(JControleResultatPeer::ID, $this->id);
		if ($this->isColumnModified(JControleResultatPeer::RNE)) $criteria->add(JControleResultatPeer::RNE, $this->rne);
		if ($this->isColumnModified(JControleResultatPeer::CONTROLE_ID)) $criteria->add(JControleResultatPeer::CONTROLE_ID, $this->controle_id);
		if ($this->isColumnModified(JControleResultatPeer::UTILISATEUR_ID)) $criteria->add(JControleResultatPeer::UTILISATEUR_ID, $this->utilisateur_id);
		if ($this->isColumnModified(JControleResultatPeer::COMPETENCE_ID)) $criteria->add(JControleResultatPeer::COMPETENCE_ID, $this->competence_id);
		if ($this->isColumnModified(JControleResultatPeer::RESULTAT)) $criteria->add(JControleResultatPeer::RESULTAT, $this->resultat);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JControleResultatPeer::DATABASE_NAME);

		$criteria->add(JControleResultatPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JControleResultat (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setRne($this->rne);

		$copyObj->setControleId($this->controle_id);

		$copyObj->setUtilisateurId($this->utilisateur_id);

		$copyObj->setCompetenceId($this->competence_id);

		$copyObj->setResultat($this->resultat);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JControleResultat Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JControleResultatPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JControleResultatPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Controle object.
	 *
	 * @param      Controle $v
	 * @return     JControleResultat The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setControle(Controle $v = null)
	{
		if ($v === null) {
			$this->setControleId(NULL);
		} else {
			$this->setControleId($v->getId());
		}

		$this->aControle = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Controle object, it will not be re-added.
		if ($v !== null) {
			$v->addJControleResultat($this);
		}

		return $this;
	}


	/**
	 * Get the associated Controle object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Controle The associated Controle object.
	 * @throws     PropelException
	 */
	public function getControle(PropelPDO $con = null)
	{
		if ($this->aControle === null && ($this->controle_id !== null)) {
			$this->aControle = ControlePeer::retrieveByPK($this->controle_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aControle->addJControleResultats($this);
			 */
		}
		return $this->aControle;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     JControleResultat The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setUtilisateurId(NULL);
		} else {
			$this->setUtilisateurId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addJControleResultat($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->utilisateur_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->utilisateur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addJControleResultats($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Declares an association between this object and a Competence object.
	 *
	 * @param      Competence $v
	 * @return     JControleResultat The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setCompetence(Competence $v = null)
	{
		if ($v === null) {
			$this->setCompetenceId(NULL);
		} else {
			$this->setCompetenceId($v->getId());
		}

		$this->aCompetence = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Competence object, it will not be re-added.
		if ($v !== null) {
			$v->addJControleResultat($this);
		}

		return $this;
	}


	/**
	 * Get the associated Competence object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Competence The associated Competence object.
	 * @throws     PropelException
	 */
	public function getCompetence(PropelPDO $con = null)
	{
		if ($this->aCompetence === null && ($this->competence_id !== null)) {
			$this->aCompetence = CompetencePeer::retrieveByPK($this->competence_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aCompetence->addJControleResultats($this);
			 */
		}
		return $this->aCompetence;
	}

	/**
	 * Declares an association between this object and a ValidationNiveau object.
	 *
	 * @param      ValidationNiveau $v
	 * @return     JControleResultat The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setValidationNiveau(ValidationNiveau $v = null)
	{
		if ($v === null) {
			$this->setResultat(NULL);
		} else {
			$this->setResultat($v->getLettre());
		}

		$this->aValidationNiveau = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the ValidationNiveau object, it will not be re-added.
		if ($v !== null) {
			$v->addJControleResultat($this);
		}

		return $this;
	}


	/**
	 * Get the associated ValidationNiveau object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     ValidationNiveau The associated ValidationNiveau object.
	 * @throws     PropelException
	 */
	public function getValidationNiveau(PropelPDO $con = null)
	{
		if ($this->aValidationNiveau === null && (($this->resultat !== "" && $this->resultat !== null))) {
			$this->aValidationNiveau = ValidationNiveauPeer::retrieveByPK($this->resultat, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aValidationNiveau->addJControleResultats($this);
			 */
		}
		return $this->aValidationNiveau;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aControle = null;
			$this->aUtilisateur = null;
			$this->aCompetence = null;
			$this->aValidationNiveau = null;
	}

} // BaseJControleResultat
