<?php

/**
 * Base class that represents a row from the 'd_documents' table.
 *
 * Liste des documents echanges pendant la discussion
 *
 * @package    competencesrb.om
 */
abstract class BaseJDiscussionDocuments extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JDiscussionDocumentsPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the discussion_id field.
	 * @var        int
	 */
	protected $discussion_id;

	/**
	 * The value for the utilisateur_id field.
	 * @var        int
	 */
	protected $utilisateur_id;

	/**
	 * The value for the nom field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $nom;

	/**
	 * The value for the chemin field.
	 * Note: this column has a database default value of: ''
	 * @var        string
	 */
	protected $chemin;

	/**
	 * @var        Discussion
	 */
	protected $aDiscussion;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJDiscussionDocuments object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->nom = '';
		$this->chemin = '';
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table d_documents
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [discussion_id] column value.
	 * cle etrangere de la table d_discussions
	 * @return     int
	 */
	public function getDiscussionId()
	{
		return $this->discussion_id;
	}

	/**
	 * Get the [utilisateur_id] column value.
	 * cle etrangere de l'utilisateur
	 * @return     int
	 */
	public function getUtilisateurId()
	{
		return $this->utilisateur_id;
	}

	/**
	 * Get the [nom] column value.
	 * nom du document
	 * @return     string
	 */
	public function getNom()
	{
		return $this->nom;
	}

	/**
	 * Get the [chemin] column value.
	 * chemin du document
	 * @return     string
	 */
	public function getChemin()
	{
		return $this->chemin;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table d_documents
	 * @param      int $v new value
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = JDiscussionDocumentsPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [discussion_id] column.
	 * cle etrangere de la table d_discussions
	 * @param      int $v new value
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 */
	public function setDiscussionId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->discussion_id !== $v) {
			$this->discussion_id = $v;
			$this->modifiedColumns[] = JDiscussionDocumentsPeer::DISCUSSION_ID;
		}

		if ($this->aDiscussion !== null && $this->aDiscussion->getId() !== $v) {
			$this->aDiscussion = null;
		}

		return $this;
	} // setDiscussionId()

	/**
	 * Set the value of [utilisateur_id] column.
	 * cle etrangere de l'utilisateur
	 * @param      int $v new value
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 */
	public function setUtilisateurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->utilisateur_id !== $v) {
			$this->utilisateur_id = $v;
			$this->modifiedColumns[] = JDiscussionDocumentsPeer::UTILISATEUR_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setUtilisateurId()

	/**
	 * Set the value of [nom] column.
	 * nom du document
	 * @param      string $v new value
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 */
	public function setNom($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->nom !== $v || $v === '') {
			$this->nom = $v;
			$this->modifiedColumns[] = JDiscussionDocumentsPeer::NOM;
		}

		return $this;
	} // setNom()

	/**
	 * Set the value of [chemin] column.
	 * chemin du document
	 * @param      string $v new value
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 */
	public function setChemin($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->chemin !== $v || $v === '') {
			$this->chemin = $v;
			$this->modifiedColumns[] = JDiscussionDocumentsPeer::CHEMIN;
		}

		return $this;
	} // setChemin()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(JDiscussionDocumentsPeer::NOM,JDiscussionDocumentsPeer::CHEMIN))) {
				return false;
			}

			if ($this->nom !== '') {
				return false;
			}

			if ($this->chemin !== '') {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->discussion_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->utilisateur_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->nom = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->chemin = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 5; // 5 = JDiscussionDocumentsPeer::NUM_COLUMNS - JDiscussionDocumentsPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JDiscussionDocuments object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aDiscussion !== null && $this->discussion_id !== $this->aDiscussion->getId()) {
			$this->aDiscussion = null;
		}
		if ($this->aUtilisateur !== null && $this->utilisateur_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDiscussionDocumentsPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JDiscussionDocumentsPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aDiscussion = null;
			$this->aUtilisateur = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDiscussionDocumentsPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JDiscussionDocumentsPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JDiscussionDocumentsPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JDiscussionDocumentsPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aDiscussion !== null) {
				if ($this->aDiscussion->isModified() || $this->aDiscussion->isNew()) {
					$affectedRows += $this->aDiscussion->save($con);
				}
				$this->setDiscussion($this->aDiscussion);
			}

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = JDiscussionDocumentsPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JDiscussionDocumentsPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += JDiscussionDocumentsPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aDiscussion !== null) {
				if (!$this->aDiscussion->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aDiscussion->getValidationFailures());
				}
			}

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}


			if (($retval = JDiscussionDocumentsPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JDiscussionDocumentsPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getDiscussionId();
				break;
			case 2:
				return $this->getUtilisateurId();
				break;
			case 3:
				return $this->getNom();
				break;
			case 4:
				return $this->getChemin();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JDiscussionDocumentsPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getDiscussionId(),
			$keys[2] => $this->getUtilisateurId(),
			$keys[3] => $this->getNom(),
			$keys[4] => $this->getChemin(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JDiscussionDocumentsPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setDiscussionId($value);
				break;
			case 2:
				$this->setUtilisateurId($value);
				break;
			case 3:
				$this->setNom($value);
				break;
			case 4:
				$this->setChemin($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JDiscussionDocumentsPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setDiscussionId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setUtilisateurId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setNom($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setChemin($arr[$keys[4]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JDiscussionDocumentsPeer::DATABASE_NAME);

		if ($this->isColumnModified(JDiscussionDocumentsPeer::ID)) $criteria->add(JDiscussionDocumentsPeer::ID, $this->id);
		if ($this->isColumnModified(JDiscussionDocumentsPeer::DISCUSSION_ID)) $criteria->add(JDiscussionDocumentsPeer::DISCUSSION_ID, $this->discussion_id);
		if ($this->isColumnModified(JDiscussionDocumentsPeer::UTILISATEUR_ID)) $criteria->add(JDiscussionDocumentsPeer::UTILISATEUR_ID, $this->utilisateur_id);
		if ($this->isColumnModified(JDiscussionDocumentsPeer::NOM)) $criteria->add(JDiscussionDocumentsPeer::NOM, $this->nom);
		if ($this->isColumnModified(JDiscussionDocumentsPeer::CHEMIN)) $criteria->add(JDiscussionDocumentsPeer::CHEMIN, $this->chemin);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JDiscussionDocumentsPeer::DATABASE_NAME);

		$criteria->add(JDiscussionDocumentsPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JDiscussionDocuments (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setDiscussionId($this->discussion_id);

		$copyObj->setUtilisateurId($this->utilisateur_id);

		$copyObj->setNom($this->nom);

		$copyObj->setChemin($this->chemin);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JDiscussionDocuments Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JDiscussionDocumentsPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JDiscussionDocumentsPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Discussion object.
	 *
	 * @param      Discussion $v
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setDiscussion(Discussion $v = null)
	{
		if ($v === null) {
			$this->setDiscussionId(NULL);
		} else {
			$this->setDiscussionId($v->getId());
		}

		$this->aDiscussion = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Discussion object, it will not be re-added.
		if ($v !== null) {
			$v->addJDiscussionDocuments($this);
		}

		return $this;
	}


	/**
	 * Get the associated Discussion object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Discussion The associated Discussion object.
	 * @throws     PropelException
	 */
	public function getDiscussion(PropelPDO $con = null)
	{
		if ($this->aDiscussion === null && ($this->discussion_id !== null)) {
			$this->aDiscussion = DiscussionPeer::retrieveByPK($this->discussion_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aDiscussion->addJDiscussionDocumentss($this);
			 */
		}
		return $this->aDiscussion;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     JDiscussionDocuments The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setUtilisateurId(NULL);
		} else {
			$this->setUtilisateurId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addJDiscussionDocuments($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->utilisateur_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->utilisateur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addJDiscussionDocumentss($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aDiscussion = null;
			$this->aUtilisateur = null;
	}

} // BaseJDiscussionDocuments
