<?php

/**
 * Base class that represents a row from the 'exe_reponses' table.
 *
 * Liste des reponses des eleves
 *
 * @package    competencesrb.om
 */
abstract class BaseJExeReponse extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        JExeReponsePeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the eleve_id field.
	 * @var        int
	 */
	protected $eleve_id;

	/**
	 * The value for the exercice_id field.
	 * @var        int
	 */
	protected $exercice_id;

	/**
	 * The value for the exe_doc_question_id field.
	 * @var        int
	 */
	protected $exe_doc_question_id;

	/**
	 * The value for the reponse field.
	 * @var        resource
	 */
	protected $reponse;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the created_on field.
	 * @var        int
	 */
	protected $created_on;

	/**
	 * The value for the updated_on field.
	 * @var        int
	 */
	protected $updated_on;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * @var        Exercice
	 */
	protected $aExercice;

	/**
	 * @var        JDocQuestion
	 */
	protected $aJDocQuestion;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseJExeReponse object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table exe_doc_questions
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [eleve_id] column value.
	 * cle etrangere de l'eleve
	 * @return     int
	 */
	public function getEleveId()
	{
		return $this->eleve_id;
	}

	/**
	 * Get the [exercice_id] column value.
	 * cle etrangere de l'exercice
	 * @return     int
	 */
	public function getExerciceId()
	{
		return $this->exercice_id;
	}

	/**
	 * Get the [exe_doc_question_id] column value.
	 * cle etrangere de la question
	 * @return     int
	 */
	public function getExeDocQuestionId()
	{
		return $this->exe_doc_question_id;
	}

	/**
	 * Get the [reponse] column value.
	 * reponse a la question
	 * @return     resource
	 */
	public function getReponse()
	{
		return $this->reponse;
	}

	/**
	 * Get the [rne] column value.
	 * Rne de l'etablissement
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [created_on] column value.
	 * Date de creation
	 * @return     int
	 */
	public function getCreatedOn()
	{
		return $this->created_on;
	}

	/**
	 * Get the [updated_on] column value.
	 * Date de modification
	 * @return     int
	 */
	public function getUpdatedOn()
	{
		return $this->updated_on;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table exe_doc_questions
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = JExeReponsePeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [eleve_id] column.
	 * cle etrangere de l'eleve
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setEleveId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->eleve_id !== $v) {
			$this->eleve_id = $v;
			$this->modifiedColumns[] = JExeReponsePeer::ELEVE_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setEleveId()

	/**
	 * Set the value of [exercice_id] column.
	 * cle etrangere de l'exercice
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setExerciceId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->exercice_id !== $v) {
			$this->exercice_id = $v;
			$this->modifiedColumns[] = JExeReponsePeer::EXERCICE_ID;
		}

		if ($this->aExercice !== null && $this->aExercice->getId() !== $v) {
			$this->aExercice = null;
		}

		return $this;
	} // setExerciceId()

	/**
	 * Set the value of [exe_doc_question_id] column.
	 * cle etrangere de la question
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setExeDocQuestionId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->exe_doc_question_id !== $v) {
			$this->exe_doc_question_id = $v;
			$this->modifiedColumns[] = JExeReponsePeer::EXE_DOC_QUESTION_ID;
		}

		if ($this->aJDocQuestion !== null && $this->aJDocQuestion->getId() !== $v) {
			$this->aJDocQuestion = null;
		}

		return $this;
	} // setExeDocQuestionId()

	/**
	 * Set the value of [reponse] column.
	 * reponse a la question
	 * @param      resource $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setReponse($v)
	{
		// Because BLOB columns are streams in PDO we have to assume that they are
		// always modified when a new value is passed in.  For example, the contents
		// of the stream itself may have changed externally.
		if (!is_resource($v)) {
			$this->reponse = fopen('php://memory', 'r+');
			fwrite($this->reponse, $v);
			rewind($this->reponse);
		} else { // it's already a stream
			$this->reponse = $v;
		}
		$this->modifiedColumns[] = JExeReponsePeer::REPONSE;

		return $this;
	} // setReponse()

	/**
	 * Set the value of [rne] column.
	 * Rne de l'etablissement
	 * @param      string $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = JExeReponsePeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [created_on] column.
	 * Date de creation
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setCreatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->created_on !== $v) {
			$this->created_on = $v;
			$this->modifiedColumns[] = JExeReponsePeer::CREATED_ON;
		}

		return $this;
	} // setCreatedOn()

	/**
	 * Set the value of [updated_on] column.
	 * Date de modification
	 * @param      int $v new value
	 * @return     JExeReponse The current object (for fluent API support)
	 */
	public function setUpdatedOn($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->updated_on !== $v) {
			$this->updated_on = $v;
			$this->modifiedColumns[] = JExeReponsePeer::UPDATED_ON;
		}

		return $this;
	} // setUpdatedOn()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->eleve_id = ($row[$startcol + 1] !== null) ? (int) $row[$startcol + 1] : null;
			$this->exercice_id = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->exe_doc_question_id = ($row[$startcol + 3] !== null) ? (int) $row[$startcol + 3] : null;
			if ($row[$startcol + 4] !== null) {
				$this->reponse = fopen('php://memory', 'r+');
				fwrite($this->reponse, $row[$startcol + 4]);
				rewind($this->reponse);
			} else {
				$this->reponse = null;
			}
			$this->rne = ($row[$startcol + 5] !== null) ? (string) $row[$startcol + 5] : null;
			$this->created_on = ($row[$startcol + 6] !== null) ? (int) $row[$startcol + 6] : null;
			$this->updated_on = ($row[$startcol + 7] !== null) ? (int) $row[$startcol + 7] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 8; // 8 = JExeReponsePeer::NUM_COLUMNS - JExeReponsePeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating JExeReponse object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aUtilisateur !== null && $this->eleve_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
		if ($this->aExercice !== null && $this->exercice_id !== $this->aExercice->getId()) {
			$this->aExercice = null;
		}
		if ($this->aJDocQuestion !== null && $this->exe_doc_question_id !== $this->aJDocQuestion->getId()) {
			$this->aJDocQuestion = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JExeReponsePeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = JExeReponsePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aUtilisateur = null;
			$this->aExercice = null;
			$this->aJDocQuestion = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JExeReponsePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			JExeReponsePeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(JExeReponsePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			JExeReponsePeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->aExercice !== null) {
				if ($this->aExercice->isModified() || $this->aExercice->isNew()) {
					$affectedRows += $this->aExercice->save($con);
				}
				$this->setExercice($this->aExercice);
			}

			if ($this->aJDocQuestion !== null) {
				if ($this->aJDocQuestion->isModified() || $this->aJDocQuestion->isNew()) {
					$affectedRows += $this->aJDocQuestion->save($con);
				}
				$this->setJDocQuestion($this->aJDocQuestion);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = JExeReponsePeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = JExeReponsePeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += JExeReponsePeer::doUpdate($this, $con);
				}

				// Rewind the reponse LOB column, since PDO does not rewind after inserting value.
				if ($this->reponse !== null && is_resource($this->reponse)) {
					rewind($this->reponse);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}

			if ($this->aExercice !== null) {
				if (!$this->aExercice->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aExercice->getValidationFailures());
				}
			}

			if ($this->aJDocQuestion !== null) {
				if (!$this->aJDocQuestion->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aJDocQuestion->getValidationFailures());
				}
			}


			if (($retval = JExeReponsePeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JExeReponsePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getEleveId();
				break;
			case 2:
				return $this->getExerciceId();
				break;
			case 3:
				return $this->getExeDocQuestionId();
				break;
			case 4:
				return $this->getReponse();
				break;
			case 5:
				return $this->getRne();
				break;
			case 6:
				return $this->getCreatedOn();
				break;
			case 7:
				return $this->getUpdatedOn();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = JExeReponsePeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getEleveId(),
			$keys[2] => $this->getExerciceId(),
			$keys[3] => $this->getExeDocQuestionId(),
			$keys[4] => $this->getReponse(),
			$keys[5] => $this->getRne(),
			$keys[6] => $this->getCreatedOn(),
			$keys[7] => $this->getUpdatedOn(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = JExeReponsePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setEleveId($value);
				break;
			case 2:
				$this->setExerciceId($value);
				break;
			case 3:
				$this->setExeDocQuestionId($value);
				break;
			case 4:
				$this->setReponse($value);
				break;
			case 5:
				$this->setRne($value);
				break;
			case 6:
				$this->setCreatedOn($value);
				break;
			case 7:
				$this->setUpdatedOn($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = JExeReponsePeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setEleveId($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setExerciceId($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setExeDocQuestionId($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setReponse($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setRne($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setCreatedOn($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setUpdatedOn($arr[$keys[7]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(JExeReponsePeer::DATABASE_NAME);

		if ($this->isColumnModified(JExeReponsePeer::ID)) $criteria->add(JExeReponsePeer::ID, $this->id);
		if ($this->isColumnModified(JExeReponsePeer::ELEVE_ID)) $criteria->add(JExeReponsePeer::ELEVE_ID, $this->eleve_id);
		if ($this->isColumnModified(JExeReponsePeer::EXERCICE_ID)) $criteria->add(JExeReponsePeer::EXERCICE_ID, $this->exercice_id);
		if ($this->isColumnModified(JExeReponsePeer::EXE_DOC_QUESTION_ID)) $criteria->add(JExeReponsePeer::EXE_DOC_QUESTION_ID, $this->exe_doc_question_id);
		if ($this->isColumnModified(JExeReponsePeer::REPONSE)) $criteria->add(JExeReponsePeer::REPONSE, $this->reponse);
		if ($this->isColumnModified(JExeReponsePeer::RNE)) $criteria->add(JExeReponsePeer::RNE, $this->rne);
		if ($this->isColumnModified(JExeReponsePeer::CREATED_ON)) $criteria->add(JExeReponsePeer::CREATED_ON, $this->created_on);
		if ($this->isColumnModified(JExeReponsePeer::UPDATED_ON)) $criteria->add(JExeReponsePeer::UPDATED_ON, $this->updated_on);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(JExeReponsePeer::DATABASE_NAME);

		$criteria->add(JExeReponsePeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of JExeReponse (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setEleveId($this->eleve_id);

		$copyObj->setExerciceId($this->exercice_id);

		$copyObj->setExeDocQuestionId($this->exe_doc_question_id);

		$copyObj->setReponse($this->reponse);

		$copyObj->setRne($this->rne);

		$copyObj->setCreatedOn($this->created_on);

		$copyObj->setUpdatedOn($this->updated_on);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     JExeReponse Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     JExeReponsePeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new JExeReponsePeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     JExeReponse The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setEleveId(NULL);
		} else {
			$this->setEleveId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addJExeReponse($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->eleve_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->eleve_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addJExeReponses($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Declares an association between this object and a Exercice object.
	 *
	 * @param      Exercice $v
	 * @return     JExeReponse The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setExercice(Exercice $v = null)
	{
		if ($v === null) {
			$this->setExerciceId(NULL);
		} else {
			$this->setExerciceId($v->getId());
		}

		$this->aExercice = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Exercice object, it will not be re-added.
		if ($v !== null) {
			$v->addJExeReponse($this);
		}

		return $this;
	}


	/**
	 * Get the associated Exercice object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Exercice The associated Exercice object.
	 * @throws     PropelException
	 */
	public function getExercice(PropelPDO $con = null)
	{
		if ($this->aExercice === null && ($this->exercice_id !== null)) {
			$this->aExercice = ExercicePeer::retrieveByPK($this->exercice_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aExercice->addJExeReponses($this);
			 */
		}
		return $this->aExercice;
	}

	/**
	 * Declares an association between this object and a JDocQuestion object.
	 *
	 * @param      JDocQuestion $v
	 * @return     JExeReponse The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setJDocQuestion(JDocQuestion $v = null)
	{
		if ($v === null) {
			$this->setExeDocQuestionId(NULL);
		} else {
			$this->setExeDocQuestionId($v->getId());
		}

		$this->aJDocQuestion = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the JDocQuestion object, it will not be re-added.
		if ($v !== null) {
			$v->addJExeReponse($this);
		}

		return $this;
	}


	/**
	 * Get the associated JDocQuestion object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     JDocQuestion The associated JDocQuestion object.
	 * @throws     PropelException
	 */
	public function getJDocQuestion(PropelPDO $con = null)
	{
		if ($this->aJDocQuestion === null && ($this->exe_doc_question_id !== null)) {
			$this->aJDocQuestion = JDocQuestionPeer::retrieveByPK($this->exe_doc_question_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aJDocQuestion->addJExeReponses($this);
			 */
		}
		return $this->aJDocQuestion;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aUtilisateur = null;
			$this->aExercice = null;
			$this->aJDocQuestion = null;
	}

} // BaseJExeReponse
