<?php

/**
 * Base class that represents a row from the 'logs' table.
 *
 * Logs de connexion
 *
 * @package    competencesrb.om
 */
abstract class BaseLog extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        LogPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the type field.
	 * Note: this column has a database default value of: 'session'
	 * @var        string
	 */
	protected $type;

	/**
	 * The value for the degre field.
	 * Note: this column has a database default value of: 0
	 * @var        int
	 */
	protected $degre;

	/**
	 * The value for the texte field.
	 * @var        string
	 */
	protected $texte;

	/**
	 * The value for the debut field.
	 * @var        int
	 */
	protected $debut;

	/**
	 * The value for the fin field.
	 * @var        int
	 */
	protected $fin;

	/**
	 * The value for the ip field.
	 * Note: this column has a database default value of: '0'
	 * @var        string
	 */
	protected $ip;

	/**
	 * The value for the navigateur field.
	 * Note: this column has a database default value of: 'inconnu'
	 * @var        string
	 */
	protected $navigateur;

	/**
	 * The value for the marqueur field.
	 * Note: this column has a database default value of: '0'
	 * @var        string
	 */
	protected $marqueur;

	/**
	 * The value for the utilisateur_id field.
	 * @var        int
	 */
	protected $utilisateur_id;

	/**
	 * @var        Utilisateur
	 */
	protected $aUtilisateur;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseLog object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
		$this->type = 'session';
		$this->degre = 0;
		$this->ip = '0';
		$this->navigateur = 'inconnu';
		$this->marqueur = '0';
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table logs
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [type] column value.
	 * Type de log
	 * @return     string
	 */
	public function getType()
	{
		return $this->type;
	}

	/**
	 * Get the [degre] column value.
	 * Degre de gravite
	 * @return     int
	 */
	public function getDegre()
	{
		return $this->degre;
	}

	/**
	 * Get the [texte] column value.
	 * Description du log
	 * @return     string
	 */
	public function getTexte()
	{
		return $this->texte;
	}

	/**
	 * Get the [debut] column value.
	 * timestamp UNIX du debut
	 * @return     int
	 */
	public function getDebut()
	{
		return $this->debut;
	}

	/**
	 * Get the [fin] column value.
	 * timestamp UNIX de la fin
	 * @return     int
	 */
	public function getFin()
	{
		return $this->fin;
	}

	/**
	 * Get the [ip] column value.
	 * Adresse IP de l'utilisateur
	 * @return     string
	 */
	public function getIp()
	{
		return $this->ip;
	}

	/**
	 * Get the [navigateur] column value.
	 * Type de navigateur
	 * @return     string
	 */
	public function getNavigateur()
	{
		return $this->navigateur;
	}

	/**
	 * Get the [marqueur] column value.
	 * Marqueur le temps de la session
	 * @return     string
	 */
	public function getMarqueur()
	{
		return $this->marqueur;
	}

	/**
	 * Get the [utilisateur_id] column value.
	 * cle etrangere de l'utilisateur logue
	 * @return     int
	 */
	public function getUtilisateurId()
	{
		return $this->utilisateur_id;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table logs
	 * @param      int $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = LogPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [type] column.
	 * Type de log
	 * @param      string $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setType($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->type !== $v || $v === 'session') {
			$this->type = $v;
			$this->modifiedColumns[] = LogPeer::TYPE;
		}

		return $this;
	} // setType()

	/**
	 * Set the value of [degre] column.
	 * Degre de gravite
	 * @param      int $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setDegre($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->degre !== $v || $v === 0) {
			$this->degre = $v;
			$this->modifiedColumns[] = LogPeer::DEGRE;
		}

		return $this;
	} // setDegre()

	/**
	 * Set the value of [texte] column.
	 * Description du log
	 * @param      string $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setTexte($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->texte !== $v) {
			$this->texte = $v;
			$this->modifiedColumns[] = LogPeer::TEXTE;
		}

		return $this;
	} // setTexte()

	/**
	 * Set the value of [debut] column.
	 * timestamp UNIX du debut
	 * @param      int $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setDebut($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->debut !== $v) {
			$this->debut = $v;
			$this->modifiedColumns[] = LogPeer::DEBUT;
		}

		return $this;
	} // setDebut()

	/**
	 * Set the value of [fin] column.
	 * timestamp UNIX de la fin
	 * @param      int $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setFin($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->fin !== $v) {
			$this->fin = $v;
			$this->modifiedColumns[] = LogPeer::FIN;
		}

		return $this;
	} // setFin()

	/**
	 * Set the value of [ip] column.
	 * Adresse IP de l'utilisateur
	 * @param      string $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setIp($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->ip !== $v || $v === '0') {
			$this->ip = $v;
			$this->modifiedColumns[] = LogPeer::IP;
		}

		return $this;
	} // setIp()

	/**
	 * Set the value of [navigateur] column.
	 * Type de navigateur
	 * @param      string $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setNavigateur($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->navigateur !== $v || $v === 'inconnu') {
			$this->navigateur = $v;
			$this->modifiedColumns[] = LogPeer::NAVIGATEUR;
		}

		return $this;
	} // setNavigateur()

	/**
	 * Set the value of [marqueur] column.
	 * Marqueur le temps de la session
	 * @param      string $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setMarqueur($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->marqueur !== $v || $v === '0') {
			$this->marqueur = $v;
			$this->modifiedColumns[] = LogPeer::MARQUEUR;
		}

		return $this;
	} // setMarqueur()

	/**
	 * Set the value of [utilisateur_id] column.
	 * cle etrangere de l'utilisateur logue
	 * @param      int $v new value
	 * @return     Log The current object (for fluent API support)
	 */
	public function setUtilisateurId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->utilisateur_id !== $v) {
			$this->utilisateur_id = $v;
			$this->modifiedColumns[] = LogPeer::UTILISATEUR_ID;
		}

		if ($this->aUtilisateur !== null && $this->aUtilisateur->getId() !== $v) {
			$this->aUtilisateur = null;
		}

		return $this;
	} // setUtilisateurId()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array(LogPeer::TYPE,LogPeer::DEGRE,LogPeer::IP,LogPeer::NAVIGATEUR,LogPeer::MARQUEUR))) {
				return false;
			}

			if ($this->type !== 'session') {
				return false;
			}

			if ($this->degre !== 0) {
				return false;
			}

			if ($this->ip !== '0') {
				return false;
			}

			if ($this->navigateur !== 'inconnu') {
				return false;
			}

			if ($this->marqueur !== '0') {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->type = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->degre = ($row[$startcol + 2] !== null) ? (int) $row[$startcol + 2] : null;
			$this->texte = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->debut = ($row[$startcol + 4] !== null) ? (int) $row[$startcol + 4] : null;
			$this->fin = ($row[$startcol + 5] !== null) ? (int) $row[$startcol + 5] : null;
			$this->ip = ($row[$startcol + 6] !== null) ? (string) $row[$startcol + 6] : null;
			$this->navigateur = ($row[$startcol + 7] !== null) ? (string) $row[$startcol + 7] : null;
			$this->marqueur = ($row[$startcol + 8] !== null) ? (string) $row[$startcol + 8] : null;
			$this->utilisateur_id = ($row[$startcol + 9] !== null) ? (int) $row[$startcol + 9] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 10; // 10 = LogPeer::NUM_COLUMNS - LogPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating Log object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

		if ($this->aUtilisateur !== null && $this->utilisateur_id !== $this->aUtilisateur->getId()) {
			$this->aUtilisateur = null;
		}
	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(LogPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = LogPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->aUtilisateur = null;
		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(LogPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			LogPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(LogPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			LogPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			// We call the save method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if ($this->aUtilisateur->isModified() || $this->aUtilisateur->isNew()) {
					$affectedRows += $this->aUtilisateur->save($con);
				}
				$this->setUtilisateur($this->aUtilisateur);
			}

			if ($this->isNew() ) {
				$this->modifiedColumns[] = LogPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = LogPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += LogPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			// We call the validate method on the following object(s) if they
			// were passed to this object by their coresponding set
			// method.  This object relates to these object(s) by a
			// foreign key reference.

			if ($this->aUtilisateur !== null) {
				if (!$this->aUtilisateur->validate($columns)) {
					$failureMap = array_merge($failureMap, $this->aUtilisateur->getValidationFailures());
				}
			}


			if (($retval = LogPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}



			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = LogPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getType();
				break;
			case 2:
				return $this->getDegre();
				break;
			case 3:
				return $this->getTexte();
				break;
			case 4:
				return $this->getDebut();
				break;
			case 5:
				return $this->getFin();
				break;
			case 6:
				return $this->getIp();
				break;
			case 7:
				return $this->getNavigateur();
				break;
			case 8:
				return $this->getMarqueur();
				break;
			case 9:
				return $this->getUtilisateurId();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = LogPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getType(),
			$keys[2] => $this->getDegre(),
			$keys[3] => $this->getTexte(),
			$keys[4] => $this->getDebut(),
			$keys[5] => $this->getFin(),
			$keys[6] => $this->getIp(),
			$keys[7] => $this->getNavigateur(),
			$keys[8] => $this->getMarqueur(),
			$keys[9] => $this->getUtilisateurId(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = LogPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setType($value);
				break;
			case 2:
				$this->setDegre($value);
				break;
			case 3:
				$this->setTexte($value);
				break;
			case 4:
				$this->setDebut($value);
				break;
			case 5:
				$this->setFin($value);
				break;
			case 6:
				$this->setIp($value);
				break;
			case 7:
				$this->setNavigateur($value);
				break;
			case 8:
				$this->setMarqueur($value);
				break;
			case 9:
				$this->setUtilisateurId($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = LogPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setType($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setDegre($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setTexte($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setDebut($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setFin($arr[$keys[5]]);
		if (array_key_exists($keys[6], $arr)) $this->setIp($arr[$keys[6]]);
		if (array_key_exists($keys[7], $arr)) $this->setNavigateur($arr[$keys[7]]);
		if (array_key_exists($keys[8], $arr)) $this->setMarqueur($arr[$keys[8]]);
		if (array_key_exists($keys[9], $arr)) $this->setUtilisateurId($arr[$keys[9]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(LogPeer::DATABASE_NAME);

		if ($this->isColumnModified(LogPeer::ID)) $criteria->add(LogPeer::ID, $this->id);
		if ($this->isColumnModified(LogPeer::TYPE)) $criteria->add(LogPeer::TYPE, $this->type);
		if ($this->isColumnModified(LogPeer::DEGRE)) $criteria->add(LogPeer::DEGRE, $this->degre);
		if ($this->isColumnModified(LogPeer::TEXTE)) $criteria->add(LogPeer::TEXTE, $this->texte);
		if ($this->isColumnModified(LogPeer::DEBUT)) $criteria->add(LogPeer::DEBUT, $this->debut);
		if ($this->isColumnModified(LogPeer::FIN)) $criteria->add(LogPeer::FIN, $this->fin);
		if ($this->isColumnModified(LogPeer::IP)) $criteria->add(LogPeer::IP, $this->ip);
		if ($this->isColumnModified(LogPeer::NAVIGATEUR)) $criteria->add(LogPeer::NAVIGATEUR, $this->navigateur);
		if ($this->isColumnModified(LogPeer::MARQUEUR)) $criteria->add(LogPeer::MARQUEUR, $this->marqueur);
		if ($this->isColumnModified(LogPeer::UTILISATEUR_ID)) $criteria->add(LogPeer::UTILISATEUR_ID, $this->utilisateur_id);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(LogPeer::DATABASE_NAME);

		$criteria->add(LogPeer::ID, $this->id);

		return $criteria;
	}

	/**
	 * Returns the primary key for this object (row).
	 * @return     int
	 */
	public function getPrimaryKey()
	{
		return $this->getId();
	}

	/**
	 * Generic method to set the primary key (id column).
	 *
	 * @param      int $key Primary key.
	 * @return     void
	 */
	public function setPrimaryKey($key)
	{
		$this->setId($key);
	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of Log (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setType($this->type);

		$copyObj->setDegre($this->degre);

		$copyObj->setTexte($this->texte);

		$copyObj->setDebut($this->debut);

		$copyObj->setFin($this->fin);

		$copyObj->setIp($this->ip);

		$copyObj->setNavigateur($this->navigateur);

		$copyObj->setMarqueur($this->marqueur);

		$copyObj->setUtilisateurId($this->utilisateur_id);


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     Log Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     LogPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new LogPeer();
		}
		return self::$peer;
	}

	/**
	 * Declares an association between this object and a Utilisateur object.
	 *
	 * @param      Utilisateur $v
	 * @return     Log The current object (for fluent API support)
	 * @throws     PropelException
	 */
	public function setUtilisateur(Utilisateur $v = null)
	{
		if ($v === null) {
			$this->setUtilisateurId(NULL);
		} else {
			$this->setUtilisateurId($v->getId());
		}

		$this->aUtilisateur = $v;

		// Add binding for other direction of this n:n relationship.
		// If this object has already been added to the Utilisateur object, it will not be re-added.
		if ($v !== null) {
			$v->addLog($this);
		}

		return $this;
	}


	/**
	 * Get the associated Utilisateur object
	 *
	 * @param      PropelPDO Optional Connection object.
	 * @return     Utilisateur The associated Utilisateur object.
	 * @throws     PropelException
	 */
	public function getUtilisateur(PropelPDO $con = null)
	{
		if ($this->aUtilisateur === null && ($this->utilisateur_id !== null)) {
			$this->aUtilisateur = UtilisateurPeer::retrieveByPK($this->utilisateur_id, $con);
			/* The following can be used additionally to
			   guarantee the related object contains a reference
			   to this object.  This level of coupling may, however, be
			   undesirable since it could result in an only partially populated collection
			   in the referenced object.
			   $this->aUtilisateur->addLogs($this);
			 */
		}
		return $this->aUtilisateur;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
		} // if ($deep)

			$this->aUtilisateur = null;
	}

} // BaseLog
