<?php

/**
 * Base class that represents a row from the 'validations' table.
 *
 * Liste des niveaux de validation
 *
 * @package    competencesrb.om
 */
abstract class BaseValidationNiveau extends BaseObject  implements Persistent {


	/**
	 * The Peer class.
	 * Instance provides a convenient way of calling static methods on a class
	 * that calling code may not be able to identify.
	 * @var        ValidationNiveauPeer
	 */
	protected static $peer;

	/**
	 * The value for the id field.
	 * @var        int
	 */
	protected $id;

	/**
	 * The value for the rne field.
	 * @var        string
	 */
	protected $rne;

	/**
	 * The value for the lettre field.
	 * @var        string
	 */
	protected $lettre;

	/**
	 * The value for the texte field.
	 * @var        string
	 */
	protected $texte;

	/**
	 * The value for the couleur field.
	 * @var        string
	 */
	protected $couleur;

	/**
	 * The value for the niveau field.
	 * @var        int
	 */
	protected $niveau;

	/**
	 * @var        array JControleResultat[] Collection to store aggregation of JControleResultat objects.
	 */
	protected $collJControleResultats;

	/**
	 * @var        Criteria The criteria used to select the current contents of collJControleResultats.
	 */
	private $lastJControleResultatCriteria = null;

	/**
	 * @var        array Bilan[] Collection to store aggregation of Bilan objects.
	 */
	protected $collBilans;

	/**
	 * @var        Criteria The criteria used to select the current contents of collBilans.
	 */
	private $lastBilanCriteria = null;

	/**
	 * Flag to prevent endless save loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInSave = false;

	/**
	 * Flag to prevent endless validation loop, if this object is referenced
	 * by another object which falls in this transaction.
	 * @var        boolean
	 */
	protected $alreadyInValidation = false;

	/**
	 * Initializes internal state of BaseValidationNiveau object.
	 * @see        applyDefaults()
	 */
	public function __construct()
	{
		parent::__construct();
		$this->applyDefaultValues();
	}

	/**
	 * Applies default values to this object.
	 * This method should be called from the object's constructor (or
	 * equivalent initialization method).
	 * @see        __construct()
	 */
	public function applyDefaultValues()
	{
	}

	/**
	 * Get the [id] column value.
	 * cle primaire de la table validations
	 * @return     int
	 */
	public function getId()
	{
		return $this->id;
	}

	/**
	 * Get the [rne] column value.
	 * Etablissement de l'utilisateur
	 * @return     string
	 */
	public function getRne()
	{
		return $this->rne;
	}

	/**
	 * Get the [lettre] column value.
	 * Lettre de la validation
	 * @return     string
	 */
	public function getLettre()
	{
		return $this->lettre;
	}

	/**
	 * Get the [texte] column value.
	 * texte de la validation
	 * @return     string
	 */
	public function getTexte()
	{
		return $this->texte;
	}

	/**
	 * Get the [couleur] column value.
	 * Couleur de la validation en hexadecimal
	 * @return     string
	 */
	public function getCouleur()
	{
		return $this->couleur;
	}

	/**
	 * Get the [niveau] column value.
	 * Niveau de la validation
	 * @return     int
	 */
	public function getNiveau()
	{
		return $this->niveau;
	}

	/**
	 * Set the value of [id] column.
	 * cle primaire de la table validations
	 * @param      int $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setId($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->id !== $v) {
			$this->id = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::ID;
		}

		return $this;
	} // setId()

	/**
	 * Set the value of [rne] column.
	 * Etablissement de l'utilisateur
	 * @param      string $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setRne($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->rne !== $v) {
			$this->rne = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::RNE;
		}

		return $this;
	} // setRne()

	/**
	 * Set the value of [lettre] column.
	 * Lettre de la validation
	 * @param      string $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setLettre($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->lettre !== $v) {
			$this->lettre = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::LETTRE;
		}

		return $this;
	} // setLettre()

	/**
	 * Set the value of [texte] column.
	 * texte de la validation
	 * @param      string $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setTexte($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->texte !== $v) {
			$this->texte = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::TEXTE;
		}

		return $this;
	} // setTexte()

	/**
	 * Set the value of [couleur] column.
	 * Couleur de la validation en hexadecimal
	 * @param      string $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setCouleur($v)
	{
		if ($v !== null) {
			$v = (string) $v;
		}

		if ($this->couleur !== $v) {
			$this->couleur = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::COULEUR;
		}

		return $this;
	} // setCouleur()

	/**
	 * Set the value of [niveau] column.
	 * Niveau de la validation
	 * @param      int $v new value
	 * @return     ValidationNiveau The current object (for fluent API support)
	 */
	public function setNiveau($v)
	{
		if ($v !== null) {
			$v = (int) $v;
		}

		if ($this->niveau !== $v) {
			$this->niveau = $v;
			$this->modifiedColumns[] = ValidationNiveauPeer::NIVEAU;
		}

		return $this;
	} // setNiveau()

	/**
	 * Indicates whether the columns in this object are only set to default values.
	 *
	 * This method can be used in conjunction with isModified() to indicate whether an object is both
	 * modified _and_ has some values set which are non-default.
	 *
	 * @return     boolean Whether the columns in this object are only been set with default values.
	 */
	public function hasOnlyDefaultValues()
	{
			// First, ensure that we don't have any columns that have been modified which aren't default columns.
			if (array_diff($this->modifiedColumns, array())) {
				return false;
			}

		// otherwise, everything was equal, so return TRUE
		return true;
	} // hasOnlyDefaultValues()

	/**
	 * Hydrates (populates) the object variables with values from the database resultset.
	 *
	 * An offset (0-based "start column") is specified so that objects can be hydrated
	 * with a subset of the columns in the resultset rows.  This is needed, for example,
	 * for results of JOIN queries where the resultset row includes columns from two or
	 * more tables.
	 *
	 * @param      array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
	 * @param      int $startcol 0-based offset column which indicates which restultset column to start with.
	 * @param      boolean $rehydrate Whether this object is being re-hydrated from the database.
	 * @return     int next starting column
	 * @throws     PropelException  - Any caught Exception will be rewrapped as a PropelException.
	 */
	public function hydrate($row, $startcol = 0, $rehydrate = false)
	{
		try {

			$this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
			$this->rne = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
			$this->lettre = ($row[$startcol + 2] !== null) ? (string) $row[$startcol + 2] : null;
			$this->texte = ($row[$startcol + 3] !== null) ? (string) $row[$startcol + 3] : null;
			$this->couleur = ($row[$startcol + 4] !== null) ? (string) $row[$startcol + 4] : null;
			$this->niveau = ($row[$startcol + 5] !== null) ? (int) $row[$startcol + 5] : null;
			$this->resetModified();

			$this->setNew(false);

			if ($rehydrate) {
				$this->ensureConsistency();
			}

			// FIXME - using NUM_COLUMNS may be clearer.
			return $startcol + 6; // 6 = ValidationNiveauPeer::NUM_COLUMNS - ValidationNiveauPeer::NUM_LAZY_LOAD_COLUMNS).

		} catch (Exception $e) {
			throw new PropelException("Error populating ValidationNiveau object", $e);
		}
	}

	/**
	 * Checks and repairs the internal consistency of the object.
	 *
	 * This method is executed after an already-instantiated object is re-hydrated
	 * from the database.  It exists to check any foreign keys to make sure that
	 * the objects related to the current object are correct based on foreign key.
	 *
	 * You can override this method in the stub class, but you should always invoke
	 * the base method from the overridden method (i.e. parent::ensureConsistency()),
	 * in case your model changes.
	 *
	 * @throws     PropelException
	 */
	public function ensureConsistency()
	{

	} // ensureConsistency

	/**
	 * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
	 *
	 * This will only work if the object has been saved and has a valid primary key set.
	 *
	 * @param      boolean $deep (optional) Whether to also de-associated any related objects.
	 * @param      PropelPDO $con (optional) The PropelPDO connection to use.
	 * @return     void
	 * @throws     PropelException - if this object is deleted, unsaved or doesn't have pk match in db
	 */
	public function reload($deep = false, PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("Cannot reload a deleted object.");
		}

		if ($this->isNew()) {
			throw new PropelException("Cannot reload an unsaved object.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ValidationNiveauPeer::DATABASE_NAME, Propel::CONNECTION_READ);
		}

		// We don't need to alter the object instance pool; we're just modifying this instance
		// already in the pool.

		$stmt = ValidationNiveauPeer::doSelectStmt($this->buildPkeyCriteria(), $con);
		$row = $stmt->fetch(PDO::FETCH_NUM);
		$stmt->closeCursor();
		if (!$row) {
			throw new PropelException('Cannot find matching row in the database to reload object values.');
		}
		$this->hydrate($row, 0, true); // rehydrate

		if ($deep) {  // also de-associate any related objects?

			$this->collJControleResultats = null;
			$this->lastJControleResultatCriteria = null;

			$this->collBilans = null;
			$this->lastBilanCriteria = null;

		} // if (deep)
	}

	/**
	 * Removes this object from datastore and sets delete attribute.
	 *
	 * @param      PropelPDO $con
	 * @return     void
	 * @throws     PropelException
	 * @see        BaseObject::setDeleted()
	 * @see        BaseObject::isDeleted()
	 */
	public function delete(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("This object has already been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ValidationNiveauPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			ValidationNiveauPeer::doDelete($this, $con);
			$this->setDeleted(true);
			$con->commit();
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Persists this object to the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All modified related objects will also be persisted in the doSave()
	 * method.  This method wraps all precipitate database operations in a
	 * single transaction.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        doSave()
	 */
	public function save(PropelPDO $con = null)
	{
		if ($this->isDeleted()) {
			throw new PropelException("You cannot save an object that has been deleted.");
		}

		if ($con === null) {
			$con = Propel::getConnection(ValidationNiveauPeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
		}
		
		$con->beginTransaction();
		try {
			$affectedRows = $this->doSave($con);
			$con->commit();
			ValidationNiveauPeer::addInstanceToPool($this);
			return $affectedRows;
		} catch (PropelException $e) {
			$con->rollBack();
			throw $e;
		}
	}

	/**
	 * Performs the work of inserting or updating the row in the database.
	 *
	 * If the object is new, it inserts it; otherwise an update is performed.
	 * All related objects are also updated in this method.
	 *
	 * @param      PropelPDO $con
	 * @return     int The number of rows affected by this insert/update and any referring fk objects' save() operations.
	 * @throws     PropelException
	 * @see        save()
	 */
	protected function doSave(PropelPDO $con)
	{
		$affectedRows = 0; // initialize var to track total num of affected rows
		if (!$this->alreadyInSave) {
			$this->alreadyInSave = true;

			if ($this->isNew() ) {
				$this->modifiedColumns[] = ValidationNiveauPeer::ID;
			}

			// If this object has been modified, then save it to the database.
			if ($this->isModified()) {
				if ($this->isNew()) {
					$pk = ValidationNiveauPeer::doInsert($this, $con);
					$affectedRows += 1; // we are assuming that there is only 1 row per doInsert() which
										 // should always be true here (even though technically
										 // BasePeer::doInsert() can insert multiple rows).

					$this->setId($pk);  //[IMV] update autoincrement primary key

					$this->setNew(false);
				} else {
					$affectedRows += ValidationNiveauPeer::doUpdate($this, $con);
				}

				$this->resetModified(); // [HL] After being saved an object is no longer 'modified'
			}

			if ($this->collJControleResultats !== null) {
				foreach ($this->collJControleResultats as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			if ($this->collBilans !== null) {
				foreach ($this->collBilans as $referrerFK) {
					if (!$referrerFK->isDeleted()) {
						$affectedRows += $referrerFK->save($con);
					}
				}
			}

			$this->alreadyInSave = false;

		}
		return $affectedRows;
	} // doSave()

	/**
	 * Array of ValidationFailed objects.
	 * @var        array ValidationFailed[]
	 */
	protected $validationFailures = array();

	/**
	 * Gets any ValidationFailed objects that resulted from last call to validate().
	 *
	 *
	 * @return     array ValidationFailed[]
	 * @see        validate()
	 */
	public function getValidationFailures()
	{
		return $this->validationFailures;
	}

	/**
	 * Validates the objects modified field values and all objects related to this table.
	 *
	 * If $columns is either a column name or an array of column names
	 * only those columns are validated.
	 *
	 * @param      mixed $columns Column name or an array of column names.
	 * @return     boolean Whether all columns pass validation.
	 * @see        doValidate()
	 * @see        getValidationFailures()
	 */
	public function validate($columns = null)
	{
		$res = $this->doValidate($columns);
		if ($res === true) {
			$this->validationFailures = array();
			return true;
		} else {
			$this->validationFailures = $res;
			return false;
		}
	}

	/**
	 * This function performs the validation work for complex object models.
	 *
	 * In addition to checking the current object, all related objects will
	 * also be validated.  If all pass then <code>true</code> is returned; otherwise
	 * an aggreagated array of ValidationFailed objects will be returned.
	 *
	 * @param      array $columns Array of column names to validate.
	 * @return     mixed <code>true</code> if all validations pass; array of <code>ValidationFailed</code> objets otherwise.
	 */
	protected function doValidate($columns = null)
	{
		if (!$this->alreadyInValidation) {
			$this->alreadyInValidation = true;
			$retval = null;

			$failureMap = array();


			if (($retval = ValidationNiveauPeer::doValidate($this, $columns)) !== true) {
				$failureMap = array_merge($failureMap, $retval);
			}


				if ($this->collJControleResultats !== null) {
					foreach ($this->collJControleResultats as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}

				if ($this->collBilans !== null) {
					foreach ($this->collBilans as $referrerFK) {
						if (!$referrerFK->validate($columns)) {
							$failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
						}
					}
				}


			$this->alreadyInValidation = false;
		}

		return (!empty($failureMap) ? $failureMap : true);
	}

	/**
	 * Retrieves a field from the object by name passed in as a string.
	 *
	 * @param      string $name name
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     mixed Value of field.
	 */
	public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = ValidationNiveauPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		$field = $this->getByPosition($pos);
		return $field;
	}

	/**
	 * Retrieves a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @return     mixed Value of field at $pos
	 */
	public function getByPosition($pos)
	{
		switch($pos) {
			case 0:
				return $this->getId();
				break;
			case 1:
				return $this->getRne();
				break;
			case 2:
				return $this->getLettre();
				break;
			case 3:
				return $this->getTexte();
				break;
			case 4:
				return $this->getCouleur();
				break;
			case 5:
				return $this->getNiveau();
				break;
			default:
				return null;
				break;
		} // switch()
	}

	/**
	 * Exports the object as an array.
	 *
	 * You can specify the key type of the array by passing one of the class
	 * type constants.
	 *
	 * @param      string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                        BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. Defaults to BasePeer::TYPE_PHPNAME.
	 * @param      boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns.  Defaults to TRUE.
	 * @return     an associative array containing the field names (as keys) and field values
	 */
	public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
	{
		$keys = ValidationNiveauPeer::getFieldNames($keyType);
		$result = array(
			$keys[0] => $this->getId(),
			$keys[1] => $this->getRne(),
			$keys[2] => $this->getLettre(),
			$keys[3] => $this->getTexte(),
			$keys[4] => $this->getCouleur(),
			$keys[5] => $this->getNiveau(),
		);
		return $result;
	}

	/**
	 * Sets a field from the object by name passed in as a string.
	 *
	 * @param      string $name peer name
	 * @param      mixed $value field value
	 * @param      string $type The type of fieldname the $name is of:
	 *                     one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
	 *                     BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
	 * @return     void
	 */
	public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
	{
		$pos = ValidationNiveauPeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
		return $this->setByPosition($pos, $value);
	}

	/**
	 * Sets a field from the object by Position as specified in the xml schema.
	 * Zero-based.
	 *
	 * @param      int $pos position in xml schema
	 * @param      mixed $value field value
	 * @return     void
	 */
	public function setByPosition($pos, $value)
	{
		switch($pos) {
			case 0:
				$this->setId($value);
				break;
			case 1:
				$this->setRne($value);
				break;
			case 2:
				$this->setLettre($value);
				break;
			case 3:
				$this->setTexte($value);
				break;
			case 4:
				$this->setCouleur($value);
				break;
			case 5:
				$this->setNiveau($value);
				break;
		} // switch()
	}

	/**
	 * Populates the object using an array.
	 *
	 * This is particularly useful when populating an object from one of the
	 * request arrays (e.g. $_POST).  This method goes through the column
	 * names, checking to see whether a matching key exists in populated
	 * array. If so the setByName() method is called for that column.
	 *
	 * You can specify the key type of the array by additionally passing one
	 * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
	 * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
	 * The default key type is the column's phpname (e.g. 'AuthorId')
	 *
	 * @param      array  $arr     An array to populate the object from.
	 * @param      string $keyType The type of keys the array uses.
	 * @return     void
	 */
	public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
	{
		$keys = ValidationNiveauPeer::getFieldNames($keyType);

		if (array_key_exists($keys[0], $arr)) $this->setId($arr[$keys[0]]);
		if (array_key_exists($keys[1], $arr)) $this->setRne($arr[$keys[1]]);
		if (array_key_exists($keys[2], $arr)) $this->setLettre($arr[$keys[2]]);
		if (array_key_exists($keys[3], $arr)) $this->setTexte($arr[$keys[3]]);
		if (array_key_exists($keys[4], $arr)) $this->setCouleur($arr[$keys[4]]);
		if (array_key_exists($keys[5], $arr)) $this->setNiveau($arr[$keys[5]]);
	}

	/**
	 * Build a Criteria object containing the values of all modified columns in this object.
	 *
	 * @return     Criteria The Criteria object containing all modified values.
	 */
	public function buildCriteria()
	{
		$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);

		if ($this->isColumnModified(ValidationNiveauPeer::ID)) $criteria->add(ValidationNiveauPeer::ID, $this->id);
		if ($this->isColumnModified(ValidationNiveauPeer::RNE)) $criteria->add(ValidationNiveauPeer::RNE, $this->rne);
		if ($this->isColumnModified(ValidationNiveauPeer::LETTRE)) $criteria->add(ValidationNiveauPeer::LETTRE, $this->lettre);
		if ($this->isColumnModified(ValidationNiveauPeer::TEXTE)) $criteria->add(ValidationNiveauPeer::TEXTE, $this->texte);
		if ($this->isColumnModified(ValidationNiveauPeer::COULEUR)) $criteria->add(ValidationNiveauPeer::COULEUR, $this->couleur);
		if ($this->isColumnModified(ValidationNiveauPeer::NIVEAU)) $criteria->add(ValidationNiveauPeer::NIVEAU, $this->niveau);

		return $criteria;
	}

	/**
	 * Builds a Criteria object containing the primary key for this object.
	 *
	 * Unlike buildCriteria() this method includes the primary key values regardless
	 * of whether or not they have been modified.
	 *
	 * @return     Criteria The Criteria object containing value(s) for primary key(s).
	 */
	public function buildPkeyCriteria()
	{
		$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);

		$criteria->add(ValidationNiveauPeer::ID, $this->id);
		$criteria->add(ValidationNiveauPeer::LETTRE, $this->lettre);

		return $criteria;
	}

	/**
	 * Returns the composite primary key for this object.
	 * The array elements will be in same order as specified in XML.
	 * @return     array
	 */
	public function getPrimaryKey()
	{
		$pks = array();

		$pks[0] = $this->getId();

		$pks[1] = $this->getLettre();

		return $pks;
	}

	/**
	 * Set the [composite] primary key.
	 *
	 * @param      array $keys The elements of the composite key (order must match the order in XML file).
	 * @return     void
	 */
	public function setPrimaryKey($keys)
	{

		$this->setId($keys[0]);

		$this->setLettre($keys[1]);

	}

	/**
	 * Sets contents of passed object to values from current object.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      object $copyObj An object of ValidationNiveau (or compatible) type.
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @throws     PropelException
	 */
	public function copyInto($copyObj, $deepCopy = false)
	{

		$copyObj->setRne($this->rne);

		$copyObj->setLettre($this->lettre);

		$copyObj->setTexte($this->texte);

		$copyObj->setCouleur($this->couleur);

		$copyObj->setNiveau($this->niveau);


		if ($deepCopy) {
			// important: temporarily setNew(false) because this affects the behavior of
			// the getter/setter methods for fkey referrer objects.
			$copyObj->setNew(false);

			foreach ($this->getJControleResultats() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addJControleResultat($relObj->copy($deepCopy));
				}
			}

			foreach ($this->getBilans() as $relObj) {
				if ($relObj !== $this) {  // ensure that we don't try to copy a reference to ourselves
					$copyObj->addBilan($relObj->copy($deepCopy));
				}
			}

		} // if ($deepCopy)


		$copyObj->setNew(true);

		$copyObj->setId(NULL); // this is a auto-increment column, so set to default value

	}

	/**
	 * Makes a copy of this object that will be inserted as a new row in table when saved.
	 * It creates a new object filling in the simple attributes, but skipping any primary
	 * keys that are defined for the table.
	 *
	 * If desired, this method can also make copies of all associated (fkey referrers)
	 * objects.
	 *
	 * @param      boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
	 * @return     ValidationNiveau Clone of current object.
	 * @throws     PropelException
	 */
	public function copy($deepCopy = false)
	{
		// we use get_class(), because this might be a subclass
		$clazz = get_class($this);
		$copyObj = new $clazz();
		$this->copyInto($copyObj, $deepCopy);
		return $copyObj;
	}

	/**
	 * Returns a peer instance associated with this om.
	 *
	 * Since Peer classes are not to have any instance attributes, this method returns the
	 * same instance for all member of this class. The method could therefore
	 * be static, but this would prevent one from overriding the behavior.
	 *
	 * @return     ValidationNiveauPeer
	 */
	public function getPeer()
	{
		if (self::$peer === null) {
			self::$peer = new ValidationNiveauPeer();
		}
		return self::$peer;
	}

	/**
	 * Clears out the collJControleResultats collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addJControleResultats()
	 */
	public function clearJControleResultats()
	{
		$this->collJControleResultats = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collJControleResultats collection (array).
	 *
	 * By default this just sets the collJControleResultats collection to an empty array (like clearcollJControleResultats());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initJControleResultats()
	{
		$this->collJControleResultats = array();
	}

	/**
	 * Gets an array of JControleResultat objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau has previously been saved, it will retrieve
	 * related JControleResultats from storage. If this ValidationNiveau is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array JControleResultat[]
	 * @throws     PropelException
	 */
	public function getJControleResultats($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
			   $this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				JControleResultatPeer::addSelectColumns($criteria);
				$this->collJControleResultats = JControleResultatPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				JControleResultatPeer::addSelectColumns($criteria);
				if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
					$this->collJControleResultats = JControleResultatPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastJControleResultatCriteria = $criteria;
		return $this->collJControleResultats;
	}

	/**
	 * Returns the number of related JControleResultat objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related JControleResultat objects.
	 * @throws     PropelException
	 */
	public function countJControleResultats(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				$count = JControleResultatPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
					$count = JControleResultatPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collJControleResultats);
				}
			} else {
				$count = count($this->collJControleResultats);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a JControleResultat object to this object
	 * through the JControleResultat foreign key attribute.
	 *
	 * @param      JControleResultat $l JControleResultat
	 * @return     void
	 * @throws     PropelException
	 */
	public function addJControleResultat(JControleResultat $l)
	{
		if ($this->collJControleResultats === null) {
			$this->initJControleResultats();
		}
		if (!in_array($l, $this->collJControleResultats, true)) { // only add it if the **same** object is not already associated
			array_push($this->collJControleResultats, $l);
			$l->setValidationNiveau($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getJControleResultatsJoinControle($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinControle($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinControle($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getJControleResultatsJoinUtilisateur($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinUtilisateur($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related JControleResultats from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getJControleResultatsJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collJControleResultats === null) {
			if ($this->isNew()) {
				$this->collJControleResultats = array();
			} else {

				$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

				$this->collJControleResultats = JControleResultatPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(JControleResultatPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastJControleResultatCriteria) || !$this->lastJControleResultatCriteria->equals($criteria)) {
				$this->collJControleResultats = JControleResultatPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastJControleResultatCriteria = $criteria;

		return $this->collJControleResultats;
	}

	/**
	 * Clears out the collBilans collection (array).
	 *
	 * This does not modify the database; however, it will remove any associated objects, causing
	 * them to be refetched by subsequent calls to accessor method.
	 *
	 * @return     void
	 * @see        addBilans()
	 */
	public function clearBilans()
	{
		$this->collBilans = null; // important to set this to NULL since that means it is uninitialized
	}

	/**
	 * Initializes the collBilans collection (array).
	 *
	 * By default this just sets the collBilans collection to an empty array (like clearcollBilans());
	 * however, you may wish to override this method in your stub class to provide setting appropriate
	 * to your application -- for example, setting the initial array to the values stored in database.
	 *
	 * @return     void
	 */
	public function initBilans()
	{
		$this->collBilans = array();
	}

	/**
	 * Gets an array of Bilan objects which contain a foreign key that references this object.
	 *
	 * If this collection has already been initialized with an identical Criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau has previously been saved, it will retrieve
	 * related Bilans from storage. If this ValidationNiveau is new, it will return
	 * an empty collection or the current collection, the criteria is ignored on a new object.
	 *
	 * @param      PropelPDO $con
	 * @param      Criteria $criteria
	 * @return     array Bilan[]
	 * @throws     PropelException
	 */
	public function getBilans($criteria = null, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
			   $this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				BilanPeer::addSelectColumns($criteria);
				$this->collBilans = BilanPeer::doSelect($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return the collection.


				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				BilanPeer::addSelectColumns($criteria);
				if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
					$this->collBilans = BilanPeer::doSelect($criteria, $con);
				}
			}
		}
		$this->lastBilanCriteria = $criteria;
		return $this->collBilans;
	}

	/**
	 * Returns the number of related Bilan objects.
	 *
	 * @param      Criteria $criteria
	 * @param      boolean $distinct
	 * @param      PropelPDO $con
	 * @return     int Count of related Bilan objects.
	 * @throws     PropelException
	 */
	public function countBilans(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		} else {
			$criteria = clone $criteria;
		}

		if ($distinct) {
			$criteria->setDistinct();
		}

		$count = null;

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$count = 0;
			} else {

				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				$count = BilanPeer::doCount($criteria, $con);
			}
		} else {
			// criteria has no effect for a new object
			if (!$this->isNew()) {
				// the following code is to determine if a new query is
				// called for.  If the criteria is the same as the last
				// one, just return count of the collection.


				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
					$count = BilanPeer::doCount($criteria, $con);
				} else {
					$count = count($this->collBilans);
				}
			} else {
				$count = count($this->collBilans);
			}
		}
		$this->lastBilanCriteria = $criteria;
		return $count;
	}

	/**
	 * Method called to associate a Bilan object to this object
	 * through the Bilan foreign key attribute.
	 *
	 * @param      Bilan $l Bilan
	 * @return     void
	 * @throws     PropelException
	 */
	public function addBilan(Bilan $l)
	{
		if ($this->collBilans === null) {
			$this->initBilans();
		}
		if (!in_array($l, $this->collBilans, true)) { // only add it if the **same** object is not already associated
			array_push($this->collBilans, $l);
			$l->setValidationNiveau($this);
		}
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getBilansJoinUtilisateurRelatedByProfesseurId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByProfesseurId($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getBilansJoinUtilisateurRelatedByEleveId($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinUtilisateurRelatedByEleveId($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}


	/**
	 * If this collection has already been initialized with
	 * an identical criteria, it returns the collection.
	 * Otherwise if this ValidationNiveau is new, it will return
	 * an empty collection; or if this ValidationNiveau has previously
	 * been saved, it will retrieve related Bilans from storage.
	 *
	 * This method is protected by default in order to keep the public
	 * api reasonable.  You can provide public methods for those you
	 * actually need in ValidationNiveau.
	 */
	public function getBilansJoinCompetence($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
	{
		if ($criteria === null) {
			$criteria = new Criteria(ValidationNiveauPeer::DATABASE_NAME);
		}
		elseif ($criteria instanceof Criteria)
		{
			$criteria = clone $criteria;
		}

		if ($this->collBilans === null) {
			if ($this->isNew()) {
				$this->collBilans = array();
			} else {

				$criteria->add(BilanPeer::RESULTAT, $this->lettre);

				$this->collBilans = BilanPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		} else {
			// the following code is to determine if a new query is
			// called for.  If the criteria is the same as the last
			// one, just return the collection.

			$criteria->add(BilanPeer::RESULTAT, $this->lettre);

			if (!isset($this->lastBilanCriteria) || !$this->lastBilanCriteria->equals($criteria)) {
				$this->collBilans = BilanPeer::doSelectJoinCompetence($criteria, $con, $join_behavior);
			}
		}
		$this->lastBilanCriteria = $criteria;

		return $this->collBilans;
	}

	/**
	 * Resets all collections of referencing foreign keys.
	 *
	 * This method is a user-space workaround for PHP's inability to garbage collect objects
	 * with circular references.  This is currently necessary when using Propel in certain
	 * daemon or large-volumne/high-memory operations.
	 *
	 * @param      boolean $deep Whether to also clear the references on all associated objects.
	 */
	public function clearAllReferences($deep = false)
	{
		if ($deep) {
			if ($this->collJControleResultats) {
				foreach ((array) $this->collJControleResultats as $o) {
					$o->clearAllReferences($deep);
				}
			}
			if ($this->collBilans) {
				foreach ((array) $this->collBilans as $o) {
					$o->clearAllReferences($deep);
				}
			}
		} // if ($deep)

		$this->collJControleResultats = null;
		$this->collBilans = null;
	}

} // BaseValidationNiveau
